<?php

namespace App\Exports;

use App\Models\Course;
use App\Models\NominatedTrainee;
use Illuminate\Contracts\View\View;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\Exportable;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromView;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;

class CourseTraineeExport implements FromView, ShouldAutoSize
{
    use Exportable;

    protected $id;

    function __construct($id)
    {
        $this->id = $id;
    }

    /**
     * @return \Illuminate\Support\Collection
     */
    public function view(): View
    {
        $findCourse = Course::findOrFail($this->id);
        $users = DB::table('nominated_trainees')->join('users', 'users.id', 'nominated_trainees.user_id')
            ->join('trainee_infos', 'trainee_infos.user_id', 'users.id')
            ->leftJoin('designations', 'designations.id', 'trainee_infos.designation')
            ->leftJoin('organizations', 'organizations.id', 'trainee_infos.organization_id')
            ->where('nominated_trainees.nomination_id', $findCourse->nomination_id)
            ->where('nominated_trainees.approve', 1)
            ->select('users.name', 'designations.name as designation_name', 'organizations.name as organization_name', 'trainee_infos.email', 'trainee_infos.other_designation as other_designation', 'trainee_infos.mobile_no')
            ->get();
        return view('export.course_trainee', [
            'data' => $users
        ]);
    }
}
