<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyBatchRequest;
use App\Http\Requests\StoreBatchRequest;
use App\Http\Requests\UpdateBatchRequest;
use App\Models\Batch;
use Gate;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class BatchController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {

        abort_if(Gate::denies('batch_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $batches = Batch::all();

        return view('admin.batches.index', compact('batches'));
    }

    public function create()
    {
        abort_if(Gate::denies('batch_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.batches.create');
    }

    public function store(StoreBatchRequest $request)
    {
        $batch = Batch::create($request->all());

        return redirect()->route('batches.index');
    }

    public function edit(Batch $batch)
    {
        abort_if(Gate::denies('batch_edit' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.batches.edit', compact('batch'));
    }

    public function update(UpdateBatchRequest $request, Batch $batch)
    {
        $batch->update($request->all());

        return redirect()->route('batches.index');
    }

    public function show(Batch $batch)
    {
        abort_if(Gate::denies('batch_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $batch->load('batchNominations');

        return view('admin.batches.show', compact('batch'));
    }

    public function destroy(Batch $batch)
    {
        abort_if(Gate::denies('batch_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $batch->delete();

        return back();
    }

    public function massDestroy(MassDestroyBatchRequest $request)
    {
        Batch::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
