<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyBudgetRequest;
use App\Http\Requests\StoreBudgetRequest;
use App\Http\Requests\UpdateBudgetRequest;
use App\Models\Budget;
use App\Models\User;
use Gate;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class BudgetController extends Controller
{
    public $courseRole;
    protected $user;


    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->user= Auth::user();
            $this->courseRole = CourseRole::where('user_id', $this->user->id)->get();
            return $next($request);
        });
        
    }
    public function index()
    {
        abort_if(Gate::denies('budget_access' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $budgets = Budget::with(['created_by'])->get();

        return view('admin.budgets.index', compact('budgets'));
    }

    public function create()
    {
        abort_if(Gate::denies('budget_create' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.budgets.create', compact('created_bies'));
    }

    public function store(StoreBudgetRequest $request)
    {
        $budget = Budget::create($request->all());

        $notification = array(
            'toaster-message' => 'Budget Created successfuly',
            'alert-type' => 'success'
        );

        return redirect()->route('budgets.index')->with($notification);
    }

    public function edit(Budget $budget)
    {
        abort_if(Gate::denies('budget_edit' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $budget->load('created_by');

        return view('admin.budgets.edit', compact('budget', 'created_bies'));
    }

    public function update(UpdateBudgetRequest $request, Budget $budget)
    {
        $budget->update($request->all());

        return redirect()->route('budgets.index');
    }

    public function show(Budget $budget)
    {
        abort_if(Gate::denies('budget_show' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $budget->load('created_by');

        return view('admin.budgets.show', compact('budget'));
    }

    public function destroy($id)
    {
        //abort_if(Gate::denies('budget_delete' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $budget=Budget::findOrFail($id);
        $budget->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }


    public function massDestroy(MassDestroyBudgetRequest $request)
    {
        Budget::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
