<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AssignmentFile;
use App\Models\Course;
use App\Models\Coursefeepayment;
use App\Models\CoursePayment;
use App\Models\ExamResult;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Gate;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use App\Models\ExamModule;
use App\Models\NominatedTrainee;
use App\Models\TraineeInfo;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\DB;

class CertificateController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('certificate_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courses = Course::where('is_approved', 1)->latest()->get();

        return view('admin.certificate.index', compact('courses'));
    }

    public function store(Request $request)
    {
        abort_if(Gate::denies('certificate_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $course = Course::findOrFail($request->course_id);
        $nomination_id = $course->nomination_id;
        if ($course->course_end > date("d-m-Y")) {
            return response()->json(['res' => 'Training not finished yet !'], 400);
        }
        $total_exam_module_mark = $course->courseExamModule()->sum('number');
        $trainee_id = $request->trainee_id;
        if ($trainee_id) {
            $process_marks = $this->generateMarks($trainee_id, $course, $total_exam_module_mark);

            return response()->json(
                [
                    'res' => $process_marks['data'],
                    'results' => $process_marks['results'],
                    'percentage' => $process_marks['percentage'],
                    'paymentStatus' => $process_marks['paymentStatus'],
                ],
                200
            );
        } else {
            $trainee_list = NominatedTrainee::where('nomination_id', $nomination_id)->select('user_id')->get();

            foreach ($trainee_list as $key => $value) {
                $all_trainee_marks[] = $this->generateMarks($value->user_id, $course, $total_exam_module_mark);
            }
            return response()->json($all_trainee_marks);
        }
    }

    public function generateMarks($trainee_id, $course, $total_exam_module_mark)
    {
        $trainee_marks = Course::leftJoin('exam_modules', 'exam_modules.course_id', 'courses.id')
            ->leftJoin('exam_marks', function ($join) use ($trainee_id) {
                $join->on('exam_marks.exam_module_id', '=', 'exam_modules.id');
                $join->where('exam_marks.trainee_id', '=', $trainee_id);
            })
            ->leftJoin('exam_results', function ($join) use ($trainee_id) {
                $join->on('exam_results.exam_module_id', '=', 'exam_modules.id');
                $join->where('exam_results.user_id', '=', $trainee_id);
            })
            ->select(DB::raw('SUM(exam_marks.marks) as exam_marks, SUM(exam_results.total_number) as quiz_marks'))
            ->get();


        $find_individual_assignment = ExamModule::where('exam_type', 'individual assignment')->where('course_id', $course->id)->select('id', 'number')->get();

        $deduct_number = $find_individual_assignment->map(function ($data) use ($trainee_id) {
            $number = 0;
            $IA_exist = AssignmentFile::where('exam_module_id', $data->id)
                ->where('user_id', $trainee_id)
                ->select('id', 'exam_module_id')
                ->get();
            if (count($IA_exist) == 0) {
                $number = $number + $data->number;
            }
            return $number;
        })->first();

        $total_number_of_trainee = collect($trainee_marks)->map(function ($data) {
            return $data->exam_marks + $data->quiz_marks;
        })->first();

        $total_exam_mark = $total_exam_module_mark - $deduct_number;

        $trainee = User::where('id', $trainee_id)->with('traineeInfo')->first();
        $data = [
            'course' => $course->title,
            'course_id' => $course->id,
            'start_date' =>  Carbon::parse($course->course_start)->format('jS F'),
            'end_date' => Carbon::parse($course->course_end)->format('jS F'),
            'year' => Carbon::parse($course->course_end)->format('Y'),
            'trainee_name' => $trainee->name,
            'trainee_id' => $trainee_id,
        ];
        // TRAINEE RESULT 
        $results =  [
            'total_exam_module_marks' => round($total_exam_mark, 2),
            'trainee_total_number' => round($total_number_of_trainee, 2)
        ];
        $info['percentage'] = round(100 * $results['trainee_total_number'] / $results['total_exam_module_marks'], 2);

        // PAYMENT STATUS
        $info['paymentStatus'] = CoursePayment::whereUserId($trainee_id)->whereCourseId($course->id)->whereStatus(1)->first();
        $info['results'] = $results;
        $info['data'] = $data;


        return $info;
    }

    public function certificatePDF(Request $request, Course $course)
    {
        $trainee_id = $request->trainee;
        $trainee = TraineeInfo::where('user_id', $trainee_id)->first();
        //get rector and mds user from user table
        $users = User::whereIn('id', [6, 7])->get()->toArray();
        $data = [
            'course' => $course->title,
            'course_id' => $course->id,
            'start_date' =>  Carbon::parse($course->course_start)->format('jS F'),
            'end_date' => Carbon::parse($course->course_end)->format('jS F'),
            'year' => Carbon::parse($course->course_end)->format('Y'),
            'trainee_name' => ucfirst($trainee->name_english),
            'designation' => $trainee->other_designation ? $trainee->other_designation : $trainee->user_designation->name,
            'mds_sign' => $users[0]['sign'],
            'mds_name' => $users[0]['designation'],
            'rector_sign' => $users[1]['sign'],
            'rector_name' => $users[1]['designation'],
        ];

        $mpdf = new \Mpdf\Mpdf();
        $mpdf->SetBasePath(public_path());
        $mpdf->WriteHTML(view('admin.certificate.view', compact('data')));
        $mpdf->Output();
    }
}
