<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCourseAssociateOfficerRequest;
use App\Http\Requests\StoreCourseAssociateOfficerRequest;
use App\Http\Requests\UpdateCourseAssociateOfficerRequest;
use App\Models\Course;
use App\Models\CourseAssociateOfficer;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class CourseAssociateOfficerController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('course_associate_officer_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseAssociateOfficers = CourseAssociateOfficer::with(['user', 'course'])->get();

        return view('admin.courseAssociateOfficers.index', compact('courseAssociateOfficers'));
    }

    public function create()
    {
        abort_if(Gate::denies('course_associate_officer_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.courseAssociateOfficers.create', compact('courses', 'users'));
    }

    public function store(StoreCourseAssociateOfficerRequest $request)
    {
        $courseAssociateOfficer = CourseAssociateOfficer::create($request->all());

        return redirect()->route('course-associate-officers.index');
    }

    public function edit(CourseAssociateOfficer $courseAssociateOfficer)
    {
        abort_if(Gate::denies('course_associate_officer_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courseAssociateOfficer->load('user', 'course');

        return view('admin.courseAssociateOfficers.edit', compact('courseAssociateOfficer', 'courses', 'users'));
    }

    public function update(UpdateCourseAssociateOfficerRequest $request, CourseAssociateOfficer $courseAssociateOfficer)
    {
        $courseAssociateOfficer->update($request->all());

        return redirect()->route('course-associate-officers.index');
    }

    public function show(CourseAssociateOfficer $courseAssociateOfficer)
    {
        abort_if(Gate::denies('course_associate_officer_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseAssociateOfficer->load('user', 'course');

        return view('admin.courseAssociateOfficers.show', compact('courseAssociateOfficer'));
    }

    public function destroy(CourseAssociateOfficer $courseAssociateOfficer)
    {
        abort_if(Gate::denies('course_associate_officer_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseAssociateOfficer->delete();

        return back();
    }

    public function massDestroy(MassDestroyCourseAssociateOfficerRequest $request)
    {
        CourseAssociateOfficer::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
