<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCourseBudgetRequest;
use App\Http\Requests\StoreCourseBudgetRequest;
use App\Http\Requests\UpdateCourseBudgetRequest;
use App\Models\Budget;
use App\Models\Course;
use App\Models\CourseBudget;
use Gate;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class CourseBudgetController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }
    
    public function index()
    {
        abort_if(Gate::denies('course_budget_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseBudgets = CourseBudget::with(['budget', 'course'])->get();

        return view('admin.courseBudgets.index', compact('courseBudgets'));
    }

    public function create()
    {
        abort_if(Gate::denies('course_budget_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $budgets = Budget::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.courseBudgets.create', compact('budgets', 'courses'));
    }

    public function store(StoreCourseBudgetRequest $request)
    {
        $courseBudget = CourseBudget::create($request->all());

        return redirect()->route('course-budgets.index');
    }

    public function edit(CourseBudget $courseBudget)
    {
        abort_if(Gate::denies('course_budget_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $budgets = Budget::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courseBudget->load('budget', 'course');

        return view('admin.courseBudgets.edit', compact('budgets', 'courseBudget', 'courses'));
    }

    public function update(UpdateCourseBudgetRequest $request, CourseBudget $courseBudget)
    {
        $courseBudget->update($request->all());

        return redirect()->route('course-budgets.index');
    }

    public function show(CourseBudget $courseBudget)
    {
        abort_if(Gate::denies('course_budget_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseBudget->load('budget', 'course');

        return view('admin.courseBudgets.show', compact('courseBudget'));
    }

    public function destroy(CourseBudget $courseBudget)
    {
        abort_if(Gate::denies('course_budget_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseBudget->delete();

        return back();
    }

    public function massDestroy(MassDestroyCourseBudgetRequest $request)
    {
        CourseBudget::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
