<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCourseContentRequest;
use App\Http\Requests\StoreCourseContentRequest;
use App\Http\Requests\UpdateCourseContentRequest;
use App\Models\Course;
use App\Models\CourseContent;
use Gate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Symfony\Component\HttpFoundation\Response;

class CourseContentController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('course_content_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseContents = CourseContent::with(['course'])->get();

        return view('admin.courseContents.index', compact('courseContents'));
    }

    public function create()
    {
        abort_if(Gate::denies('course_content_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.courseContents.create', compact('courses'));
    }

    public function store(StoreCourseContentRequest $request)
    {
        $courseContent = CourseContent::create($request->all());

        return redirect()->route('course-contents.index');
    }

    public function edit(CourseContent $courseContent)
    {
        abort_if(Gate::denies('course_content_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courses = Course::pluck('course_code', 'id')->prepend(trans('global.pleaseSelect'), '');

        $courseContent->load('course');

        return view('admin.courseContents.edit', compact('courseContent', 'courses'));
    }

    public function update(UpdateCourseContentRequest $request, CourseContent $courseContent)
    {
        $courseContent->update($request->all());

        return redirect()->route('course-contents.index');
    }

    public function show(CourseContent $courseContent)
    {
        abort_if(Gate::denies('course_content_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseContent->load('course');

        return view('admin.courseContents.show', compact('courseContent'));
    }

    public function destroy(CourseContent $courseContent)
    {
        abort_if(Gate::denies('course_content_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $courseContent->delete();

        return back();
    }

    public function massDestroy(MassDestroyCourseContentRequest $request)
    {
        CourseContent::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
