<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyCourseRequest;
use App\Http\Requests\StoreCourseRequest;
use App\Http\Requests\UpdateCourseRequest;
use App\Imports\CourseContentImport;
use App\Imports\LessonImport;
use App\Models\AssignmentFile;
use App\Models\AssignmentGroup;
use App\Models\AssignmentSubmission;
use App\Models\Batch;
use App\Models\Budget;
use App\Models\Course;
use App\Models\CourseAssociateOfficer;
use App\Models\CourseBudget;
use App\Models\CourseContent;
use App\Models\CourseInitiation;
use App\Models\CourseRole;
use App\Models\CourseSetting;
use App\Models\ExamMark;
use App\Models\ExamModule;
use App\Models\LearningPoint;
use App\Models\Lesson;
use App\Models\NominatedTrainee;
use App\Models\Nomination;
use App\Models\PresentationFile;
use App\Models\PresentationGroup;
use App\Models\Role;
use App\Models\Trainer;
use App\Models\TrainerApproval;
use App\Models\TrainerEvaluation;
use App\Models\User;
use Carbon\Carbon;
use Gate;
use File;
// use DataTables;
use Illuminate\Validation\ValidationException;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;
use Excel;
use Yajra\DataTables\DataTables;

class CourseController extends Controller
{
    use MediaUploadingTrait;

    public $courseRole;
    protected $user;


    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $this->user = Auth::user();

            if ($this->user) {
                $this->courseRole = CourseRole::where('user_id', $this->user->id)->get();
            } else {
                $this->courseRole = null;
            }
            // dd($this->courseRole->toArray());

            return $next($request);
        });
    }

    public function checkVal($array, $string)
    {
        if (in_array($string, $array)) {
            return true;
        } else {
            return false;
        }
    }

    public function index(Request $request)
    {
        abort_if(Gate::denies('course_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // $roles = Role::leftJoin('course_roles', 'course_roles.role_id', 'roles.id')
        //     ->leftJoin('users', 'users.id', 'course_roles.user_id')
        //     ->where('course_roles.user_id', auth()->user()->id)
        //     ->pluck('title')->toArray();
        // $roleId = Role::with(['permissions'])->get()->toArray();
        $roles = CourseRole::with(['role'])->where('user_id', auth()->user()->id)->get()->pluck('role.title')->toArray();
        $courses = Course::latest()->get();

        // dd(auth()->user()->can("course_settings", $this->courseRole));
        if ($request->ajax()) {
            return Datatables::of($courses)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $html = '<div class="btn-group">
                <button type="button" class="btn btn-info dropdown-toggle btn-xs" 
                    data-toggle="dropdown" aria-expanded="false">Action
                    <span class="caret"></span><span class="sr-only">Toggle Dropdown
                    </span>
                </button>
                <ul class="dropdown-menu dropdown-menu-right" role="menu">';
                    if (auth()->user()->can("adjustment_sheet", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courseadjustmentsheet.index', $row->id) . '"><i class="fa fa-caret-right"></i>Course Adjustment Sheet</a>';
                    }
                    if (auth()->user()->can("course_settings", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.settings', $row->id) . '"><i class="fa fa-caret-right"></i>Course Setting</a>';
                    }
                    if (auth()->user()->can("course_settings", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.trainer.list', $row->id) . '"><i class="fa fa-caret-right"></i>Trainer list</a>';
                    }
                    // if (auth()->user()->can("view_assignment",$this->courseRole)) {
                    //     $html .= '<li><a class="singleassignment" onclick="singleAssignmentModal(this.id)" href="javascript:void(0)" id="'.$row->id.'"><i class="fa fa-caret-right"></i>My Assignment</a> <li><a class="groupassignment" onclick="groupAssignmentModal(this.id)" href="javascript:void(0)" id="'.$row->id.'"><i class="fa fa-caret-right"></i>Group Assignment</a>';
                    // }
                    if (auth()->user()->can("course_trainee_view", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('course-trainee.view', $row->id) . '"><i class="fa fa-caret-right"></i>View Trainee</a>';
                    }
                    if (auth()->user()->can("course_add_lesson", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.addlesson', $row->id) . '"><i class="fa fa-caret-right"></i>Add Lesson</a>';
                    }
                    if (auth()->user()->can("course_view_lesson", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.viewlesson', $row->id) . '"><i class="fa fa-caret-right"></i>View Lesson</a>';
                    }
                    if (auth()->user()->can("course_settings", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.examModule', $row->id) . '"><i class="fa fa-caret-right"></i>Exam Module</a>';
                    }

                    if (auth()->user()->can("course_show", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.show', $row->id) . '"><i class="fa fa-caret-right"></i>View Course</a>';
                    }
                    if (auth()->user()->can("course_edit", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('courses.edit', $row->id) . '"><i class="fa fa-caret-right"></i>Edit Course</a>';
                    }


                    if (auth()->user()->can("release_order_create", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('release-order.create', $row->id) . '"><i class="fa fa-caret-right"></i>Release Order</a>';
                    }

                    if (auth()->user()->can("allownce_acknowledgement", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('allowance-create', $row->id) . '"><i class="fa fa-caret-right"></i>Allowance form</a>';
                    }
                    if (auth()->user()->can("allownce_acknowledgement", $this->courseRole)) {
                        $html .= '<li> <a  href="' . route('allowance-list', $row->id) . '"><i class="fa fa-caret-right"></i>Allowance list</a>';
                    }
                    if (auth()->user()->can("course_delete", $this->courseRole)) {
                        $html .= '<li><a href="' . route('courses.destroy', [$row->id]) . '" class="delete-course"><i class="fa fa-trash"></i>Delete</a></li>';
                    }
                    $authid = auth()->user()->id;
                    $posssible_trainers = TrainerApproval::where('user_id', $authid)->where('course_id', $row->id)->first();

                    if ($posssible_trainers && $posssible_trainers->approved == 0) {
                        $html .= '<li><a href="' . route('courses.approveOrDenyCourseByTrainer', [$row->id]) . '" class="take-course"><i class="fa fa-check"></i> Take Course</a></li> <li><a href="' . route('courses.approveOrDenyCourseByTrainer', [$row->id]) . '" class="deny-course"><i class="fa fa-close"></i>Deny Course</a></li>';
                    }
                    $html .=  '</ul></div>';
                    return $html;
                })
                ->editColumn('type_course', function ($row) {
                    return Course::TYPE_COURSE_SELECT[$row->type_course] ?? '';
                })
                ->rawColumns(['action', 'type_course'])
                ->make(true);
        } elseif ($this->checkVal($roles, 'MDS')) {
            return view('admin.courses.index', compact('courses'));
        } elseif ($this->checkVal($roles, 'Rector')) {
            return view('admin.courses.index', compact('courses'));
        } elseif ($this->checkVal($roles, 'Course Director')) {
            return view('admin.courses.mycourses', compact('courses'));
        } else {
            $roles = auth()->user()->roles()->pluck('title')->toArray();
            if ($this->checkVal($roles, 'Admin')) {
                return view('admin.courses.index', compact('courses'));
            } else {
                $courses = Course::FilteredList()->get();
                return view('admin.courses.index', compact('courses'));
            }
        }

        return view('admin.courses.mycourses', compact('courses'));
    }

    public function previousCourses()
    {
        abort_if(Gate::denies('course_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');


        $authid = strval(auth()->user()->id);
        $roles = auth()->user()->roles()->pluck('title')->toArray();

        if ($this->checkVal($roles, 'MDS')) {
            $courses = Course::AllList()->where('course_end', '<', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } elseif ($this->checkVal($roles, 'Rector')) {
            $courses = Course::AllList()->where('course_end', '<', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } elseif ($this->checkVal($roles, 'Admin')) {
            $courses = Course::AllList()->where('course_end', '<', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } else {
            $courses = Course::FilteredList()->where('course_end', '<', date('y-m-d'))->get();
            return view('admin.courses.index', compact('courses'));
        }
    }


    public function ongoingCourses()
    {

        abort_if(Gate::denies('course_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $authid = strval(auth()->user()->id);
        $roles = auth()->user()->roles()->pluck('title')->toArray();

        if ($this->checkVal($roles, 'MDS')) {
            $courses = Course::AllList()->where('course_start', '<=', date('y-m-d'))->where('course_end', '>=', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } elseif ($this->checkVal($roles, 'Rector')) {
            $courses = Course::AllList()->where('course_start', '<=', date('y-m-d'))->where('course_end', '>=', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } elseif ($this->checkVal($roles, 'Admin')) {
            $courses = Course::AllList()->where('course_start', '<=', date('y-m-d'))->where('course_end', '>=', date('y-m-d'))->get();
            return view('admin.courses.mycourses', compact('courses'));
        } else {
            $courses = Course::FilteredList()->where('course_start', '<=', date('y-m-d'))->where('course_end', '>=', date('y-m-d'))->get();
            return view('admin.courses.index', compact('courses'));
        }
    }

    public function courseSettingsEdit(Course $course)
    {
        $course = $course->load('settings');
        return view('admin.courses.settings', compact('course'));
    }

    public function updateCourseSettings(Course $course, Request $request)
    {
        $data = $request->except(['_method', '_token']);

        $course->settings()->updateOrCreate(['course_id' => $course->id], $data);

        return redirect()->back();
    }

    public function courseTrainerList(Request $request, $courseId)
    {
        $course = Course::find($courseId);
        $course_trainers = $course->trainerApproval->load('user');
        return view('admin.courses.trainerList', compact('course_trainers', 'course'));
    }


    public function create()
    {

        abort_if(Gate::denies('course_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominations = Nomination::pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $budgets = Budget::where('status', 1)->get();

        return view('admin.courses.create', compact('created_bies', 'nominations', 'budgets'));
    }
    // COURSE CREATE WITH  Intiation
    public function courseCreateWithIntiation($intiationId)
    {

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
        $courseIntioation = CourseInitiation::findOrFail($intiationId);
        $budgets = Budget::where('status', 1)->get();
        $batches = Batch::get();
        return view('admin.courses.createIntiation', compact('created_bies', 'budgets', 'courseIntioation', 'batches'));
    }


    public function store(StoreCourseRequest $request)
    {
        ini_set('memory_limit', '64M');
        //dd($request->all());
        // abort_if(Gate::denies('course_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        DB::beginTransaction();
        try {

            // $nomination = Nomination::findOrFail($request->nomination_id);
            $courseInitiation = CourseInitiation::findOrFail($request->course_initiation_id);
            $course = new Course();
            $course->course_code = $request->course_code;
            $course->title = $request->title;
            $course->type_course = $request->type_course;
            $course->course_duration = $request->course_duration;
            $course->field_visit = $request->field_visit;
            $course->course_start = $request->course_start;
            $course->course_end = $request->course_end;
            $course->requiring_body = $request->requiring_body;
            $course->course_principal_advisor = $request->principal_advisor;
            // $course->nomination_id = $nomination->id;
            $course->total_budget = $request->total_budget;
            $course->budget_tax = $request->budget_tax;
            $course->total_budget_inc_vat = $request->total_budget_inc_vat;
            $course->course_initiation_id = $courseInitiation->id;
            $course->batch_id = $request->batch_id;
            $course->course_advisor = $request->course_advisor;
            $course->course_director = $request->course_director;
            $course->possible_trainers = $request->possible_trainers;
            $course->course_co_ordinator = $request->course_co_ordinator;
            $course->course_helper = $request->course_helper;
            $course->associcate_course_co_ordinator = $request->assoc_course_co_ordinator;
            $course->save();

            if ($request->file('file')) {
                $import = new LessonImport($course->id);
                $import->import($request->file('file'));
            }

            $course_role = CourseRole::find($courseInitiation->course_role_id);
            $course_role->course_id = $course->id;
            $course_role->save();
            //save user role to the course

            if ($request->course_director && is_array($request->course_director)) {
                foreach ($request->course_director as $key => $value) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $value;
                    $course_role->course_id = $course->id;
                    $course_role->role_id = 9;
                    $course_role->save();
                }
            }
            if ($request->course_co_ordinator && is_array($request->course_co_ordinator)) {
                foreach ($request->course_co_ordinator as $key => $value) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $value;
                    $course_role->course_id = $course->id;
                    $course_role->role_id = 14;
                    $course_role->save();
                }
            }
            if ($request->assoc_course_co_ordinator && is_array($request->assoc_course_co_ordinator)) {
                foreach ($request->assoc_course_co_ordinator as $key => $value) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $value;
                    $course_role->course_id = $course->id;
                    $course_role->role_id = 15;
                    $course_role->save();
                }
            }

            if ($request->course_helper && is_array($request->course_helper)) {
                foreach ($request->course_helper as $key => $value) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $value;
                    $course_role->course_id = $course->id;
                    $course_role->role_id = 16;
                    $course_role->save();
                }
            }
            if ($request->course_advisor && is_array($request->course_advisor)) {
                foreach ($request->course_advisor as $key => $value) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $value;
                    $course_role->course_id = $course->id;
                    $course_role->role_id = 17;
                    $course_role->save();
                }
            }




            if ($request->has('budget')) {

                foreach ($request->budget as $key => $value) {
                    $course_budget = new CourseBudget();
                    if (array_key_exists('budget_id', $value)) {
                        $course_budget->budget_id = $value['budget_id'];
                    } else {
                        $course_budget->budget_name = $value['name'];
                    }

                    $course_budget->unit = $value['unit'];
                    $course_budget->qty = $value['qty'];
                    $course_budget->rate = $value['rate'];
                    $course_budget->total_cost = $value['total_cost'];
                    $course_budget->course_id = $course->id;
                    $course_budget->save();
                }
            }

            if ($media = $request->input('ck-media', false)) {
                Media::whereIn('id', $media)->update(['model_id' => $course->id]);
            }
        } catch (\Exception $e) {
            DB::rollback();
            // return back()->withError('Something wrong');
            throw $e;
        }
        DB::commit();

        $notification = array(
            'toaster-message' => 'Course Created successfuly',
            'alert-type' => 'success'
        );

        return redirect()->route('course-initiation.index')->with($notification);
    }

    public function edit(Course $course)
    {

        abort_if(Gate::denies('course_edit', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        //$nominations = Nomination::pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');
        //   $course = Course::with(['possibleTrainers'])->findOrFail($course->id);
        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
        $budgets = Budget::where('status', 1)->get();
        $course_budgets = CourseBudget::with(['budget'])->where('course_id', $course->id)->get();
        $course->load('nomination', 'created_by');
        $course_contents = CourseContent::where('course_id', $course->id)->get();
        // $course_associate_offices = CourseAssociateOfficer::where('course_id', $course->id)->first();

        return view('admin.courses.edit', compact('course', 'created_bies', 'budgets', 'course_contents', 'course_budgets'));
    }

    public function update(UpdateCourseRequest $request, Course $course)
    {
        // dd($request->all());
        DB::beginTransaction();
        try {
            $course->update($request->all());

            if ($request->has('budget')) {

                foreach ($request->budget as $key => $value) {

                    if (array_key_exists('budget_id', $value)) {
                        $course_budget = CourseBudget::findOrFail($value['budget_id']);
                    } else {
                        $course_budget = new CourseBudget();
                        $course_budget->budget_name = $value['name'];
                        $course_budget->course_id  = $course->id;
                    }

                    $course_budget->rate = $value['rate'];
                    $course_budget->unit = $value['unit'];
                    $course_budget->qty = $value['qty'];
                    $course_budget->total_cost = $value['total_cost'];
                    $course_budget->comment = null;
                    $course_budget->save();
                }
            }
            DB::commit();
        } catch (\Exception $e) {
            DB::rollback();
            throw $e;
        }
        $notification = array(
            'toaster-message' => 'Course updated successfully',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }

    public function show(Course $course)
    {

        abort_if(Gate::denies('course_show', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');


        $approval_users = User::with("roles")->whereHas("roles", function ($q) {
            $q->where("title", "MDS")->orWhere('title', 'Rector');
        })->get();
        $users = $approval_users->map(function ($user) {
            $newuser['role']              = $user->roles['0']['title'];
            $newuser['name']              = $user->name;
            $newuser['designation']       = $user->designation;
            $newuser['sign']              = $user->sign;
            return $newuser;
        })->toArray();

        $course->load('nomination', 'created_by', 'courseLessons', 'courseContents', 'courseBudgets', 'courseAssociateOfficers');

        return view('admin.courses.show', compact('course', 'users'));
    }

    public function destroy(Course $course)
    {

        abort_if(Gate::denies('course_delete', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (request()->ajax()) {
            $course->delete();
            $output = [
                'success' => true,
                'msg' => 'Course has been deleted'
            ];
            return $output;
        }

        return back();
    }

    public function massDestroy(MassDestroyCourseRequest $request)
    {
        Course::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {
        //abort_if(Gate::denies('course_create') && Gate::denies('course_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $model         = new Course();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }

    public function addLesson(Course $course)
    {

        abort_if(Gate::denies('lesson_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        // $resource_people = Trainer::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $lessons = Lesson::with('resource_person')->where('course_id', $course->id)->orderBy('date', 'ASC')->get()->groupBy(function ($val) {
            return Carbon::parse($val->date)->format('Y-m-d');
        });

        return view('admin.lessons.create', compact('course', 'lessons'));
    }
    // VIEW LESSON 
    public function viewLesson(Course $course)
    {
        ini_set('memory_limit', '164M');

        //abort_if(Gate::denies('course_view_lesson', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $lessons = Lesson::with('resource_person')->where('course_id', $course->id)->orderBy('id', 'ASC')->paginate(10);

        return view('admin.lessons.view', compact('lessons', 'course'));
    }


    public function examModule(Course $course)
    {
        $course_setting = $course->settings;
        $quize_mark = $course->quizes->sum('quiz_mark');
        $presentation_number = $course->coursePresentation->count();
        //$presentation_total_mark= $presentation_number *  $course_setting->default_presentation_mark;
        $assignement_number = $course->courseAssignmentFile->count();

        //$assignement_total_mark= $assignement_number *  $course_setting->default_assignment_mark;
        $exam_modules = $course->courseExamModule->groupBy('module');

        return view('admin.courses.examModule', compact('course', 'exam_modules', 'quize_mark'));
    }


    public function getLesson(Request $request, Course $course)
    {
        if ($request->ajax()) {
            abort_if(Gate::denies('lesson_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
            $lessons = Lesson::with('resource_person')->where('course_id', $course->id)->orderBy('date', 'ASC')->get()->groupBy(function ($val) {
                return Carbon::parse($val->date)->format('Y-m-d');
            });

            return view('admin.lessons.lesson_table', compact('lessons'));
        }
        $lessons = Lesson::with('resource_person')->where('course_id', $course->id)->orderBy('date', 'ASC')->get()->groupBy(function ($val) {
            return Carbon::parse($val->date)->format('Y-m-d');
        });
        return view('admin.lessons.viewLessons', compact('lessons', 'course'));
    }

    public function approveCourse(Course $course)
    {
        if ($course->mds_approval == null) {
            $course->mds_approval = 1;
            $course->mds_comment = request()->comment;
        } elseif ($course->rector_approval == null) {
            $course->rector_approval = 1;
            $course->is_approved = 1;
            $course->rector_comments = request()->comment;
        }

        $course->save();

        $notification = array(
            'toaster-message' => 'Course Approved successfuly',
            'alert-type' => 'success'
        );

        return redirect()->route('courses.all')->with($notification);
    }

    public function viewAssignments(Course $course)
    {
        $single_assingments = AssignmentFile::where('course_id', $course->id)->where('group_id', null)
            ->with(['assignmentSubmissions', 'user'])->get();

        $group_assingments = AssignmentFile::where('course_id', $course->id)->whereNotNull('group_id')
            ->with(['assignmentSubmissions', 'user', 'group'])->get();

        return view('assignment.view-all', compact('single_assingments', 'group_assingments'));
    }
    // VIEW PRESENTATION 
    public function viewPresentations(Course $course)
    {
        $single_presentations = PresentationFile::where('course_id', $course->id)->where('group_id', null)
            ->with(['user'])->get();

        $group_presentations = PresentationFile::where('course_id', $course->id)->whereNotNull('group_id')
            ->with(['user', 'group'])->get();

        return view('presentation.view-all', compact('single_presentations', 'group_presentations'));
    }

    public function viewEvaluationForm(Course $course)
    {
        return view('admin.courses.evaluation', compact('course'));
    }

    public function saveEvaluationForm(Request $request)
    {
        $request->user()->course_evaluation()->create($request->all());

        $notification = array(
            'toaster-message' => 'Evaluation submitted successfuly',
            'alert-type' => 'success'
        );

        return redirect()->route('courses.all')->with($notification);
    }


    //create assignment gourp
    public function createAssignmentGroup(Course $course)
    {
        $nomination = $course->nomination;
        $assignment_groups = AssignmentGroup::where('course_id', $course->id)->get();
        $trainee = NominatedTrainee::with('user')->where('nomination_id', $nomination->id)->whereApprove(1)->get();
        return view('assignment.group.create', compact('trainee', 'course', 'assignment_groups'));
    }
    //create presentation gourp
    public function createPresentationGroup(Course $course)
    {
        $nomination = $course->nomination;
        $assignment_groups = PresentationGroup::where('course_id', $course->id)->get();
        $trainee = NominatedTrainee::with('user')->where('nomination_id', $nomination->id)->whereApprove(1)->get();
        return view('presentation.group.create', compact('trainee', 'course', 'assignment_groups'));
    }
    //store assignment group
    public function storeAssignmentGroup(Request $request)
    {
        if ($request->has('group_id')) {
            $this->updateAssignmentGroup($request);
            $notification = array(
                'toaster-message' => 'Assignment group updated successfuly',
                'alert-type' => 'success'
            );

            return redirect()->back()->with($notification);
        }
        $request['created_by'] = auth()->user()->id;
        AssignmentGroup::create($request->all());
        $notification = array(
            'toaster-message' => 'Assignment group created successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }
    //store presentation group
    public function storePresentationGroup(Request $request)
    {
        // dd($request->all());
        if ($request->has('group_id')) {
            $this->updatePresentationGroup($request);
            $notification = array(
                'toaster-message' => 'Presentation group updated successfuly',
                'alert-type' => 'success'
            );

            return redirect()->back()->with($notification);
        }
        $request['created_by'] = auth()->user()->id;
        $presentationGroup = PresentationGroup::create($request->all());

        if ($presentationGroup->id) {

            $file = new PresentationFile();
            $file->name = $request->group_name;
            $file->group_id = $presentationGroup->id;
            $file->course_id = $request->course_id;
            $file->exam_module_id = $request->exam_module_id;
            $file->user_id = $request->user_id;
            $file->presentation_date = $request->presentation_date;
            $file->created_by = auth()->user()->id;
            $file->save();
        }

        $notification = array(
            'toaster-message' => 'Presentation group created successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }

    public function deleteAssignmentGroup(Request $request)
    {
        $assignment_group = AssignmentGroup::findOrFail($request->group_id);
        $assignment_group->delete();
        $notification = array(
            'toaster-message' => 'Assignment group deleted successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }

    public function deletePresentationGroup(Request $request)
    {
        $presentation_group = PresentationGroup::findOrFail($request->group_id);
        $presentation_group->delete();
        $notification = array(
            'toaster-message' => 'Presentation group deleted successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }
    //view assignment gourp
    public function viewAssignmentGroup(Course $course)
    {
        // $nomination = $course->nomination;
        $viewAssignment = $course->with('courseAssignmentGroup', 'courseAssignmentFile.assignmentSubmissions')->where('id', $course->id)->first();
        // $files = AssignmentFile::where('course_id', $course->id)->get();
        // dd($viewAssignment);
        return view('assignment.group.view', compact('viewAssignment'));
    }
    //update assignment gourp
    public function updateAssignmentGroup(Request $request)
    {
        $assignmentGroup = AssignmentGroup::findOrFail($request->group_id);
        $assignmentGroup->group_name = $request->group_name;
        $assignmentGroup->save();
        $notification = array(
            'toaster-message' => 'Assignment group updated successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }
    //update presentation group

    public function updatePresentationGroup(Request $request)
    {
        $assignmentGroup = PresentationGroup::findOrFail($request->group_id);
        $assignmentGroup->group_name = $request->group_name;
        $assignmentGroup->save();
        $notification = array(
            'toaster-message' => 'Presentation group updated successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }
    //view presentation gourp
    public function viewPresentationGroup(Course $course)
    {
        $nomination = $course->nomination;
        $presentation_files = PresentationFile::with(['course', 'presentationGroup'])->where('course_id', $course->id)->get();
        // $files = PresentationFile::where('course_id', $course->id)->get();
        return view('presentation.group.view', compact('presentation_files'));
    }

    //save assignment grpup file

    public function saveAssignmentFileForGroup(Request $request)
    {
        $request->validate([
            'assignment' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
        ]);
        $fileName = time() . '.' . $request->assignment->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->assignment->move(public_path('upload/files'), $fileName);
        //save assignment file
        $file = new AssignmentFile();
        $file->name = $request->name;
        $file->group_id = $request->group_id;
        $file->exam_module_id = $request->exam_module_id;
        $file->course_id = $request->course_id;
        $file->user_id = $request->user_id;
        $file->submission_last_date = $request->submission_last_date;
        $file->file = $fileName;
        $file->created_by = auth()->user()->id;
        $file->save();

        return redirect()->back();
    }
    // save presentation for group
    public function savePresentationForGroup(Request $request)
    {
        //save Presentation file
        $file = new PresentationFile();
        $file->name = $request->name;
        $file->group_id = $request->group_id;
        $file->course_id = $request->course_id;
        $file->exam_module_id = $request->exam_module_id;
        $file->user_id = $request->user_id;
        $file->presentation_date = $request->presentation_date;
        $file->created_by = auth()->user()->id;
        $file->save();

        return redirect()->back();
    }

    public function addMarks(Request $request, Course $course)
    {
        $exam_module = $request->exam_module;
        $module = ExamModule::findOrFail($exam_module);
        $course_id = $course->id;
        $query = NominatedTrainee::leftJoin('exam_marks', function ($join) use ($exam_module) {
            $join->on('exam_marks.trainee_id', '=', 'nominated_trainees.user_id');
            $join->where('exam_marks.exam_module_id', '=', $exam_module);
        })
            ->join('users', 'users.id', '=', 'nominated_trainees.user_id')
            ->join('designations', 'designations.id', '=', 'users.designation')
            ->where('nominated_trainees.nomination_id', $course->nomination_id)
            ->where('nominated_trainees.approve', 1);

        if ($module->exam_type == 'individual assignment') {
            $query->leftJoin('assignment_files', 'assignment_files.user_id', '=', 'users.id')
                ->whereNotNull('assignment_files.user_id')
                ->where('assignment_files.exam_module_id', $exam_module)
                ->select('assignment_files.user_id');
        }

        if ($module->exam_type == 'assignment') {
            $query->leftJoin('courses', 'courses.nomination_id', '=', 'nominated_trainees.nomination_id')
                ->leftJoin('assignment_groups', function ($join) use ($course_id) {
                    $join->on('assignment_groups.course_id', '=', 'courses.id');
                    $join->where('assignment_groups.course_id', '=', $course_id);
                })->select('assignment_groups.id', 'assignment_groups.user_id', 'assignment_groups.group_name');
        }

        $query->select('users.name', 'designations.name as designation_name', 'users.id as users_id', 'nominated_trainees.user_id', 'exam_marks.id as marks_id', 'exam_marks.trainee_id', 'exam_marks.marks');

        $users = $query->get();
        return view('admin.courses.addMarks', compact('course', 'users', 'module'));
    }
    //save assignment single file

    public function saveAssignmentFileForSingle(Request $request)
    {

        $request->validate([
            'assignment' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
        ]);
        $fileName = time() . '.' . $request->assignment->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->assignment->move(public_path('upload/files'), $fileName);
        //save assignment file
        foreach ($request->user_id as $userId) {
            $file = new AssignmentFile();
            $file->name = $request->name;
            $file->course_id = $request->course_id;
            $file->exam_module_id = $request->exam_module_id;
            $file->user_id = $userId;
            $file->submission_last_date = $request->submission_last_date;
            $file->file = $fileName;
            $file->created_by = auth()->user()->id;
            $file->save();
        }


        return redirect()->back();
    }
    // save single presentation
    public function savePresentationForSingle(Request $request)
    {
        //save prersentation file
        foreach ($request->user_id as $userId) {
            $file = new PresentationFile();
            $file->name = $request->name;
            $file->course_id = $request->course_id;
            $file->user_id = $userId;
            $file->presentation_date = $request->presentation_date;
            $file->created_by = auth()->user()->id;
            $file->save();
        }


        return redirect()->back();
    }
    //view all assigned lessons 
    public function approveOrDenyCourseByTrainer(Course $course, Request $request)
    {

        abort_if(Gate::denies('approve_lesson', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if (request()->ajax()) {
            $tr_approve = TrainerApproval::where('course_id', $course->id)->where('user_id', auth()->user()->id)->first();
            $tr_approve->course_id = $course->id;
            $tr_approve->user_id = auth()->user()->id;
            $tr_approve->approved = $request->approved;
            $tr_approve->save();

            $output = [
                'success' => true,
                'msg' => 'Request successfully submitted'
            ];
            return $output;
        }
    }

    // SINGLE ASSIGNMENT
    public function getMyAssignment($id)
    {
        $assignments = AssignmentFile::with('assignmentSubmissions')->where('user_id', auth()->user()->id)->where('course_id', $id)->get();
        return response()->json(array(
            'assignments' => $assignments
        ));
    }
    // SINGLE ASSIGNMENT SUBMISSION 
    public function storeAssignmentSubmission(Request $request)
    {

        $request->validate([
            'file' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
        ]);
        $fileName = time() . '.' . $request->file->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->file->move(public_path('upload/files'), $fileName);
        //save assignment file
        $file = new AssignmentSubmission();
        $file->user_id = auth()->user()->id;
        $file->assignment_file_id = $request->assignment_file_id;
        $file->file = $fileName;
        $file->created_by = auth()->user()->id;
        $file->save();

        return redirect()->back();
    }
    // GROUP  ASSIGNMENT
    public function getGroupAssignment($id)
    {
        $assign_group = AssignmentGroup::where('course_id', $id)->whereJsonContains('user_id', strval(auth()->user()->id))->first();
        $groupassignments = AssignmentFile::with(['assignmentSubmissions'])->whereNotNull('group_id')->where('course_id', $id)->where('group_id', $assign_group->id)->get();
        return response()->json(array(
            'groupassignments' => $groupassignments
        ));
    }

    // GROUP  ASSIGNMENT
    public function getGroupPresentation($id)
    {
        $groupPresentation = PresentationGroup::with('presentationFile')->where('course_id', $id)->whereJsonContains('user_id', strval(auth()->user()->id))->get();

        return response()->json(array(
            'grouppresentation' => $groupPresentation
        ));
    }

    public function storePresentationSubmission(Request $request)
    {
        // dd($request->all());
        $request->validate([
            'file' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
        ]);
        $fileName = time() . '.' . $request->file->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->file->move(public_path('upload/files'), $fileName);
        //update Presentation file
        $file = PresentationFile::findOrFail($request->presentation_file_id);
        $file->user_id = auth()->user()->id;
        $file->file = $fileName;
        $file->save();

        $notification = array(
            'toaster-message' => 'Presentation file uploaded successfuly',
            'alert-type' => 'success'
        );

        return redirect()->back()->with($notification);
    }

    // COURSE WISE TRAINEE VIEW
    public function viewCourseTrainee($courseId)
    {
        $findCourse = Course::findOrFail($courseId);
        $users = NominatedTrainee::with('user')->where('nomination_id', $findCourse->nomination_id)->where('approve', 1)->get();
        return view('admin.courses.trainee-view', compact('findCourse', 'users'));
    }

    public function viewLessonLearningPoint($lessonid)
    {
        $data = User::leftJoin('nominated_trainees', 'nominated_trainees.user_id', 'users.id')
            ->leftJoin('courses', 'courses.nomination_id', 'nominated_trainees.nomination_id')
            ->leftJoin('lessons', 'lessons.course_id', 'courses.id')
            ->leftJoin('learning_points', 'learning_points.lesson_id', 'lessons.id')
            ->leftJoin('marks', function ($join) {
                $join->on('marks.markable_id', '=', 'learning_points.id');
                $join->where('marks.markable_type', 'App\Models\LearningPoint');
            })
            ->leftJoin('trainee_attendances', 'trainee_attendances.trainee_id', 'users.id')
            ->where('lessons.id', $lessonid)
            ->select('users.name as name', 'users.id as user_id', 'lessons.id as lesson_id', 'learning_points.id as learning_point_id', 'learning_points.learning_points as learning_point', 'learning_points.created_at as created_at', 'trainee_attendances.present as is_present', 'lessons.lesson_name as lesson_name', 'lessons.topic as lesson_topic', 'lessons.date as lesson_date', 'lessons.start_time as lesson_start_time', 'lessons.end_time as lesson_end_time', 'marks.mark as mark')
            ->get();

        return view('admin.lessons.learning_points', compact('data'));
    }
    // TRAINER EVALUATION 
    public function viewLessonEvaluation(Request $request, $lessonid)
    {
        $lesson = Lesson::with('resource_person')->find($lessonid);
        $evaluations = TrainerEvaluation::with(['lesson', 'user'])->where('lesson_id', $lessonid)->get();

        // if ($request->ajax()) {
        //     $evaluations = TrainerEvaluation::with(['lesson','user'])->where('lesson_id', $lessonid)->get();
        //     return Datatables::of($evaluations)
        //         ->addIndexColumn()
        //         ->addColumn('evaluation', function ($row) {
        //             $html = '<ol>
        //             <li>Theoretical Portion</li>
        //            <li>Citation of practical examples</li>
        //            <li>Describing the power sector relevance</li>
        //            <li>Capacity to make the topic understandable</li>
        //            <li>Language proficiency</li>
        //            <li>Capacity to increase trainees involvement</li>
        //            <li>Timeliness</li>
        //            <li>Capacity to involve multi disciplinary knowledge</li>
        //            <li>Capacity to answer the question</li>
        //            <li>Training materials</li>
        //            <li>Capacity to control the class</li>
        //            <li>Interaction with the trainees</li>
        //            <li>Overall training capacity</li>

        //        </ol>';
        //                 return $html;

        //         })
        //         ->addColumn('lesson', function($evaluations)
        //         {
        //            return $evaluations->lesson?$evaluations->lesson->resource_person->name:'';
        //         })
        //         ->addColumn('user', function($evaluations)
        //         {
        //            return $evaluations->user?$evaluations->user->name:'';
        //         })
        //         ->rawColumns(['evaluation','lesson','user'])
        //         ->make(true);
        // }
        // dd($lesson);
        return view('admin.lessons.evaluation', compact('lesson', 'evaluations'));
    }

    //  TRAINEE REMOVE FROM ASSIGNMENT GROUP 
    public function traineeRemove(Request $request)
    {
        $assignmentGroup = AssignmentGroup::findOrFail($request->group_id);
        $allTrainee = $assignmentGroup->user_id;
        $temp = [];
        foreach ($allTrainee as $itemkey => $item) {
            if ($item != $request->trainee_id) {
                $temp[] = $item;
            }
        }
        $assignmentGroup->update([
            'user_id' => $temp
        ]);
        $notification = array(
            'toaster-message' => 'Trainee remove from this group',
            'alert-type' => 'success'
        );
        return redirect()->back()->with($notification);
    }
    //  TRAINEE REMOVE FROM PRESENTATION GROUP 
    public function traineeRemovePresentation(Request $request)
    {
        $presentationGroup = PresentationGroup::findOrFail($request->group_id);
        $allTrainee = $presentationGroup->user_id;
        $temp = [];
        foreach ($allTrainee as $itemkey => $item) {
            if ($item != $request->trainee_id) {
                $temp[] = $item;
            }
        }
        $presentationGroup->update([
            'user_id' => $temp
        ]);
        $notification = array(
            'toaster-message' => 'Trainee remove from this group',
            'alert-type' => 'success'
        );
        return redirect()->back()->with($notification);
    }

    // TRAINEE APPROVED BY ADMIN
    public function joinCourse(Request $request)
    {

        $course_id = $request->course_id;
        $email = $request->email;

        $course = Course::findOrFail($course_id);

        $nomination_id = $course->nomination->id;


        $user = User::where('email', $email)->first();
        if (!$user) {
            throw ValidationException::withMessages([
                'user' => 'Sorry! User not found.',
            ]);
        }
        if ($user->organization_id == null) {
            throw ValidationException::withMessages([
                'user' => 'Sorry! We couldnt find your organization.',
            ]);
        }

        $nominated_trainee = new NominatedTrainee();
        $nominated_trainee->nomination_id = $nomination_id;
        $nominated_trainee->organization_id = $user->organization_id;
        $nominated_trainee->user_id = $user->id;
        $nominated_trainee->save();

        return redirect('/')->with('success', 'Course Enrolled Successfuly');
    }
    public function adjustmentSheet(Request $request)
    {
        $course = Course::findOrFail($request->courseId)->load('adjustment_sheet');
        return view("admin.courses.adjustmentsheet", compact("course"));
    }

    public function adjustmentSheetUpload(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
            'course_id' => 'required',
        ]);

        $fileName = time() . '.' . $request->file->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->file->move(public_path('upload/files'), $fileName);
        //save assignment file

        $adjustment_sheet['title'] = $request->title;
        $adjustment_sheet['file'] = $fileName;
        $adjustment_sheet['course_id'] = $request->course_id;
        $adjustment_sheet['created_by'] =  auth()->user()->id;

        DB::table('adjustment_sheets')->insert($adjustment_sheet);

        return redirect()->back()->with('success', 'File uploaded Successfuly');
    }
}
