<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCourseInitiationRequest;
use App\Http\Requests\StoreCourseInitiationRequest;
use App\Models\Batch;
use App\Models\CourseInitiation;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Models\CourseRole;
use App\Models\Role;
use Illuminate\Support\Facades\Auth;

class CourseInitiationController extends Controller
{


    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('course_initiation_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $ci = CourseInitiation::with('course')->latest()->get();
        return view('admin.courseInitiation.index', compact('ci'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $batches = Batch::get();
        return view('admin.courseInitiation.create', compact('batches'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreCourseInitiationRequest $request)
    {
        $cr = new CourseRole();
        $role = new Role();
        $cr->user_id = $request->course_director;
        $cr->role_id = $role->course_director()->id;
        $cr->save();
        $request['course_role_id'] = $cr->id;
        CourseInitiation::create($request->all());
        $notification = array(
            'toaster-message' => 'Course successfuly initiated',
            'alert-type' => 'success'
        );

        return redirect()->route('course-initiation.index')->with($notification);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\CourseInitiation  $courseInitiation
     * @return \Illuminate\Http\Response
     */
    public function show(CourseInitiation $courseInitiation)
    {
        $courseInitiation = CourseInitiation::with(['batch', 'courseDirector'])->findOrFail($courseInitiation->id);

        return view('admin.courseInitiation.show', compact('courseInitiation'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\CourseInitiation  $courseInitiation
     * @return \Illuminate\Http\Response
     */
    public function edit(CourseInitiation $courseInitiation)
    {

        $batches = Batch::get();
        return view('admin.courseInitiation.edit', compact('courseInitiation', 'batches'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\CourseInitiation  $courseInitiation
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, CourseInitiation $courseInitiation)
    {
        $courseInitiation->update($request->all());
        $notification = array(
            'toaster-message' => 'Course intiation successfuly updated',
            'alert-type' => 'success'
        );

        return redirect()->route('course-initiation.index')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\CourseInitiation  $courseInitiation
     * @return \Illuminate\Http\Response
     */
    public function destroy(CourseInitiation $courseInitiation)
    {
        $courseInitiation->delete();

        $notification = array(
            'toaster-message' => 'Course intiation successfuly deleted',
            'alert-type' => 'success'
        );

        return redirect()->route('course-initiation.index')->with($notification);
    }

    public function massDestroy(MassDestroyCourseInitiationRequest $request)
    {
        CourseInitiation::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
