<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyCoursefeepaymentRequest;
use App\Http\Requests\StoreCoursefeepaymentRequest;
use App\Http\Requests\UpdateCoursefeepaymentRequest;
use App\Mail\MoneyReceiptMail;
use App\Models\Course;
use App\Models\Coursefeepayment;
use App\Models\CoursePayment;
use App\Models\Designation;
use App\Models\NominatedTrainee;
use App\Models\TraineeOrganization;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Support\Facades\DB;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Redirect;

class CoursefeepaymentController extends Controller
{
    use MediaUploadingTrait;

    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }


    public function index()
    {
        abort_if(Gate::denies('coursefeepayment_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $role = auth()->user()->roles->first()->title;
        if ($role == 'Trainee') {
            $coursefeepayments = Coursefeepayment::with(['user', 'media'])->where('user_id', auth()->user()->id)->get();
            return view('admin.coursefeepayments.index', compact('coursefeepayments'));
        } else if ($role == 'Organization') {
            $coursefeepayments = Coursefeepayment::with(['user', 'media'])->where('user_id', auth()->user()->id)->get();
            return view('admin.coursefeepayments.org-index', compact('coursefeepayments'));
        }
    }

    public function create()
    {
        abort_if(Gate::denies('coursefeepayment_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        $role = auth()->user()->roles->first()->title;
        if ($role == 'Trainee') {
            $traineeorganizations = TraineeOrganization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

            $courses = Course::join('nominations', 'nominations.id', '=', 'courses.nomination_id')
                ->join('nominated_trainees', 'nominated_trainees.nomination_id', '=', 'nominations.id')
                ->where('nominated_trainees.user_id', '=', auth()->user()->id)
                ->where('nominated_trainees.approve', '=', 1)
                ->select('courses.*')
                ->get();
            $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
            return view('admin.coursefeepayments.create', compact('traineeorganizations', 'users', 'courses'));
        } else if ($role == 'Organization') {

            $courses = Course::join('nominations', 'nominations.id', '=', 'courses.nomination_id')
                ->join('nominated_trainees', 'nominated_trainees.nomination_id', '=', 'nominations.id')
                ->where('nominated_trainees.organization_id', '=', auth()->user()->organization_id)
                ->where('nominated_trainees.approve', '=', 1)
                ->select('courses.*')
                ->groupBy('nominated_trainees.nomination_id')
                ->get();

            // dd($courses);

            return view('admin.coursefeepayments.org-create', compact('courses'));
        }
    }

    public function store(StoreCoursefeepaymentRequest $request)
    {

        $coursefeepayment = Coursefeepayment::create($request->all());

        if ($request->input('image_cheque', false)) {
            $coursefeepayment->addMedia(storage_path('tmp/uploads/' . basename($request->input('image_cheque'))))->toMediaCollection('image_cheque');
        }

        if ($request->input('image_submit_slip', false)) {
            $coursefeepayment->addMedia(storage_path('tmp/uploads/' . basename($request->input('image_submit_slip'))))->toMediaCollection('image_submit_slip');
        }

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $coursefeepayment->id]);
        }

        return redirect()->route('coursefeepayments.index');
    }

    public function edit(Coursefeepayment $coursefeepayment)
    {
        abort_if(Gate::denies('coursefeepayment_edit', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $designations = Designation::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $traineeorganizations = TraineeOrganization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $coursefeepayment->load('designation', 'traineeorganization', 'user');

        return view('admin.coursefeepayments.edit', compact('coursefeepayment', 'designations', 'traineeorganizations'));
    }

    public function update(UpdateCoursefeepaymentRequest $request, Coursefeepayment $coursefeepayment)
    {
        $coursefeepayment->update($request->all());

        if ($request->input('image_cheque', false)) {
            if (!$coursefeepayment->image_cheque || $request->input('image_cheque') !== $coursefeepayment->image_cheque->file_name) {
                if ($coursefeepayment->image_cheque) {
                    $coursefeepayment->image_cheque->delete();
                }
                $coursefeepayment->addMedia(storage_path('tmp/uploads/' . basename($request->input('image_cheque'))))->toMediaCollection('image_cheque');
            }
        } elseif ($coursefeepayment->image_cheque) {
            $coursefeepayment->image_cheque->delete();
        }

        if ($request->input('image_submit_slip', false)) {
            if (!$coursefeepayment->image_submit_slip || $request->input('image_submit_slip') !== $coursefeepayment->image_submit_slip->file_name) {
                if ($coursefeepayment->image_submit_slip) {
                    $coursefeepayment->image_submit_slip->delete();
                }
                $coursefeepayment->addMedia(storage_path('tmp/uploads/' . basename($request->input('image_submit_slip'))))->toMediaCollection('image_submit_slip');
            }
        } elseif ($coursefeepayment->image_submit_slip) {
            $coursefeepayment->image_submit_slip->delete();
        }

        return redirect()->route('coursefeepayments.index');
    }

    public function show(Coursefeepayment $coursefeepayment)
    {
        abort_if(Gate::denies('coursefeepayment_show', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $coursefeepayment->load(['user' => function ($query) {
            $query->with(['traineeInfo' => function ($query2) {
                $query2->with('user_designation', 'organization');
            }]);
        }]);

        return view('admin.coursefeepayments.show', compact('coursefeepayment'));
    }

    public function destroy(Coursefeepayment $coursefeepayment)
    {
        abort_if(Gate::denies('coursefeepayment_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $coursefeepayment->delete();

        return back();
    }

    public function massDestroy(MassDestroyCoursefeepaymentRequest $request)
    {
        Coursefeepayment::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {

        $model         = new Coursefeepayment();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
    // COURSE PAYMENT LIST
    public function list()
    {
        $authid = strval(auth()->user()->id);

        $course = Course::whereJsonContains('course_director', $authid)->with(['payment' => function ($q) {
            $q->with(['user', 'media']);
        }])->get();


        // $coursefeepayments = Coursefeepayment::with(['course'=>function($q) use($authid){
        //     $q->whereJsonContains('course_director', $authid);
        // },'designation', 'traineeorganization', 'user', 'media'])->get();
        //dd($course);
        return view('admin.coursepayments.index', compact('course'));
    }
    public function showCoursePayment($id)
    {

        $coursePayment = Coursefeepayment::find($id);

        // if ($coursePayment->traineeorganization_id == NULL) {

        //     $orgUser = User::findOrFail($coursePayment->user_id);
        //     $course = Course::findOrFail($coursePayment->course_id);
        //     $trainees = NominatedTrainee::with('user')->where('nomination_id', $course->nomination_id)->where('organization_id', $orgUser->organization_id)->where('approve', 1)->get();
        //     return view('admin.coursepayments.showOrg', compact('coursePayment', 'trainees'));
        // } 
        $coursePayment->load(['user' => function ($query) {
            $query->with(['traineeInfo' => function ($query2) {
                $query2->with('user_designation', 'organization');
            }]);
        }]);



        return view('admin.coursepayments.show', compact('coursePayment'));
    }
    // COURSE PAYMENT APPROVE 
    public function approveCoursePayment($id)
    {

        DB::beginTransaction();
        try {
            $courserfeePayment = Coursefeepayment::findOrFail($id);
            $courserfeePayment->update([
                'approve' => 1
            ]);

            $coursePayment = new CoursePayment();
            $coursePayment->course_id = $courserfeePayment->course_id;
            $coursePayment->user_id = $courserfeePayment->user_id;
            $coursePayment->status = 1;
            $coursePayment->save();

            DB::commit();
            $notification = array(
                'toaster-message' => 'Course Payment Approved successfuly',
                'alert-type' => 'success'
            );

            return redirect()->back()->with($notification);
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
    }
    // COURSE PAYMENT APPROVE FOR ORG
    public function approveCoursePaymentOrg(Request $request)
    {
        DB::beginTransaction();
        try {
            Coursefeepayment::findOrFail($request->coursePaymentId)->update([
                'approve' => 1
            ]);

            foreach ($request->trainess as $traineeId) {
                $coursePayment = new CoursePayment();
                $coursePayment->course_id = $request->course_id;
                $coursePayment->user_id = $traineeId;
                $coursePayment->status = 1;
                $coursePayment->save();
            }
            DB::commit();
            $notification = array(
                'toaster-message' => 'Course Payment Approved successfuly',
                'alert-type' => 'success'
            );
            return redirect()->route('coursepayment')->with($notification);
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
    }
    public function moneyReceipt($id)
    {
        return view('admin.coursepayments.money-receipt');
    }
    // MONEY RECEIPT DATA
    public function getMoneyReceiptData($id)
    {
        $courseFeePayment = Coursefeepayment::with('user')->findOrFail($id);
        return response()->json(array(
            'courseFeePayment' => $courseFeePayment
        ));
    }
    // MONEY RECEIPT FORWARD TO MAIL
    public function moneyReceiptMail(Request $request)
    {
        DB::beginTransaction();
        try {
            $coursefeepayment = Coursefeepayment::findOrFail($request->courseFeePaymentId);
            $user = User::findOrFail($coursefeepayment->user_id);
            // ===== START SEND MONEY RECEIPT EMAIL =================

            Mail::to($user->email)->send(new MoneyReceiptMail($coursefeepayment));
            // ===== END SEND MONEY RECEIPT EMAIL =================
            DB::commit();
            $notification = array(
                'toaster-message' => 'Send mail successfuly',
                'alert-type' => 'success'
            );
            return redirect()->back()->with($notification);
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
    }
}
