<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyDesignationRequest;
use App\Http\Requests\StoreDesignationRequest;
use App\Http\Requests\UpdateDesignationRequest;
use App\Models\Designation;
use Gate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Symfony\Component\HttpFoundation\Response;

class DesignationController extends Controller
{

    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('designation_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $designations = Designation::all();

        return view('admin.designations.index', compact('designations'));
    }

    public function create()
    {
        abort_if(Gate::denies('designation_create' ,$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.designations.create');
    }

    public function store(StoreDesignationRequest $request)
    {
        $designation = Designation::create($request->all());

        return redirect()->route('designations.index');
    }

    public function edit(Designation $designation)
    {
        abort_if(Gate::denies('designation_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.designations.edit', compact('designation'));
    }

    public function update(UpdateDesignationRequest $request, Designation $designation)
    {
        $designation->update($request->all());

        return redirect()->route('designations.index');
    }

    public function show(Designation $designation)
    {
        abort_if(Gate::denies('designation_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.designations.show', compact('designation'));
    }

    public function destroy(Designation $designation)
    {
        abort_if(Gate::denies('designation_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $designation->delete();

        return back();
    }

    public function massDestroy(MassDestroyDesignationRequest $request)
    {
        Designation::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
