<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Middleware\TrainingInfo;
use App\Models\CourseRole;
use App\Models\NominatedTrainee;
use Gate;
use Illuminate\Support\Facades\Auth;

class HomeController extends Controller
{
    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }


    public function index()
    {
        $year = [];
        $passed = [];
        $enrollees = [];
        $course_taken = 0;
        $total_trainee_approve = 0;

        if (Gate::allows('dashboard_report', $this->courseRole)) {
            $year = ['2015', '2016', '2017', '2018', '2019', '2020', '2021', '2022'];
            $enrollees = ['456', '560', '789', '490', '345', '947', '1020', '700'];
            $passed = ['400', '545', '700', '480', '340', '900', '890', '0'];
        }

        if (Gate::allows('trainer_evaluation', $this->courseRole)) {
            $course_taken = NominatedTrainee::where('user_id', auth()->user()->id)->where('approve', 1)->count();
        }
        if (Gate::allows('nomination_list', $this->courseRole) && auth()->user()->roles()->first()->title != 'Admin') {
            $user_org = auth()->user()->organization;
            // dd(NominatedTrainee::where('organization_id', $user_org->id)->where('approve', 1));
            $total_trainee_approve = NominatedTrainee::where('organization_id', $user_org->id)->where('approve', 1)->count();
        }
        return view('home')->with('year', json_encode($year, JSON_NUMERIC_CHECK))->with('passed', json_encode($passed, JSON_NUMERIC_CHECK))->with('course_taken', $course_taken)->with('total_trainee_approve', $total_trainee_approve);
    }
}
