<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Course;
use App\Models\Module;
use App\Models\Topic;
use Illuminate\Http\Request;

class ModuleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $modules=Module::get();
        return view('admin.module.index',compact('modules'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $courses = Course::where('is_approved', 1)->latest()->get();
        return view('admin.module.create',compact('courses'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //dd($request->all());
        $module=new Module();
        $module->name= $request->name;
        $module->course_id = $request->course_id;
        $module->created_by= auth()->user()->id;
        $module->updated_by= auth()->user()->id;
        $module->save();

        if($request->has('topics'))
        {
           $module->topics= $request->topics;
           $module->save();
        }
        $notification = array(
            'toaster-message' => 'Module added Successfully!',
            'alert-type' => 'success'
        );
        return redirect()->route('module.index')->with($notification);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Module  $module
     * @return \Illuminate\Http\Response
     */
    public function show(Module $module)
    {
        return view('admin.module.show',compact('module'));
        
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Module  $module
     * @return \Illuminate\Http\Response
     */
    public function edit(Module $module)
    {
        $courses=Course::latest()->get();
        $module=$module->load('course');
        return view('admin.module.edit',compact('courses','module'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Module  $module
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Module $module)
    {
        
        if($request->has('name'))
        {
            $module->name= $request->name;
        }
        if($request->has('course_id'))
        {
            $module->course_id= $request->course_id;
        }
         $module->updated_by= auth()->user()->id;
         
         $module->save();
 
         if($request->has('topics'))
         {
            $module->topics= $request->topics;
            $module->save();
         }
         $notification = array(
             'toaster-message' => 'Module updated Successfully!',
             'alert-type' => 'success'
         );
         return redirect()->route('module.index')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Module  $module
     * @return \Illuminate\Http\Response
     */
    public function destroy(Module $module)
    {
        $module->delete();
        $notification = array(
            'toaster-message' => 'Module deleted Successfully!',
            'alert-type' => 'success'
        );
        return redirect()->route('module.index')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Module  $module
     * @return \Illuminate\Http\Response
     */
    public function deleteTopic(Topic $topic)
    {
       $topic->delete();
    
       $notification = array(
            'toaster-message' => 'Topic deleted Successfully!',
            'alert-type' => 'success'
        );
        return redirect()->back()->with($notification);
    }

    
}
