<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyNominatedOrganisationRequest;
use App\Http\Requests\StoreNominatedOrganisationRequest;
use App\Http\Requests\UpdateNominatedOrganisationRequest;
use App\Jobs\NominationMailJob;
use App\Mail\NominationMail;
use App\Models\NominatedOrganisation;
use App\Models\Nomination;
use App\Models\Organization;
use Gate;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Mail;

class NominatedOrganisationController extends Controller
{

    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('nominated_organisation_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedOrganisations = NominatedOrganisation::with(['nomination', 'organization'])->get();

        return view('admin.nominatedOrganisations.index', compact('nominatedOrganisations'));
    }

    public function create($nomination_id)
    {
        abort_if(Gate::denies('nominated_organisation_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominations = Nomination::where('id', $nomination_id)->first();
        // $nominations = Nomination::where('id', $nomination_id)->pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');
        $exitsNominatedOrganization = NominatedOrganisation::with('nomination', 'organization')->where('nomination_id', $nomination_id)->get();
        // return json_encode($exitsNominatedOrganization);

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.nominatedOrganisations.create', compact('nominations', 'organizations', 'exitsNominatedOrganization', 'nomination_id'));
    }

    public function store(StoreNominatedOrganisationRequest $request)
    {
       
        $ifExit = NominatedOrganisation::where('nomination_id', $request->nomination_id)->where('organization_id', $request->organization_id)->first();
        if ($ifExit) {
            return response()->json(['error' => 'Multiple not allowed']);
        } else {
            $nominatedOrganisation = NominatedOrganisation::create($request->all());
            $findOrganization = Organization::where('id', $request->organization_id)->first();
            $details['email'] = $findOrganization->email;
            // ===== START SEND NOMINATION EMAIL =================
            dispatch(new NominationMailJob($details));
            //Mail::to($findOrganization->email)->send(new NominationMail());

            // ===== END SEND NOMINATION EMAIL =================
            $data = NominatedOrganisation::with('nomination', 'organization')->where('nomination_id', $request->nomination_id)->get();
            return response()->json('success');
        }

        // return redirect()->route('nominated-organisations.index');
    }

    public function edit(NominatedOrganisation $nominatedOrganisation)
    {
        abort_if(Gate::denies('nominated_organisation_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominations = Nomination::pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $nominatedOrganisation->load('nomination', 'organization');

        return view('admin.nominatedOrganisations.edit', compact('nominatedOrganisation', 'nominations', 'organizations'));
    }

    public function update(UpdateNominatedOrganisationRequest $request, NominatedOrganisation $nominatedOrganisation)
    {
        $nominatedOrganisation->update($request->all());

        return redirect()->route('nominated-organisations.index');
    }

    public function show(NominatedOrganisation $nominatedOrganisation)
    {
        abort_if(Gate::denies('nominated_organisation_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedOrganisation->load('nomination', 'organization');

        return view('admin.nominatedOrganisations.show', compact('nominatedOrganisation'));
    }

    public function destroy(NominatedOrganisation $nominatedOrganisation)
    {
        abort_if(Gate::denies('nominated_organisation_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedOrganisation->delete();
      

        return back();
    }
    public function nominatedOrgRemove($id)
    {
        $findNominatedOrg = NominatedOrganisation::findOrFail($id);
        $findNominatedOrg->delete();
        return response()->json(['success' => 'Successfully remove']);
    }

    public function massDestroy(MassDestroyNominatedOrganisationRequest $request)
    {
        NominatedOrganisation::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    // NOMINATION WISE ORGANIZATION
    public function nominationWiseOrganization($nomination_id)
    {
        $exitsNominatedOrganization = NominatedOrganisation::with('nomination', 'organization')->where('nomination_id', $nomination_id)->get();
        return json_encode($exitsNominatedOrganization);
    }
    public function getNomination($nomination_id)
    {
        $data = NominatedOrganisation::with('nomination', 'organization')->where('nomination_id', $nomination_id)->get();
        return json_encode($data);
    }
}
