<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyNominatedTraineeRequest;
use App\Http\Requests\StoreNominatedTraineeRequest;
use App\Http\Requests\UpdateNominatedTraineeRequest;
use App\Models\NominatedTrainee;
use App\Models\Nomination;
use App\Models\Organization;
use App\Models\User;
use Gate;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class NominatedTraineeController extends Controller
{

    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }


    public function index()
    {
        abort_if(Gate::denies('nominated_trainee_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedTrainees = NominatedTrainee::with(['nomination', 'organization', 'user'])->get();

        return view('admin.nominatedTrainees.index', compact('nominatedTrainees'));
    }

    public function create()
    {
        abort_if(Gate::denies('nominated_trainee_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominations = Nomination::pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.nominatedTrainees.create', compact('nominations', 'organizations', 'users'));
    }

    public function store(StoreNominatedTraineeRequest $request)
    {
        $nominatedTrainee = NominatedTrainee::create($request->all());

        return redirect()->route('nominated-trainees.index');
    }

    public function edit(NominatedTrainee $nominatedTrainee)
    {
        abort_if(Gate::denies('nominated_trainee_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominations = Nomination::pluck('course_title', 'id')->prepend(trans('global.pleaseSelect'), '');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $nominatedTrainee->load('nomination', 'organization', 'user');

        return view('admin.nominatedTrainees.edit', compact('nominatedTrainee', 'nominations', 'organizations', 'users'));
    }

    public function update(UpdateNominatedTraineeRequest $request, NominatedTrainee $nominatedTrainee)
    {
        $nominatedTrainee->update($request->all());

        return redirect()->route('nominated-trainees.index');
    }

    public function show(NominatedTrainee $nominatedTrainee)
    {
        abort_if(Gate::denies('nominated_trainee_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedTrainee->load('nomination', 'organization', 'user');

        return view('admin.nominatedTrainees.show', compact('nominatedTrainee'));
    }

    public function destroy(NominatedTrainee $nominatedTrainee)
    {
        abort_if(Gate::denies('nominated_trainee_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedTrainee->delete();

        return back();
    }

    public function massDestroy(MassDestroyNominatedTraineeRequest $request)
    {
        NominatedTrainee::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
