<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Traits\MediaUploadingTrait;
use App\Http\Requests\MassDestroyTraineeInfoRequest;
use App\Http\Requests\StoreTraineeInfoRequest;
use App\Http\Requests\UpdateTraineeInfoRequest;
use App\Models\Designation;
use App\Models\Organization;
use App\Models\TraineeInfo;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Spatie\MediaLibrary\MediaCollections\Models\Media;
use Symfony\Component\HttpFoundation\Response;

class TraineeInfoController extends Controller
{
    use MediaUploadingTrait;

    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('trainee_info_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $traineeInfos = TraineeInfo::with(['organization', 'user'])->get();

        return view('admin.traineeInfos.index', compact('traineeInfos'));
    }

    public function create()
    {
        abort_if(Gate::denies('trainee_info_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');
        $designations = Designation::orderBy('name','asc')->get();
        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $traineeInfo = TraineeInfo::where('user_id',auth()->user()->id)->first();
        return view('admin.traineeInfos.create', compact('organizations', 'users','traineeInfo','designations'));
    }

    public function store(StoreTraineeInfoRequest $request)
    {
        $traineeInfo = TraineeInfo::create($request->all());

        if ($media = $request->input('ck-media', false)) {
            Media::whereIn('id', $media)->update(['model_id' => $traineeInfo->id]);
        }

        return redirect()->route('trainee-infos.create');
    }

    public function edit(TraineeInfo $traineeInfo)
    {
        abort_if(Gate::denies('trainee_info_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $users = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $traineeInfo->load('organization', 'user');

        return view('admin.traineeInfos.edit', compact('organizations', 'traineeInfo', 'users'));
    }
    public function getBranchByOrganization($id)
    {
        $branches = Branch::where('organizations_id',$id)->get();
        return response()->json($branches);
    }
    public function update(Request $request, TraineeInfo $traineeInfo)
    {
        if ($request->has('email'))
        {
            $traineeInfo->email = $request->email;

        }
        if ($request->has('name_english'))
        {
            $traineeInfo->name_english = $request->name_english;

        }
        if ($request->has('designation'))
        {
            $traineeInfo->designation = $request->designation;

        }
        if ($request->has('other_designation'))
        {
            $traineeInfo->other_designation = $request->other_designation;

        }
        if ($request->has('mobile_no'))
        {

            $traineeInfo->mobile_no = $request->mobile_no;
        }
        if ($request->has('gmail_address'))
        {
            $traineeInfo->gmail_address = $request->gmail_address;

        }
        if ($request->has('other_email_address'))
        {
            $traineeInfo->other_email_address = $request->other_email_address;

        }
        if ($request->has('name_bangla'))
        {
            $traineeInfo->name_bangla = $request->name_bangla;
        }
        if ($request->has('fathers_name'))
        {
            $traineeInfo->fathers_name = $request->fathers_name;
        }
        if ($request->has('mothers_name'))
        {
            $traineeInfo->mothers_name = $request->mothers_name;
        }
        if ($request->has('national_id_no'))
        {
            $traineeInfo->national_id_no = $request->national_id_no;
        }
        if ($request->has('present_address'))
        {
            $traineeInfo->present_address = $request->present_address;
        }
        if ($request->has('home_district'))
        {
            $traineeInfo->home_district = $request->home_district;
        }
        if ($request->has('permanent_address'))
        {
            $traineeInfo->permanent_address = $request->permanent_address;
        }
        if ($request->has('religion'))
        {
            $traineeInfo->religion = $request->religion;
        }
        if ($request->has('work_division'))
        {
            $traineeInfo->work_division = $request->work_division;
        }
        if ($request->has('office_name'))
        {
            $traineeInfo->office_name = $request->office_name;
        }
        if ($request->has('office_address'))
        {
            $traineeInfo->office_address = $request->office_address;
        }
        if ($request->has('organization_id_no'))
        {
            $traineeInfo->organization_id_no = $request->organization_id_no;
        }
        if ($request->has('entry_post'))
        {
            $traineeInfo->entry_post = $request->entry_post;
        }
        if ($request->has('present_job_description'))
        {
            $traineeInfo->present_job_description = $request->present_job_description;
        }
        if ($request->has('bank_account_name'))
        {
            $traineeInfo->bank_account_name = $request->bank_account_name;
        }
        if ($request->has('bank_name'))
        {
            $traineeInfo->bank_name = $request->bank_name;
        }
        if ($request->has('branch_name'))
        {
            $traineeInfo->branch_name = $request->branch_name;
        }
        if ($request->has('bank_account_no'))
        {
            $traineeInfo->bank_account_no = $request->bank_account_no;
        }
        if ($request->has('mobile_banking'))
        {
            $traineeInfo->mobile_banking = $request->mobile_banking;
        }
        if ($request->has('mobile_banking_no'))
        {
            $traineeInfo->mobile_banking_no = $request->mobile_banking_no;
        }
        if ($request->has('educational_qualification'))
        {
            $traineeInfo->educational_qualification = $request->educational_qualification;
        }
        if ($request->has('fields_of_interest'))
        {
            $traineeInfo->fields_of_interest = $request->fields_of_interest;
        }
        if ($request->has('additional_comment'))
        {
            $traineeInfo->additional_comment = $request->additional_comment;
        }
        if ($request->has('bpmi_bus_arrangements'))
        {
            $traineeInfo->bpmi_bus_arrangements = $request->bpmi_bus_arrangements;
        }

        if ($request->innovative_idea_select =='no')
        {
            $traineeInfo->innovative_idea = "no";
        }
        if ($request->innovative_idea_select =='yes')
        {
            $traineeInfo->innovative_idea = $request->innovative_idea;
        }
        if ($request->work_as_a_trainer_select =='no')
        {
            $traineeInfo->willing_to_work_as_a_trainer = "no";
        }
        if ($request->work_as_a_trainer_select =='yes')
        {
            $traineeInfo->willing_to_work_as_a_trainer = $request->willing_to_work_as_a_trainer;

        }
        if ($request->work_as_a_consultant_select =='no')
        {
            $traineeInfo->willing_to_work_as_a_consultant = "no";
        }
        if ($request->work_as_a_consultant_select =='yes')
        {
            $traineeInfo->willing_to_work_as_a_consultant = $request->willing_to_work_as_a_consultant;

        }
        if (!is_null($request->service_designation)) {
            $service_array=array();
            $service_details=array();
            $count = count($request->service_designation);
            for ($i=0; $i <$count ; $i++)
            {
                if (!is_null($request->service_designation[$i]))
                {
                    $service_details['service_designation']=$request->service_designation[$i];
                    $service_details['service_organization']=$request->service_organization[$i];
                    $service_details['service_duration']=$request->service_duration[$i];
                    array_push($service_array,$service_details);
                }
            }
            $traineeInfo->service_history=$service_array;
        }
        if (!is_null($request->promotion_designation)) {
            $promotion_array=array();
            $promotion_details=array();
            $count = count($request->promotion_designation);
            for ($i=0; $i <$count ; $i++)
            {
                if (!is_null($request->promotion_designation[$i]))
                {
                    $promotion_details['promotion_designation']=$request->promotion_designation[$i];
                    $promotion_details['promotion_date']=$request->promotion_date[$i];
                    array_push($promotion_array,$promotion_details);
                }
            }
            $traineeInfo->promotion_history=$promotion_array;
        }
        if (!is_null($request->training_title)) {
            $training_array=array();
            $training_details=array();
            $count = count($request->training_title);
            for ($i=0; $i <$count ; $i++)
            {
                if (!is_null($request->training_title[$i]))
                {
                    $training_details['training_title']=$request->training_title[$i];
                    $training_details['training_institution']=$request->training_institution[$i];
                    $training_details['training_duration']=$request->training_duration[$i];
                    array_push($training_array,$training_details);
                }
            }
            $traineeInfo->major_professional_trainings=$training_array;
        }
        if (!is_null($request->education_title)) {
            $education_array=array();
            $education_details=array();
            $count = count($request->education_title);
            for ($i=0; $i <$count ; $i++)
            {
                if (!is_null($request->education_title[$i]))
                {
                    $education_details['education_title']=$request->education_title[$i];
                    $education_details['educational_institution']=$request->educational_institution[$i];
                    $education_details['education_duration']=$request->education_duration[$i];
                    array_push($education_array,$education_details);
                }
            }
            $traineeInfo->educational_qualification=$education_array;
        }
        $traineeInfo->save();
        $notification = array(
            'toaster-message' => 'Information Updated successfuly',
            'alert-type' => 'success'
        );
        return redirect()->route('trainee-infos.create')->with($notification);
    }

    public function show(TraineeInfo $traineeInfo)
    {
        abort_if(Gate::denies('trainee_info_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $traineeInfo->load('organization', 'user');

        return view('admin.traineeInfos.show', compact('traineeInfo'));
    }

    public function destroy(TraineeInfo $traineeInfo)
    {
        abort_if(Gate::denies('trainee_info_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $traineeInfo->delete();

        return back();
    }

    public function massDestroy(MassDestroyTraineeInfoRequest $request)
    {
        TraineeInfo::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }

    public function storeCKEditorImages(Request $request)
    {

        $model         = new TraineeInfo();
        $model->id     = $request->input('crud_id', 0);
        $model->exists = true;
        $media         = $model->addMediaFromRequest('upload')->toMediaCollection('ck-media');

        return response()->json(['id' => $media->id, 'url' => $media->getUrl()], Response::HTTP_CREATED);
    }
}
