<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyTraineeOrganizationRequest;
use App\Http\Requests\StoreTraineeOrganizationRequest;
use App\Http\Requests\UpdateTraineeOrganizationRequest;
use App\Models\TraineeOrganization;
use Gate;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Symfony\Component\HttpFoundation\Response;

class TraineeOrganizationController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }
    
    public function index()
    {
        abort_if(Gate::denies('trainee_organization_access',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $traineeOrganizations = TraineeOrganization::all();

        return view('admin.traineeOrganizations.index', compact('traineeOrganizations'));
    }

    public function create()
    {
        abort_if(Gate::denies('trainee_organization_create',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.traineeOrganizations.create');
    }

    public function store(StoreTraineeOrganizationRequest $request)
    {
        $traineeOrganization = TraineeOrganization::create($request->all());

        return redirect()->route('trainee-organizations.index');
    }

    public function edit(TraineeOrganization $traineeOrganization)
    {
        abort_if(Gate::denies('trainee_organization_edit',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.traineeOrganizations.edit', compact('traineeOrganization'));
    }

    public function update(UpdateTraineeOrganizationRequest $request, TraineeOrganization $traineeOrganization)
    {
        $traineeOrganization->update($request->all());

        return redirect()->route('trainee-organizations.index');
    }

    public function show(TraineeOrganization $traineeOrganization)
    {
        abort_if(Gate::denies('trainee_organization_show',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.traineeOrganizations.show', compact('traineeOrganization'));
    }

    public function destroy(TraineeOrganization $traineeOrganization)
    {
        abort_if(Gate::denies('trainee_organization_delete',$this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $traineeOrganization->delete();

        return back();
    }

    public function massDestroy(MassDestroyTraineeOrganizationRequest $request)
    {
        TraineeOrganization::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
