<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyUserRequest;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Models\Organization;
use App\Models\Role;
use App\Models\User;
use Gate;
// use DataTables;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\CourseRole;
use Symfony\Component\HttpFoundation\Response;
use Yajra\DataTables\DataTables;

class UsersController extends Controller
{
    public $courseRole;

    public function __construct()
    {
        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function allUsers(Request $request)
    {
        if ($request->ajax()) {
            $data = User::all();
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $html = '<div class="btn-group">
                    <button type="button" class="btn btn-info dropdown-toggle btn-xs" 
                        data-toggle="dropdown" aria-expanded="false">Action
                        <span class="caret"></span><span class="sr-only">Toggle Dropdown
                        </span>
                    </button>
                    <ul class="dropdown-menu dropdown-menu-right" role="menu">';
                        if (auth()->user()->can("user_show")) {
                            $html .= '<li><a href="' . route('users.show', [$row->id]) . '"><i class="fa fa-eye"></i> View</a></li>';
                        }
                        if (auth()->user()->can("user_edit")) {
                            $html .= '<li><a href="' . route('users.edit', [$row->id]) . '"><i class="fa fa-edit"></i> Edit</a></li>';
                        }
                        if (auth()->user()->can("user_delete")) {
                            $html .= '<li><a href="#" data-href="' . route('users.destroy', [$row->id]) . '" class="delete-user"><i class="fa fa-trash"></i> Delete</a></li>';
                        }
                    
                        $html .=  '</ul></div>';
                        return $html;

                })
                ->addColumn('organization', function($data)
                {
                   return $data->organization?$data->organization->name:'';
                })
                ->rawColumns(['action','organization'])
                ->make(true);
        }

        return view('admin.users.all');
    }

    public function index(Request $request)
    {
        abort_if(Gate::denies('user_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        if ($request->ajax()) {
            $data = User::where('bpmi_employee',1)->get();
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $html = '<div class="btn-group">
                    <button type="button" class="btn btn-info dropdown-toggle btn-xs" 
                        data-toggle="dropdown" aria-expanded="false">Action
                        <span class="caret"></span><span class="sr-only">Toggle Dropdown
                        </span>
                    </button>
                    <ul class="dropdown-menu dropdown-menu-right" role="menu">';
                        if (auth()->user()->can("user_show")) {
                            $html .= '<li><a href="' . route('users.show', [$row->id]) . '"><i class="fa fa-eye"></i> View</a></li>';
                        }
                        if (auth()->user()->can("user_edit")) {
                            $html .= '<li><a href="' . route('users.edit', [$row->id]) . '"><i class="fa fa-edit"></i> Edit</a></li>';
                        }
                        if (auth()->user()->can("user_delete")) {
                            $html .= '<li><a href="#" data-href="' . route('users.destroy', [$row->id]) . '" class="delete-user"><i class="fa fa-trash"></i> Delete</a></li>';
                        }
                    
                        $html .=  '</ul></div>';
                        return $html;

                })
                ->addColumn('organization', function($data)
                {
                   return $data->organization?$data->organization->name:'';
                })
                ->rawColumns(['action','organization'])
                ->make(true);
        }

        // return view('users');

        // $users = User::with(['roles', 'organization', 'created_by'])->get();

        return view('admin.users.index');
    } 
    // LIST OF TRAINEE
    public function traineeList(Request $request,$id)
    {
        
        if ($request->ajax()) {
            $data = User::with('organization')->whereHas('course_roles',function($q) use($id){
                  $q->where('role_id','=',$id);
                })->get();
           return Datatables::of($data)
                            ->addIndexColumn()
                            ->addColumn('action', function ($row) {
                                $html = '<div class="btn-group">
                                <button type="button" class="btn btn-info dropdown-toggle btn-xs" 
                                    data-toggle="dropdown" aria-expanded="false">Action
                                    <span class="caret"></span><span class="sr-only">Toggle Dropdown
                                    </span>
                                </button>
                                <ul class="dropdown-menu dropdown-menu-right" role="menu">';
                                    if (auth()->user()->can("user_show")) {
                                        $html .= '<li><a href="' . route('users.show', [$row->id]) . '"><i class="fa fa-eye"></i> View</a></li>';
                                    }
                                    if (auth()->user()->can("user_edit")) {
                                        $html .= '<li><a href="' . route('users.edit', [$row->id]) . '"><i class="fa fa-edit"></i> Edit</a></li>';
                                    }
                                    if (auth()->user()->can("user_delete")) {
                                        $html .= '<li><a href="#" data-href="' . route('users.destroy', [$row->id]) . '" class="delete-user"><i class="fa fa-trash"></i> Delete</a></li>';
                                    }
                                
                                    $html .=  '</ul></div>';
                                    return $html;
            
                            })
                            ->addColumn('organization', function($data)
                              {
                              return $data->organization?$data->organization->name:'';
                              })
                            ->rawColumns(['action','organization'])
                            ->make(true);
          }
        if($id == 7){
          return view('admin.users.trainer');
        } else if($id == 8){
          return view('admin.users.trainee');
        }
    } 
    public function orgList(Request $request)
    {
        
        if ($request->ajax()) {
            $id=6;
            $data = User::with('organization')->whereHas('roles',function($q) use($id){
                  $q->where('id','=',$id);
                })->get();
              
           return Datatables::of($data)
                            ->addIndexColumn()
                            ->addColumn('action', function ($row) {
                                $html = '<div class="btn-group">
                                <button type="button" class="btn btn-info dropdown-toggle btn-xs" 
                                    data-toggle="dropdown" aria-expanded="false">Action
                                    <span class="caret"></span><span class="sr-only">Toggle Dropdown
                                    </span>
                                </button>
                                <ul class="dropdown-menu dropdown-menu-right" role="menu">';
                                    if (auth()->user()->can("user_show")) {
                                        $html .= '<li><a href="' . route('users.show', [$row->id]) . '"><i class="fa fa-eye"></i> View</a></li>';
                                    }
                                    if (auth()->user()->can("user_edit")) {
                                        $html .= '<li><a href="' . route('users.edit', [$row->id]) . '"><i class="fa fa-edit"></i> Edit</a></li>';
                                    }
                                    if (auth()->user()->can("user_delete")) {
                                        $html .= '<li><a href="#" data-href="' . route('users.destroy', [$row->id]) . '" class="delete-user"><i class="fa fa-trash"></i> Delete</a></li>';
                                    }
                                
                                    $html .=  '</ul></div>';
                                    return $html;
            
                            })
                            ->addColumn('organization', function($data)
                              {
                              return $data->organization?$data->organization->name:'';
                              })
                            ->rawColumns(['action','organization'])
                            ->make(true);
          }
        
          return view('admin.users.organization');
    
    }
    
    public function create()
    {
        abort_if(Gate::denies('user_create', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::pluck('title', 'id');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.users.create', compact('created_bies', 'organizations', 'roles'));
    }

    public function store(StoreUserRequest $request)
    {
        $request['created_by_id'] = auth()->user()->id;
        $user = User::create($request->all());
        $user->roles()->sync($request->input('roles', []));
        $notification = array(
            'toaster-message' => 'User created successfuly',
            'alert-type' => 'success'
        );
        return redirect()->route('users.index')->with($notification);
    }

    public function edit(User $user)
    {
        abort_if(Gate::denies('user_edit', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $roles = Role::pluck('title', 'id');

        $organizations = Organization::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $created_bies = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $user->load('roles', 'organization', 'created_by');

        return view('admin.users.edit', compact('created_bies', 'organizations', 'roles', 'user'));
    }

    public function update(UpdateUserRequest $request, User $user)
    {
        $user->update($request->all());
        $user->roles()->sync($request->input('roles', []));
        $notification = array(
            'toaster-message' => 'User updated successfuly',
            'alert-type' => 'success'
        );
        return redirect()->back()->with($notification);
    }

    public function show(User $user)
    {
        abort_if(Gate::denies('user_show', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $user->load('roles', 'organization', 'created_by', 'userNominatedTrainees', 'createdByCourses');

        return view('admin.users.show', compact('user'));
    }

    public function destroy(User $user)
    {
        abort_if(Gate::denies('user_delete', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        if (request()->ajax()) {
            $user->delete();
            $output = [
                'success' => true,
                'msg' => 'User has been deleted'
            ];
            return $output;
        }
        //$user->delete();

        //return back();
    }

    public function massDestroy(MassDestroyUserRequest $request)
    {
        User::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
