<?php

namespace App\Http\Controllers;

use App\Models\Course;
use App\Models\LearningPoint;
use App\Models\QuestionBank;
use App\Models\QuizCategory;
use App\Models\Role;
use App\Models\TraineeAttendance;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class AjaxController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function userSearch(Request $request)
    {
        if ($request->has('term')) {
            $search = $request->term;
          
            $data = User::select("id", "name")->where('name', 'LIKE', "%$search%")->with('roles')->get();
        }

        return response()->json($data);
    } 

    public function staffSearch(Request $request)
    {
        if ($request->has('term')) {
            $search = $request->term;

            $data = User::select("id", "name",'designation')->where('name', 'LIKE', "%$search%")->where('bpmi_employee',1)->get();
        }

        return response()->json($data);
    }
      
  
    /**
     * quiz subcategory list.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function getQuizSubcategories($catid)
    {
        $cats = [];
        if ($catid) {
            $cats = QuizCategory::where('parent_id', $catid)->get();
        }
        return response()->json($cats);
    }

    /**
     * quiz question list.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function getQuizQuestions(Request $request)
    {
        $type = $request->type;
        $id = $request->id;
        $questions = [];
        if ($type == 'module') {
            $questions = QuestionBank::where('module_id', $id)->get();
        } elseif ($type == 'topic') {
            $questions = QuestionBank::where('topic', $id)->get();
        }
        return response()->json($questions);
    }

    /**
     * course student list.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function getCourseStudents($courseid)
    {
        $students = [];
        if ($courseid) {
            $students = DB::table('courses')->join('nominations', 'courses.nomination_id', 'nominations.id')
                ->join('nominated_trainees', 'nominated_trainees.nomination_id', 'nominations.id')
                ->join('users', 'users.id', 'nominated_trainees.user_id')->select('users.id', 'users.name')->where('courses.id', $courseid)->where('nominated_trainees.approve', 1)->get();
        }
        return response()->json($students);
    }



    /**
     * Tranee attendance.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function traineeAttendance(Request $request)
    {
        $attendance_exist = TraineeAttendance::where('trainee_id', $request->trainee_id)->where('lesson_id', $request->lesson_id)->first();
        if ($attendance_exist) {
            $attendance_exist->present = $request->present;
            $attendance_exist->save();
        } else {
            $attendance = new TraineeAttendance();
            $attendance->trainee_id = $request->trainee_id;
            $attendance->lesson_id  = $request->lesson_id;
            $attendance->present = $request->present;
            $attendance->save();
        }

        return response()->json('success');
    }


    /**
     * learning point mark save
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function saveLearningPointMark(Request $request)
    {
        $lp = LearningPoint::findOrFail($request->lp_id);
        $data = [
            'user_id' => $request->trainee_id,
            'mark' => $request->mark
        ];
        $lp->mark()->create($data);
        return response()->json('success');
    }

    /**
     * course student list.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function getModulesFromCourse($courseid)
    {
        $course = Course::find($courseid)->load('modules');

        return response()->json($course->modules);
    }

    /**
     * course student list.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function getLessons($courseid)
    {
        $lessons = Course::find($courseid)->load(['courseLessons' => function ($query) {
            $query->whereNotNull('lesson_name');
        }]);


        return response()->json($lessons);
    }

    public function examModuleForm(Request $request)
    {
        $number= $request->number;
        return view('admin.courses.examModuleForm', compact('number'));
    }
}
