<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\Branch;
use App\Models\Course;
use App\Models\CourseRole;
use App\Models\Designation;
use App\Models\NominatedTrainee;
use App\Models\Organization;
use App\Models\TraineeInfo;
use App\Models\TraineeOrganization;
use App\Models\User;
use Image;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name'     => ['required', 'string', 'max:255'],
            'email'    => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @return \App\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name'     => $data['name'],
            'email'    => $data['email'],
            'password' => Hash::make($data['password']),
        ]);
    }
    // TRAINEE SIGNUP PAGE
    public function traineSignupPage()
    {

        $designations = Designation::orderBy('name','asc')->get();
        $org_lists =  Organization::orderBy('name','asc')->get();
        $branches =  Branch::orderBy('name','asc')->get();
        $courses = DB::table('courses')->join('nominations','nominations.course_id','courses.id')->orderBy('courses.id','desc')->select('courses.id as id','courses.title')->get();
        return view('trainee-signup',compact('designations','branches','org_lists','courses'));
    }
    // TRAINEE SIGNUP
    public function traineSignup(Request $request)
    {
        $this->validate($request,[
            'email'    => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
         ]);


        DB::beginTransaction();
        try{
            $user              = new User();
            $user->name        = $request->firstName.' '.$request->lastName;
            $user->email       = $request->email;
            $user->mobile      = $request->mobile;      
            $user->password    = $request->password;
            $user->save();
            $user->assignRole('Trainee');

            $userInfo                     = new TraineeInfo();
            $userInfo->email              = $request->email;
            $userInfo->name_english       = $user->name;
            $userInfo->mobile_no          = $request->mobile;
            $userInfo->designation        = $request->designation_id; 
            $userInfo->other_designation  = $request->other_designation;
            $userInfo->office_name        = $request->office_name;
            $userInfo->organization_id_no = $request->organization_id_no;
            if($request->has('branch_id'))
            {
                $userInfo->org_branch_id        = $request->branch_id;
            }
            $userInfo->organization_id    = $request->organization_id;

            $userInfo->user_id            = $user->id;

            if($request->hasFile('photo')) {

                $name = time().mt_rand() . '.' . $request->file('photo')->getClientOriginalExtension();

                $imgFile =Image::make($request->file('photo'));

                $imgFile->resize(600, 600, function ($constraint) {
                    $constraint->aspectRatio();
                    $constraint->upsize();
                })->save(public_path('upload/images/') . $name);


                $userInfo->photo            = "upload/images/".$name;
            }


            $userInfo->save();
            
            $course=Course::findOrFail($request->course_id);
           
            $nomination_id=$course->nomination->id;

            $nominated_trainee=new NominatedTrainee();
            $nominated_trainee->nomination_id=$nomination_id;
            $nominated_trainee->organization_id=$request->organization_id;
            $nominated_trainee->user_id=$user->id;
            $nominated_trainee->save();

            $course_role=new CourseRole();
            $course_role->user_id=$user->id;
            $course_role->course_id=$course->id;
            $course_role->role_id =8;
            $course_role->save();

            DB::commit();
            return redirect('/')->with('success','Registration Successful');
               
        }catch(\Exception $e){
            DB::rollback();
            throw $e;
        }

        
    }
}
