<?php

namespace App\Http\Controllers;

use App\Models\BookReview;
use App\Models\Course;
use App\Models\NominatedTrainee;
use Illuminate\Http\Request;
use File;

class BookReviewController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $book_review_list=BookReview::where('user_id',auth()->user()->id)->where('course_id',$request->courseId)->get();
        return view('bookReview.index',compact(['book_review_list']));
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function createCourseBookReview(Course $courseId)
    {
        $users = NominatedTrainee::with('user')->where('nomination_id', $courseId->nomination_id)->where('approve', 1)->get();
        return view('bookReview.create',compact(['courseId','users']));
    }

    public function submitCourseBookReview($id)
    {
        $book_review_info=BookReview::findOrFail($id);
        if(!empty($book_review_info->file))
        {
            $notification = array(
                'toaster-message' => 'You have already submitted book review',
                'alert-type' => 'warning'
            );
            return redirect()->route('courses.all')->with($notification);
        } 
        return view('bookReview.view',compact(['book_review_list']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data=$request->all();
        $data['created_by']= auth()->user()->id;
        BookReview::create($data);
        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\BookReview  $bookReview
     * @return \Illuminate\Http\Response
     */
    public function show(BookReview $bookReview)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\BookReview  $bookReview
     * @return \Illuminate\Http\Response
     */
    public function edit(BookReview $bookReview)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\BookReview  $bookReview
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, BookReview $bookReview)
    {
        $request->validate([
            'file' => 'required|mimes:pdf,docx,csv,png,jpg|max:5048',
        ]);

        $fileName ='book_review'."_".$bookReview->id."_".time() . '.' . $request->file->extension();

        $path = public_path('upload/files');

        //checking directory exist 
        if (!File::isDirectory($path)) {
            File::makeDirectory($path, 0777, true, true);
        }
        $request->file->move(public_path('upload/files'), $fileName);

        $bookReview->file=$fileName;
        $bookReview->save();
        return redirect()->route('courses.all')->with('success','File uploaded Successfuly');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\BookReview  $bookReview
     * @return \Illuminate\Http\Response
     */
    public function destroy(BookReview $bookReview)
    {
        //
    }
}
