<?php

namespace App\Http\Controllers\Organization;

use App\Http\Controllers\Controller;
use App\Mail\TraineeMail;
use App\Models\Course;
use App\Models\Designation;
use App\Models\NominatedOrganisation;
use App\Models\NominatedTrainee;
use App\Models\Nomination;
use App\Models\User;
use Illuminate\Http\Request;
use Gate;
use App\Models\Role;
use App\Models\TraineeInfo;
use App\Notifications\TraineeNotification;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Facades\Redirect;
use Symfony\Component\HttpFoundation\Response;
use App\Models\CourseRole;
use Illuminate\Support\Facades\Auth;

class NominatedController extends Controller
{
    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    public function index()
    {
        abort_if(Gate::denies('nomination_list', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nominatedOrganisations = NominatedOrganisation::with(['nomination', 'organization' => function ($q) {
            $q->with('organizationNominatedTrainees');
        }])->where('organization_id', auth()->user()->organization_id)->orderBy('id', 'DESC')->get();
        // dd($nominatedOrganisations);
        $designations = Designation::get();
        return view('admin.nominationList.index', compact('nominatedOrganisations', 'designations'));
    }

    public function traineeStore(Request $request)
    {
        abort_if(Gate::denies('nomination_list', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');
        DB::beginTransaction();
        try {
            $exitTrainee = User::where('email', 'like', "%" . $request->email . "%")->first();
            if (!empty($exitTrainee)) {
                $exitUserNomination = NominatedTrainee::where('nomination_id', $request->nomination_id)->where('user_id', $exitTrainee->id)->first();
                if (!empty($exitUserNomination)) {
                    $notification = array(
                        'toaster-message' => 'This trainee email already added',
                        'alert-type' => 'warning'
                    );
                    return redirect()->back()->with($notification);
                } else {
                    $nominatedTrainee                  = new NominatedTrainee();
                    $nominatedTrainee->nomination_id   = $request->nomination_id;
                    $nominatedTrainee->organization_id = $request->organization_id;
                    $nominatedTrainee->user_id         = $exitTrainee->id;
                    $nominatedTrainee->save();

                    // $findNomination = Nomination::with('batch')->where('id', $request->nomination_id)->first();

                    // $data                 =  [
                    //     'course_title'    => $findNomination->course_title,
                    //     'course_duration' => $findNomination->course_duration,
                    //     'course_start'    => $findNomination->course_start,
                    //     'course_end'      => $findNomination->course_end,
                    //     'batch_name'      => $findNomination->batch->batch_name ?? '',
                    //     'login_url'       => 'http: //127.0.0.1: 8000/login',
                    // ];
                    // $flag = 1;
                    // ===== START SEND NOMINATION EMAIL =================
                    // Notification::send($exitTrainee, new TraineeNotification($data));
                    // Mail::to($exitTrainee->email)->send(new TraineeMail($data, $flag));
                    // ===== END SEND NOMINATION EMAIL =================

                }
            } else {
                $user              = new User();
                $user->name        = $request->name;
                $user->email       = $request->email;
                $user->designation = $request->designation;
                $user->mobile      = $request->mobile;
                $user->department  = $request->department;
                $user->password    = 'user12';
                $user->save();
                $user->assignRole('Trainee');

                $userInfo                     = new TraineeInfo();
                $userInfo->email              = $request->email;
                $userInfo->name_english       = $user->name;
                $userInfo->mobile_no          = $request->mobile;
                $userInfo->designation        = $request->designation;
                $userInfo->organization_id    = $request->organization_id;
                $userInfo->user_id            = $user->id;
                $userInfo->save();


                $nominatedTrainee                  = new NominatedTrainee();
                $nominatedTrainee->nomination_id   = $request->nomination_id;
                $nominatedTrainee->organization_id = $request->organization_id;
                $nominatedTrainee->user_id         = $user->id;
                $nominatedTrainee->save();

                // $findNomination = Nomination::with('batch')->where('id', $request->nomination_id)->first();

                // $data                 =  [
                //     'course_title'    => $findNomination->course_title,
                //     'course_duration' => $findNomination->course_duration,
                //     'course_start'    => $findNomination->course_start,
                //     'course_end'      => $findNomination->course_end,
                //     'batch_name'      => $findNomination->batch->batch_name ?? '',
                //     'login_url'       => 'http: //127.0.0.1: 8000/login',
                //     'email'           => $user->email,
                //     'password'        => 'admin12',
                // ];
                // $flag = 2;

                // ===== START SEND NOMINATION EMAIL =================
                // Mail::to($user->email)->send(new TraineeMail($data, $flag));
                // ===== END SEND NOMINATION EMAIL =================
            }
            $course_id = Nomination::findOrFail($request->nomination_id)->course->id;


            $course_role = new CourseRole();
            $course_role->user_id = $nominatedTrainee->user_id;
            $course_role->course_id = $course_id;
            $course_role->role_id = 8;
            $course_role->save();




            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
        return Redirect()->back();
    }

    public  function traineeView($nominationId)
    {
        $NominatedTrainees = NominatedTrainee::with('traineeInfo')->where('nomination_id', $nominationId)->where('organization_id', auth()->user()->organization_id)->get();
        $course = Course::where('nomination_id', $nominationId)->first();
        return view('admin.nominationList.view', compact('NominatedTrainees', 'course'));
    }

    public function destroy(Request $request)
    {
        try {
            DB::beginTransaction();
            $nomination_trainee = NominatedTrainee::find($request->nominatedTraineeId);
            $nomination_trainee->delete();
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
        return Redirect()->back();
    }
    // APPROVED TRAINEE REPLACE
    public function traineeReplace(Request $request)
    {

        try {
            DB::beginTransaction();
            $nomination_trainee = NominatedTrainee::find($request->nominatedTraineeId);
            $nomination_trainee->update([
                'approve' => 2,
                'replace' => 1
            ]);
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            dd($e->getMessage());
        }
        return Redirect()->back();
    }
}
