<?php

namespace App\Http\Controllers;

use App\Models\Course;
use App\Models\QuestionBank;
use App\Models\QuizOption;
use App\Models\Quiz;
use App\Models\CourseRole;
use Illuminate\Http\Request;
use Gate;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class QuestionBankController extends Controller
{
    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('question_banks_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $questions = QuestionBank::with('course')->where('created_by', auth()->user()->id)->with('exam_module')->paginate(20);

        return view('quiz.questionBank', compact('questions'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $courses = Course::where('is_approved', 1)->latest()->get();
        return view('quiz.addQuestion', compact('courses'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        abort_if(Gate::denies('question_banks_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $question_bank = new QuestionBank();
        $question_bank->question = $request->question;
        $question_bank->course_id = $request->course_id;
        $question_bank->module_id = $request->module;
        $question_bank->topic = $request->topic;
        $question_bank->created_by = auth()->user()->id;
        $question_bank->save();

        if (isset($request->title)) {
            foreach ($request->title as $key => $title) {
                $option_check = 'option_check_' . ++$key;
                $online_question_option = new QuizOption();
                $online_question_option->question_banks_id = $question_bank->id;
                $online_question_option->title = $title;
                // dd($request->$option_check);
                if (isset($request->$option_check)) {
                    $online_question_option->status = 1;
                } else {
                    $online_question_option->status = 0;
                }
                $online_question_option->save();
            }
        }
        $notification = array(
            'toaster-message' => 'Question created Successfully!',
            'alert-type' => 'success'
        );
        return redirect()->route('quiz.question.index')->with($notification);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\QuestionBank  $questionBank
     * @return \Illuminate\Http\Response
     */
    public function show(QuestionBank $questionBank)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\QuestionBank  $questionBank
     * @return \Illuminate\Http\Response
     */
    public function edit(QuestionBank $questionBank)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\QuestionBank  $questionBank
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, QuestionBank $questionBank)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\QuestionBank  $questionBank
     * @return \Illuminate\Http\Response
     */
    public function destroy(QuestionBank $questionBank)
    {
        //
    }
}
