<?php

namespace App\Http\Controllers;

use App\Models\QuizCategory;
use Illuminate\Http\Request;
use Gate;
use App\Models\CourseRole;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class QuizCategoryController extends Controller
{
    public $courseRole;

    public function __construct()
    {

        $this->middleware(function ($request, $next) {
            $user = Auth::user();
            $this->courseRole = CourseRole::where('user_id', $user->id)->get();
            return $next($request);
        });
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        abort_if(Gate::denies('quiz_categories_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $cats = QuizCategory::all();

        return view('quiz.category', compact('cats'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $qc = new QuizCategory();
        $qc->name = $request->name;
        if ($request->parent_id) {
            $qc->parent_id = $request->parent_id;
        }
        $qc->save();
        return redirect()->route('quiz.category.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\QuizCategory  $quizCategory
     * @return \Illuminate\Http\Response
     */
    public function show(QuizCategory $quizCategory)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\QuizCategory  $quizCategory
     * @return \Illuminate\Http\Response
     */
    public function edit(QuizCategory $quizCategory)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\QuizCategory  $quizCategory
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, QuizCategory $quizCategory)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\QuizCategory  $quizCategory
     * @return \Illuminate\Http\Response
     */
    public function destroy(QuizCategory $category)
    {
        abort_if(Gate::denies('quiz_categories_access', $this->courseRole), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $category->delete();

        return back();
    }
}
