<?php

namespace App\Imports;

use App\Models\CourseRole;
use App\Models\Lesson;
use App\Models\TrainerApproval;
use App\Models\User;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Carbon\Carbon;
use DateTime;
use Illuminate\Support\Facades\Validator;
use Maatwebsite\Excel\Concerns\ToCollection;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\Importable;
use Maatwebsite\Excel\Concerns\WithValidation;
use Maatwebsite\Excel\Validators\Failure;

class LessonImport implements ToModel, WithHeadingRow
{
    use Importable;
    /**
     * @param array $row
     *
     * @return \Illuminate\Database\Eloquent\Model|null
     */
    public $courseId;

    protected $rowNum;

    public function __construct($courseID)
    {
        $this->courseId = $courseID;
    }

    public function convertDecimalToTime($decimal)
    {
        // Convert decimal time to total minutes (decimal * 24 hours * 60 minutes)
        $minutesInDay = $decimal * 24 * 60; // Total minutes of the day
        $hours = floor($minutesInDay / 60); // Extract hours
        $minutes = round($minutesInDay % 60); // Extract minutes

        // Format the hours and minutes to 24-hour format
        $formattedTime = sprintf('%02d:%02d', $hours, $minutes); // Zero-pad hours and minutes to 2 digits

        return $formattedTime;
    }

    public function model(array  $row)
    {
        ++$this->rowNum;
        // Validator::make($rows->toArray(), [
        //     '*.date' => 'required',
        //     '*.email' => 'sometimesexists:users'

        // ])->validate();
        // dd($row);
        $date = DateTime::createFromFormat('d/m/Y', trim($row['date']));
        $startDate = $this->convertDecimalToTime(trim($row['start_time']));
        $endDate = $this->convertDecimalToTime(trim($row['end_time']));

        if ($row['type'] == 'break') {
            Lesson::create([
                'type'       => 'break',
                'break_name' => $row['break_name'],
                'date'               => $date,
                'start_time'         => $startDate,
                'end_time'           => $endDate,
                'course_id'  => $this->courseId
            ]);
        } else {

            $user_id = $this->findUser($row, $this->rowNum);
            if ($user_id) {
                $exist_role = CourseRole::where("course_id", $this->courseId)->where('user_id', $user_id)->first();

                if (!$exist_role) {
                    $course_role = new CourseRole();
                    $course_role->user_id = $user_id;
                    $course_role->course_id = $this->courseId;
                    $course_role->role_id = 7;
                    $course_role->save();

                    $ta = new TrainerApproval();
                    $ta->user_id = $user_id;
                    $ta->course_id = $this->courseId;
                    $ta->approved = 0;
                    $ta->save();
                }
            } else {
                $user_id = null;
            }


            // $date = intval($row['date']);
            Lesson::create([
                'type'               => 'lesson',
                'lesson_name'        => $row['lesson_name'],
                'topic'              => $row['topic'],
                'date'               => $date,
                'start_time'         => $startDate,
                'end_time'           => $endDate,
                'trg_session'        => $row['trg_session'],
                'resource_person_id' => $user_id,
                'course_id'          => $this->courseId,
            ]);
        }
    }

    public function findUser($row, int $rowNum)
    {
        $email = $row['email'];

        if ($email) {
            $user = User::where('email', 'LIKE', "%$email%")->first();

            if (is_null($user)) {
                $error = ['team' => 'User is not regsistered'];
                $failures[] = new Failure($rowNum, 'team', $error, $row);
                throw new \Maatwebsite\Excel\Validators\ValidationException(
                    \Illuminate\Validation\ValidationException::withMessages($error),
                    $failures
                );
            }

            return $user->id;
        }
        return null;
    }
}
