<?php

namespace App\Jobs;

use App\Mail\TraineeMail;
use App\Models\Nomination;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Mail;

class TraineeApproveJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    public $nominatedTrainees;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct($nominatedTrainees)
    {

        $this->nominatedTrainees=$nominatedTrainees;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $user = User::findOrFail($this->nominatedTrainees->user_id);
        $findNomination = Nomination::with('batch')->where('id', $this->nominatedTrainees->nomination_id)->first();

        $data                 =  [
            'course_title'    => $findNomination->course_title,
            'course_duration' => $findNomination->course_duration,
            'course_start'    => $findNomination->course_start,
            'course_end'      => $findNomination->course_end,
            'batch_name'      => $findNomination->batch->batch_name ?? '',
            'login_url'       => 'http: //127.0.0.1: 8000/login',
        ];
        $flag = 1;

        $email = new TraineeMail($data, $flag);
        Mail::to($user->email)->send($email);

    }
}
