<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class Coursefeepayment extends Model implements HasMedia
{
    use InteractsWithMedia;
    use HasFactory;

    public const PAYMENT_METHOD_SELECT = [
        'Cheque'             => 'Cheque',
        'Bank Draft'         => 'Bank Draft',
        'Pay Order'          => 'Pay Order',
        'EFTN'               => 'EFTN',
        'Cash Deposit'       => 'Cash Deposit',
        'sending/collection' => 'Cheque Ready in Office for sending / collection',
    ];

    public $table = 'coursefeepayments';

    protected $appends = [
        'image_cheque',
        'image_submit_slip',
    ];

    protected $dates = [
        'date_of_cheque',
        'submit_date',
        'created_at',
        'deleted_at',
    ];

    protected $fillable = [
        'name',
        'designation_id',
        'traineeorganization_id',
        'registration_no',
        'pbs_reb_office_name',
        'mobile_no',
        'bank_name',
        'branch',
        'bank_account_no',
        'payment_method',
        'amount',
        'reference_no',
        'date_of_cheque',
        'submit_date',
        'user_id',
        'course_id',
        'approve',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function designation()
    {
        return $this->belongsTo(Designation::class, 'designation_id');
    }

    public function traineeorganization()
    {
        return $this->belongsTo(TraineeOrganization::class, 'traineeorganization_id');
    }

    public function getDateOfChequeAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setDateOfChequeAttribute($value)
    {
        $this->attributes['date_of_cheque'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getSubmitDateAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setSubmitDateAttribute($value)
    {
        $this->attributes['submit_date'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getImageChequeAttribute()
    {
        return $this->getMedia('image_cheque')->last();
    }

    public function getImageSubmitSlipAttribute()
    {
        return $this->getMedia('image_submit_slip')->last();
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }
    public function course()
    {
        return $this->belongsTo(Course::class, 'course_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
