<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Nomination extends Model
{
    use HasFactory;

    public $table = 'nominations';

    protected $dates = [
        'course_start',
        'course_end',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'subject',
        'details',
        'course_for',
        'course_fee',
        'course_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function nominationNominatedOrganisations()
    {
        return $this->hasMany(NominatedOrganisation::class, 'nomination_id', 'id');
    }

    public function nominationNominatedTrainees()
    {
        return $this->hasMany(NominatedTrainee::class, 'nomination_id', 'id');
    }

    public function nominationCourses()
    {
        return $this->hasMany(Course::class, 'nomination_id', 'id');
    }

    public function getCourseStartAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setCourseStartAttribute($value)
    {
        $this->attributes['course_start'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function getCourseEndAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setCourseEndAttribute($value)
    {
        $this->attributes['course_end'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function batch()
    {
        return $this->belongsTo(Batch::class, 'batch_id');
    }
    public function course()
    {
        return $this->belongsTo(Course::class, 'course_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
