<?php

namespace App\Models;

use \DateTimeInterface;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class TraineeInfo extends Model implements HasMedia
{
    use InteractsWithMedia;
    use HasFactory;

    public const BPMI_BUS_ARRANGEMENTS_SELECT = [
        'Yes' => 'Yes',
        'No'  => 'No',
    ];

    public const MOBILE_BANKING_SELECT = [
        'Bkash'  => 'Bkash',
        'Nagad'  => 'Nagad',
        'Rocket' => 'Rocket',
        'upay' => 'Upay',
        'tcash' => 't-cash',
    ];

    public const RELIGION_SELECT = [
        'Muslim'    => 'Muslim',
        'Hindu'     => 'Hindu',
        'Christian' => 'Christian',
        'Buddhist'  => 'Buddhist',
        'Other'     => 'Other',
    ];

    public const DESIGNATION_SELECT = [
        'Assistant Engineer'      => 'Assistant Engineer',
        'Sub-Divisional Engineer' => 'Sub-Divisional Engineer',
        'Executive Engineer'      => 'Executive Engineer',
    ];

    public $table = 'trainee_infos';

    protected $dates = [
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'email',
        'name_english',
        'designation',
        'other_designation',
        'organization_id',
        'mobile_no',
        'gmail_address',
        'other_email_address',
        'work_division',
        'office_name',
        'office_address',
        'organization_id_no',
        'entry_post',
        'present_job_description',
        'service_history',
        'promotion_history',
        'major_professional_trainings',
        'bank_account_name',
        'bank_name',
        'branch_name',
        'bank_account_no',
        'mobile_banking',
        'mobile_banking_no',
        'name_bangla',
        'fathers_name',
        'mothers_name',
        'national_id_no',
        'present_address',
        'home_district',
        'permanent_address',
        'religion',
        'educational_qualification',
        'fields_of_interest',
        'innovative_idea',
        'willing_to_work_as_a_trainer',
        'willing_to_work_as_a_consultant',
        'additional_comment',
        'bpmi_bus_arrangements',
        'other_method_to_go_to_payra',
        'user_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function registerMediaConversions(Media $media = null): void
    {
        $this->addMediaConversion('thumb')->fit('crop', 50, 50);
        $this->addMediaConversion('preview')->fit('crop', 120, 120);
    }

    public function organization()
    {
        return $this->belongsTo(Organization::class, 'organization_id');
    }

    public function user_designation()
    {
        return $this->belongsTo(Designation::class, 'designation');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
