<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Hash;
use Illuminate\Auth\Notifications\ResetPassword;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;

class User extends Authenticatable
{
    use SoftDeletes;
    use Notifiable;
    use HasFactory;

    public $table = 'users';

    protected $hidden = [
        'remember_token',
        'password',
    ];

    protected $dates = [
        'email_verified_at',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'name',
        'email',
        'email_verified_at',
        'password',
        'remember_token',
        'organization_id',
        'designation',
        'mobile',
        'department',
        'status',
        'sign',
        'bpmi_employee',
        'created_by_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];
    public function assignRole($role)
    {
        $role = Role::where('title', $role)->get()->first();
        return $this->roles()->save($role);
    }
    public function getIsAdminAttribute()
    {
        return $this->roles()->where('id', 1)->exists();
    }

    public function userNominatedTrainees()
    {
        return $this->hasMany(NominatedTrainee::class, 'user_id', 'id');
    }

    public function traineeInfo()
    {
        return $this->hasOne(TraineeInfo::class, 'user_id', 'id');
    }


    public function createdByCourses()
    {
        return $this->hasMany(Course::class, 'created_by_id', 'id');
    }

    public function getEmailVerifiedAtAttribute($value)
    {
        return $value ? Carbon::createFromFormat('Y-m-d H:i:s', $value)->format(config('panel.date_format') . ' ' . config('panel.time_format')) : null;
    }

    public function setEmailVerifiedAtAttribute($value)
    {
        $this->attributes['email_verified_at'] = $value ? Carbon::createFromFormat(config('panel.date_format') . ' ' . config('panel.time_format'), $value)->format('Y-m-d H:i:s') : null;
    }

    public function setPasswordAttribute($input)
    {
        if ($input) {
            $this->attributes['password'] = app('hash')->needsRehash($input) ? Hash::make($input) : $input;
        }
    }

    public function sendPasswordResetNotification($token)
    {
        $this->notify(new ResetPassword($token));
    }

    public function roles()
    {
        return $this->belongsToMany(Role::class);
    }

    public function course_roles()
    {
        return $this->hasMany(CourseRole::class);
    }


    public function course_evaluation()
    {
        return $this->hasOne(FinalCourseEvaluation::class);
    }

    public function organization()
    {
        return $this->belongsTo(Organization::class, 'organization_id');
    }
    
    public function userDesignation()
    {
        return $this->belongsTo(Designation::class, 'designation');
    }

    public function created_by()
    {
        return $this->belongsTo(User::class, 'created_by_id');
    }


    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
