<?php

namespace App\Providers;

use App\Models\Role;
use App\Models\User;
use Illuminate\Foundation\Support\Providers\AuthServiceProvider as ServiceProvider;
use Illuminate\Support\Facades\Gate;
use Illuminate\Support\Collection;


class AuthServiceProvider extends ServiceProvider
{
    /**
     * The policy mappings for the application.
     *
     * @var array
     */
    protected $policies = [
        // 'App\Models\Model' => 'App\Policies\ModelPolicy',
    ];

    /**
     * Register any authentication / authorization services.
     *
     * @return void
     */
    public function boot()
    {
        $this->registerPolicies();

        // Eager load user roles relationship globally
        User::addGlobalScope('roles', function ($builder) {
            $builder->with('roles');
        });

        // Eager load roles permissions relationship globally
        Role::addGlobalScope('permissions', function ($builder) {
            $builder->with('permissions');
        });

        Gate::before(function ($user) {
            if ($user->roles->first()->title == 'Admin') {
                $permissionsArray = Role::findOrFail(1)->permissions->pluck('title')->toArray();
                foreach ($permissionsArray as $title) {
                    Gate::define($title, function ($user) use ($title, $permissionsArray) {
                        return in_array($title, $permissionsArray);
                    });
                }
            } elseif ($user->roles->first()->title == 'Rector') {
                $permissionsArray = Role::findOrFail(4)->permissions->pluck('title')->toArray();
                foreach ($permissionsArray as $title) {
                    Gate::define($title, function ($user, $courseRole) use ($title, $permissionsArray) {
                        return in_array($title, $permissionsArray);
                    });
                }
            } elseif ($user->roles->first()->title == 'MDS') {
                $permissionsArray = Role::findOrFail(3)->permissions->pluck('title')->toArray();
                foreach ($permissionsArray as $title) {
                    Gate::define($title, function () use ($title, $permissionsArray) {
                        return in_array($title, $permissionsArray);
                    });
                }
            }
        });

        $roles = Role::with('permissions')->get();
        $permissionsArray = [];
        foreach ($roles as $role) {
            foreach ($role->permissions as $permissions) {
                $permissionsArray[] = $permissions->title;
            }
        }


        foreach ($permissionsArray as $title) {

            Gate::define($title, function ($user, $courseRole) use ($title) {


                if ($courseRole instanceof Collection) {

                    if ($courseRole->isNotEmpty()) {

                        $course_per = [];

                        foreach ($courseRole as $key => $cr) {

                            $role_per = Role::findOrFail($cr->role_id)->permissions->pluck('title')->toArray();

                            array_push($course_per, ...$role_per);
                        }
                    } else {
                        if ($user->roles->first()->title == 'MDS') {

                            $course_per = Role::findOrFail(3)->permissions->pluck('title')->toArray();
                        } elseif ($user->roles->first()->title == 'Rector') {

                            $course_per = Role::findOrFail(4)->permissions->pluck('title')->toArray();
                        } elseif ($user->roles->first()->title == 'Organization') {

                            $course_per = Role::findOrFail(6)->permissions->pluck('title')->toArray();
                        } else {

                            $course_per = Role::findOrFail(2)->permissions->pluck('title')->toArray();
                        }
                    }
                } else {

                    if ($user->roles->first()->title == 'MDS') {

                        $course_per = Role::findOrFail(3)->permissions->pluck('title')->toArray();
                    } elseif ($user->roles->first()->title == 'Rector') {

                        $course_per = Role::findOrFail(4)->permissions->pluck('title')->toArray();
                    } elseif ($user->roles->first()->title == 'Organization') {

                        $course_per = Role::findOrFail(6)->permissions->pluck('title')->toArray();
                    } else {

                        $role_id = $courseRole->role_id;

                        $course_per = Role::findOrFail($role_id)->permissions->pluck('title')->toArray();
                    }
                }




                return in_array($title, $course_per);
            });
        }
    }
}
