@extends('layouts.admin')
@section('styles')
    <style>
        h4 {
            font-size: 1rem;
            font-weight: 600;
        }

        h5 {
            font-size: 0.8rem;
            font-weight: 600;
            margin: 15px 0px;
        }

        .course-table .ck.ck-editor {
            width: 450px;
        }

        a {
            color: #fff !important;
        }
    </style>
@stop
@section('content')

    <div class="card">
        <div class="card-header">
            Edit {{ trans('cruds.course.title_singular') }}
        </div>

        <div class="card-body">
            <form method="POST" action="{{ route('courses.update', [$course->id]) }}" enctype="multipart/form-data">
                @method('PUT')
                @csrf
                <h4>1. General Information</h4>
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required" for="course_code">{{ trans('cruds.course.fields.course_code') }}</label>
                            <input class="form-control {{ $errors->has('course_code') ? 'is-invalid' : '' }}" type="text"
                                name="course_code" id="course_code" value="{{ $course->course_code }}" required>
                            @if ($errors->has('course_code'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('course_code') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.course_code_helper') }}</span>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required" for="title">{{ trans('cruds.course.fields.title') }}</label>
                            <input class="form-control {{ $errors->has('title') ? 'is-invalid' : '' }}" type="text"
                                name="title" id="title" value="{{ $course->title }}" required>
                            @if ($errors->has('title'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('title') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.title_helper') }}</span>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required">{{ trans('cruds.course.fields.type_course') }}</label>
                            <select class="form-control {{ $errors->has('type_course') ? 'is-invalid' : '' }}"
                                name="type_course" id="type_course" required>
                                <option value disabled {{ old('type_course', null) === null ? 'selected' : '' }}>
                                    {{ trans('global.pleaseSelect') }}</option>
                                @foreach (App\Models\Course::TYPE_COURSE_SELECT as $key => $label)
                                    <option value="{{ $key }}"
                                        {{ old('type_course', '1') === (string) $key ? 'selected' : '' }}>
                                        {{ $label }}</option>
                                @endforeach
                            </select>
                            @if ($errors->has('type_course'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('type_course') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.type_course_helper') }}</span>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required"
                                for="course_duration">{{ trans('cruds.course.fields.course_duration') }}</label>
                            <input class="form-control {{ $errors->has('course_duration') ? 'is-invalid' : '' }}"
                                type="text" name="course_duration" id="course_duration"
                                value="{{ $course->course_duration }}" required>
                            @if ($errors->has('course_duration'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('course_duration') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.course_duration_helper') }}</span>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label for="field_visit">{{ trans('cruds.course.fields.field_visit') }}</label>
                            <input class="form-control {{ $errors->has('field_visit') ? 'is-invalid' : '' }}"
                                type="text" name="field_visit" id="field_visit" value="{{ $course->field_visit }}">
                            @if ($errors->has('field_visit'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('field_visit') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.field_visit_helper') }}</span>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required"
                                for="course_start">{{ trans('cruds.course.fields.course_start') }}</label>
                            <input class="form-control datepicker {{ $errors->has('course_start') ? 'is-invalid' : '' }}"
                                type="text" name="course_start" id="course_start"
                                value="{{ \Carbon\Carbon::parse(trim($course->course_start))->format('d-m-Y') ?? '' }}"
                                required>
                            @if ($errors->has('course_start'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('course_start') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.course_start_helper') }}</span>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-group">
                            <label class="required" for="course_end">{{ trans('cruds.course.fields.course_end') }}</label>
                            <input class="form-control datepicker {{ $errors->has('course_end') ? 'is-invalid' : '' }}"
                                type="text" name="course_end" id="course_end"
                                value="{{ \Carbon\Carbon::parse(trim($course->course_end))->format('d-m-Y') ?? '' }}"
                                required>
                            @if ($errors->has('course_end'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('course_end') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.course_end_helper') }}</span>
                        </div>
                    </div>
                    <div class="col-md-12">
                        <div class="form-group">
                            <label for="requiring_body">Notesheet</label>
                            <textarea class="form-control ckeditor {{ $errors->has('requiring_body') ? 'is-invalid' : '' }}" name="requiring_body"
                                id="requiring_body">{!! $course->requiring_body !!}</textarea>
                            @if ($errors->has('requiring_body'))
                                <div class="invalid-feedback">
                                    {{ $errors->first('requiring_body') }}
                                </div>
                            @endif
                            <span class="help-block">{{ trans('cruds.course.fields.requiring_body_helper') }}</span>
                        </div>
                    </div>
                    {{-- <div class="col-md-4">
                    <div class="form-group">
                        <label for="nomination_id">{{ trans('cruds.course.fields.nomination') }}</label>
                        <select class="form-control select2 {{ $errors->has('nomination') ? 'is-invalid' : '' }}" name="nomination_id" id="nomination_id">
                            @foreach ($nominations as $id => $entry)
                                <option value="{{ $id }}" {{ old('nomination_id') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                            @endforeach
                        </select>
                        @if ($errors->has('nomination'))
                            <div class="invalid-feedback">
                                {{ $errors->first('nomination') }}
                            </div>
                        @endif
                        <span class="help-block">{{ trans('cruds.course.fields.nomination_helper') }}</span>
                    </div>
                </div> --}}
                </div>

                {{-- <h4>3. Information regarding Trainers/Resource Persons</h4>
            <div class="row mt-2 mb-2">
                <div class="col-md-4">
                    <select class="form-control select2 ajaxSearch" name="resource_person" id="resource_person"></select>
                </div>
                <div class="col-md-4">
                    <a class="btn btn-info mb-2 add-resource-person">
                        <i class="fa-fw fas fa-plus"></i> Add Resource Person
                    </a>
                </div>
            </div> --}}

                {{-- <div class="resource-table">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Names of the Trainers/Resource Persons </th>
                            <th>No. of classes he has taken in 12 months</th>
                            <th>Average No. Scored</th>
                            <th>Adverse Comments (If any)</th>
                            <th>Action</th>
                          </tr>
                    </thead>
                    <tbody>
                        @if ($course->possible_trainers)
                        @foreach ($course->possible_trainers as $possible_trainer)
                        <tr>
                            <td>
                                @php
                                   $user= app\Models\User::find($possible_trainer);
                                @endphp
                                {{$user->name}}
                            </td>
                            <td>5</td>
                            <td>তথ্য অনুপস্থিত</td>
                            <td>তথ্য অনুপস্থিত</td>
                            <td><a class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a></td>
                        </tr>
                        @endforeach
                        @endif
                      
                        
                    </tbody>
                </table>
            </div> --}}

                <h4>2. Course Content/Curriculum</h4>
                <div class="mb-3">
                    <a target="_blank" class="btn btn-info" href="{{ route('courses.getlesson', $course->id) }}"> View
                        Lesson Plan</a>

                </div>

                <h4>2. Tentative Budget</h4>

                <div class="budget-table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Description of Activities</th>
                                <th>Unit</th>
                                <th>Qty</th>
                                <th>Unit Cost</th>
                                <th>Total Cost (BDT)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>

                            @foreach ($course_budgets as $budget)
                                <tr>
                                    <td>
                                        <input type="hidden" name="budget[{{ $budget->id }}][budget_id]"
                                            value="{{ $budget->id }}">
                                        {{ $budget['budget']->name ?? $budget->budget_name }}
                                    </td>
                                    <td>
                                        <input type="text" name="budget[{{ $budget->id }}][unit]"
                                            class="form-control" value="{{ $budget->unit }}">
                                    </td>
                                    <td>
                                        <input type="number" name="budget[{{ $budget->id }}][qty]"
                                            class="form-control qty" value="{{ $budget->qty }}">
                                    </td>
                                    <td>
                                        <input type="number" class="form-control budget_rate"
                                            name="budget[{{ $budget->id }}][rate]" value="{{ $budget->rate }}">
                                    </td>
                                    <td>
                                        <input type="number" name="budget[{{ $budget->id }}][total_cost]"
                                            value="{{ $budget->total_cost }}"
                                            class="item-total-cost form-control total_cost">
                                    </td>
                                    <td>
                                        <a class='btn item-remove-btn btn-xs btn-danger delete_budget'><i
                                                class="fas fa-trash"></i></a>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="4"><a class='btn btn-xs btn-success add-budget'><i
                                            class="fas fa-plus"></i> Add new budget</a></td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
                <table class="table table-bordered budget_cal">
                    <tbody>
                        <tr>
                            <td colspan="1"></td>
                            <td colspan="3">
                                <div class="row">
                                    <div class="col-md-4"> <b>Total: </b> </div>
                                    <div class="col-md-8 subtotal">{{ $course->total_budget }}</div>
                                    <input type="hidden" class="total_budget" name="total_budget" value="">
                                </div>
                            </td>
                        </tr>
                        <tr>
                            <td colspan="1"></td>
                            <td colspan="3">
                                <div class="row">
                                    <div class="col-md-4"> <b>Tax: </b> </div>
                                    <div class="col-md-8"> <input type="text" class="form-control tax"
                                            value="{{ $course->budget_tax }}"></div>
                                    <input type="hidden" class="budget_tax" name="budget_tax" value="">
                                </div>
                            </td>
                        </tr>
                        <tr>
                            <td colspan="1"></td>
                            <td colspan="3">
                                <div class="row">
                                    <div class="col-md-4"> <b>Total (including VAT & AIT): </b> </div>
                                    <div class="col-md-8 totalwithtax">{{ $course->total_budget_inc_vat }}</div>
                                    <input type="hidden" class="total_budget_inc_vat" name="total_budget_inc_vat"
                                        value="">
                                </div>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <h4>3. Information Regarding Course Management</h4>
                <h4>(A)Principal Advisor</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control select2 ajaxSearch" name="course_principal_advisor"
                            id="course_principal_advisor"></select>

                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add-principal-advisor">
                            <i class="fa-fw fas fa-plus"></i> Add Principal Advisor
                        </a>
                    </div>
                </div>
                <div class="Principal-table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Principal Advisor</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                        <tbody>
                            @if ($course->course_principal_advisor)
                                @foreach ($course->course_principal_advisor as $course_principal_advisor)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($course_principal_advisor);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='principal_advisor[]'
                                                value='{{ $course_principal_advisor }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        </tbody>
                    </table>
                </div>
                <h4>(B)Course Advisor</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control select2 ajaxSearch" name="course_advisor"
                            id="course_advisor"></select>
                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add-advisor">
                            <i class="fa-fw fas fa-plus"></i> Add Advisor
                        </a>
                    </div>
                </div>
                <div class="Advisor-table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Course Advisor</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if ($course->course_advisor)
                                @foreach ($course->course_advisor as $course_advisor)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($course_advisor);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='course_advisor[]'
                                                value='{{ $course_advisor }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif

                        </tbody>
                    </table>
                </div>
                <h4>(C)Course Director</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control select2 ajaxSearch" name="course_director"
                            id="course_director"></select>
                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add-director">
                            <i class="fa-fw fas fa-plus"></i> Add Director
                        </a>
                    </div>
                </div>
                <div class="Director-table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Course Director</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if ($course->course_director)
                                @foreach ($course->course_director as $course_director)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($course_director);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='course_director[]'
                                                value='{{ $course_director }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        </tbody>
                    </table>
                </div>
                <h4>(D)Course Co-ordinator</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control ajaxSearch" name="course_co_ordinator"
                            id="course_co_ordinator"></select>
                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add_course_co_ordinator">
                            <i class="fa-fw fas fa-plus"></i> Add Course Co-ordinator
                        </a>
                    </div>
                </div>
                <div class="course_co_ordinator_table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Course Co-Ordinator</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if ($course->course_co_ordinator)
                                @foreach ($course->course_co_ordinator as $course_co_ordinator)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($course_co_ordinator);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='course_co_ordinator[]'
                                                value='{{ $course_co_ordinator }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif

                        </tbody>
                    </table>

                </div>
                <h4>(E) Asst. Course Co-ordinator</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control select2 ajaxSearch" name="assoc_course_co_ordinator"
                            id="assoc_course_co_ordinator"></select>
                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add-director">
                            <i class="fa-fw fas fa-plus"></i> Add Asst. Course Co-ordinator
                        </a>
                    </div>
                </div>
                <div class="assoc_course_co_ordinator_table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Asst. Course Co-ordinator</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if ($course->associcate_course_co_ordinator)
                                @foreach ($course->associcate_course_co_ordinator as $assoc_course_co_ordinator)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($assoc_course_co_ordinator);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='assoc_course_co_ordinator[]'
                                                value='{{ $assoc_course_co_ordinator }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        </tbody>
                    </table>
                </div>

                <h4>(F) Course Helper</h4>
                <div class="row mt-2 mb-2">
                    <div class="col-md-4">
                        <select class="form-control ajaxSearch" name="course_helper" id="course_helper"></select>
                    </div>
                    <div class="col-md-4">
                        <a class="btn btn-info mb-2 add_course_helper">
                            <i class="fa-fw fas fa-plus"></i> Add Course Helper
                        </a>
                    </div>
                </div>
                <div class="course_helper_table">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>Course Helper</th>
                                <th>No. of Courses conducted by him in last 12 months</th>
                                <th>Average marks secured</th>
                                <th>Adverse Comments (If any)</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @if ($course->course_helper)
                                @foreach ($course->course_helper as $course_helper)
                                    <tr>
                                        <td>
                                            @php
                                                $user = app\Models\User::find($course_helper);
                                            @endphp
                                            {{ $user->name }}
                                            <input type='hidden' name='course_helper[]' value='{{ $course_helper }}' />
                                        </td>
                                        <td>5</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td>তথ্য অনুপস্থিত</td>
                                        <td><a
                                                class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a>
                                        </td>
                                    </tr>
                                @endforeach
                            @endif
                        </tbody>
                    </table>

                </div>

                <div class="form-group">
                    <button class="btn btn-success" type="submit">
                        Update
                    </button>
                </div>
            </form>
        </div>
    </div>



@endsection

@section('scripts')
    <script type="text/javascript">
        $(document).ready(function() {
            $('.datepicker').datetimepicker({
                format: 'DD-MM-YYYY'
            });
        });
    </script>
    <script>
        var total = 0;
        var totalTax = 0;
        var totalBDT = 0;

        function calculateSum(val = null) {
            if (val) {
                total += val;
            } else {
                $(".item-total-cost").each(function() {
                    if ($(this).val()) {
                        total += parseFloat($(this).val());
                    }
                })
            }
            $('.subtotal').html(total);
            $('.total_budget').val(total);
            let tax = $('.tax').val();
            $('.budget_tax').val(tax);
            if (tax) {
                totalTax = (total * tax) / 100;
                totalBDT = (total + totalTax).toFixed(2);
                $('.totalwithtax').html(totalBDT);
                $('.total_budget_inc_vat').val(totalBDT);
            } else {
                $('.totalwithtax').html(total);
                $('.total_budget_inc_vat').val(total);
            }
        }

        $('.item-remove-btn').on('click', function() {
            var $row = $(this).closest('tr');
            var id = $row.find('input[name*="budget["]').val();

            const deleteUrl = "{{ route('course-budgets.destroy', ':id') }}".replace(':id', id);

            $.ajax({
                url: deleteUrl,
                type: 'DELETE',
                data: {
                    _token: '{{ csrf_token() }}'
                },
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr(
                        'content')
                },
                success: function(response) {
                    $row.remove();
                    alert('Budget item deleted successfully!');
                }
            });
        });


        $(document).on('change', ".item-total-cost", function() {

            total = 0;
            totalTax = 0;
            totalBDT = 0;
            calculateSum();

        });

        $(document).on('change', ".budget_rate, .qty", function() {
            const $row = $(this).closest('tr');
            const rate = parseFloat($row.find('.budget_rate').val()) ||
                0;
            const qty = parseFloat($row.find('.qty').val()) ||
                0;

            const itemTotalCost = rate * qty;
            $row.find('.item-total-cost').val(itemTotalCost);
            total = 0;
            totalTax = 0;
            totalBDT = 0;
            calculateSum();
        });

        $(document).on('change', ".tax", function() {
            total = 0;
            totalTax = 0;
            totalBDT = 0;
            calculateSum();

        });
        $(document).ready(function() {
            calculateSum();

            function SimpleUploadAdapter(editor) {
                editor.plugins.get('FileRepository').createUploadAdapter = function(loader) {
                    return {
                        upload: function() {
                            return loader.file
                                .then(function(file) {
                                    return new Promise(function(resolve, reject) {
                                        // Init request
                                        var xhr = new XMLHttpRequest();
                                        xhr.open('POST',
                                            '{{ route('courses.storeCKEditorImages') }}',
                                            true);
                                        xhr.setRequestHeader('x-csrf-token', window._token);
                                        xhr.setRequestHeader('Accept', 'application/json');
                                        xhr.responseType = 'json';

                                        // Init listeners
                                        var genericErrorText =
                                            `Couldn't upload file: ${ file.name }.`;
                                        xhr.addEventListener('error', function() {
                                            reject(genericErrorText)
                                        });
                                        xhr.addEventListener('abort', function() {
                                            reject()
                                        });
                                        xhr.addEventListener('load', function() {
                                            var response = xhr.response;

                                            if (!response || xhr.status !== 201) {
                                                return reject(response && response
                                                    .message ?
                                                    `${genericErrorText}\n${xhr.status} ${response.message}` :
                                                    `${genericErrorText}\n ${xhr.status} ${xhr.statusText}`
                                                );
                                            }

                                            $('form').append(
                                                '<input type="hidden" name="ck-media[]" value="' +
                                                response.id + '">');

                                            resolve({
                                                default: response.url
                                            });
                                        });

                                        if (xhr.upload) {
                                            xhr.upload.addEventListener('progress', function(
                                                e) {
                                                if (e.lengthComputable) {
                                                    loader.uploadTotal = e.total;
                                                    loader.uploaded = e.loaded;
                                                }
                                            });
                                        }

                                        // Send request
                                        var data = new FormData();
                                        data.append('upload', file);
                                        data.append('crud_id', '{{ $course->id ?? 0 }}');
                                        xhr.send(data);
                                    });
                                })
                        }
                    };
                }
            }
            let theEditor = [];
            var allEditors = document.querySelectorAll('.ckeditor');
            for (var i = 0; i < allEditors.length; ++i) {
                ClassicEditor.create(
                    allEditors[i], {
                        extraPlugins: [SimpleUploadAdapter]
                    }
                ).then(editor => {
                    theEditor.push(editor);
                })
            }

            function getDataFromTheEditor() {
                return theEditor.getData();
            }
            var i = 0;
            var course_content_index = null;
            $(".add-course-content").click(function() {
                if (course_content_index != null) {
                    var course_time = $("input[name=course_time]").val()

                    $('.course-content-table').find('tr').eq(course_content_index).closest('tr').find(
                        'td .c_subject').val(theEditor[1].getData());
                    $('.course-content-table').find('tr').eq(course_content_index).find('.c_subject').html(
                        theEditor[1].getData());

                    $('.course-content-table').find('tr').eq(course_content_index).closest('tr').find(
                        'td .c_time').val(course_time);
                    $('.course-content-table').find('tr').eq(course_content_index).find('.c_time').text(
                        course_time)

                    $('.course-content-table').find('tr').eq(course_content_index).closest('tr').find(
                        'td .c_person').val(theEditor[2].getData());
                    $('.course-content-table').find('tr').eq(course_content_index).find('.c_person').html(
                        theEditor[2].getData());

                    theEditor[1].setData('');
                    theEditor[2].setData('');
                    $("[name='course_time']").val(null)

                    $('.add-course-content').html('<i class="fa-fw fas fa-plus"></i> Add Course Content');
                    course_content_index = null

                } else {
                    i++
                    var course_time = $("input[name=course_time]").val()
                    var markup = "<tr><td><input type='hidden' class='c_subject' name='course_content[" +
                        i + "][course]' value='" + theEditor[1].getData() + "' /><div class='c_subject'>" +
                        theEditor[1].getData() +
                        "</div></td><td><input type='hidden' class='c_time' name='course_content[" + i +
                        "][time]' value='" + course_time + "' /><div class='c_time'>" + course_time +
                        "</div></td> <input type='hidden' class='index_num' value='" + i +
                        "'> <td><input type='hidden' class='c_person' name='course_content[" + i +
                        "][resource_persons]' value='" + theEditor[2].getData() +
                        "' /><div class='c_person'> " + theEditor[2].getData() +
                        "</div></td><td><a class='btn btn-xs btn-info edit_course_content'>{{ trans('global.edit') }}</a> <a class='btn btn-xs btn-danger delete_course_content'>{{ trans('global.delete') }}</a></td></tr>";
                    $(".course-table table tbody").append(markup);
                    theEditor[1].setData('');
                    theEditor[2].setData('');
                    $("[name='course_time']").val(null)

                }
            });
            $('body').on('click', '.edit_course_content', function(e) {
                var subject = ($(this).closest('tr').find('td .c_subject').val());
                var time = ($(this).closest('tr').find('td .c_time').val());
                var index = ($(this).closest('tr').find('.index_num').val());
                var resource = ($(this).closest('tr').find('td .c_person').val());
                theEditor[1].setData(subject);
                theEditor[2].setData(resource);
                $("[name='course_time']").val(time)
                $('.add-course-content').html('<i class="fa-fw fas fa-check"></i> Update Course Content');
                course_content_index = index
            })
            $('body').on('click', '.delete_course_content', function(e) {
                $(this).closest('tr').remove();
                i--;
            })
            $(".ajaxMultiSearch").select2({
                tags: true,
                multiple: true,
                tokenSeparators: [',', ' '],
                minimumInputLength: 2,
                minimumResultsForSearch: 10,
                ajax: {
                    url: "{{ route('user.search') }}",
                    dataType: "json",
                    type: "GET",
                    data: function(params) {
                        var queryParameters = {
                            term: params.term
                        }
                        return queryParameters;
                    },
                    processResults: function(data) {
                        return {
                            results: $.map(data, function(item) {
                                return {
                                    text: item.name,
                                    id: item.id
                                }
                            })
                        };
                    },
                    cache: false
                }
            });


            $(".ajaxSearch").select2({
                tags: true,
                multiple: false,
                tokenSeparators: [',', ' '],
                minimumInputLength: 2,
                minimumResultsForSearch: 10,
                ajax: {
                    url: "{{ route('staff.search') }}",
                    dataType: "json",
                    type: "GET",
                    data: function(params) {
                        var queryParameters = {
                            term: params.term
                        }
                        return queryParameters;
                    },
                    processResults: function(data) {
                        return {
                            results: $.map(data, function(item) {
                                return {
                                    text: item.name + ' (' + item.designation + ')',
                                    id: item.id
                                }
                            })
                        };
                    },
                    cache: false
                }
            });

            $(".add_course_helper").click(function() {
                var course_helper = $("select[name=course_helper]").select2('data');
                var markup = "<tr><td> <input type='hidden' name='course_helper[]' value='" + course_helper[
                        0]['id'] + "' /> " + course_helper[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_course_helper'>{{ trans('global.delete') }}</a></td></tr>";
                $(".course_helper_table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_course_helper', function(e) {
                $(this).closest('tr').remove();
            })

            $(".add_course_co_ordinator").click(function() {
                var course_co_ordinator = $("select[name=course_co_ordinator]").select2('data');
                var markup = "<tr><td> <input type='hidden' name='course_co_ordinator[]' value='" +
                    course_co_ordinator[0]['id'] + "' /> " + course_co_ordinator[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_course_co_ordinator'>{{ trans('global.delete') }}</a></td></tr>";
                $(".course_co_ordinator_table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_course_co_ordinator', function(e) {
                $(this).closest('tr').remove();
            })

            $(".add_assoc_course_co_ordinator").click(function() {
                var assoc_course_co_ordinator = $("select[name=assoc_course_co_ordinator]").select2('data');
                var markup = "<tr><td> <input type='hidden' name='assoc_course_co_ordinator[]' value='" +
                    assoc_course_co_ordinator[0]['id'] + "' /> " + assoc_course_co_ordinator[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_assoc_course_co_ordinator'>{{ trans('global.delete') }}</a></td></tr>";
                $(".assoc_course_co_ordinator_table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_assoc_course_co_ordinator', function(e) {
                $(this).closest('tr').remove();
            })


            $(".add-principal-advisor").click(function() {
                var principal_advisor = $("select[name=course_principal_advisor]").select2('data');
                var markup = "<tr><td> <input type='hidden' name='principal_advisor[]' value='" +
                    principal_advisor[0]['id'] + "' /> " + principal_advisor[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_principal_advisor'>{{ trans('global.delete') }}</a></td></tr>";
                $(".Principal-table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_principal_advisor', function(e) {
                $(this).closest('tr').remove();
            })
            $(".add-advisor").click(function() {
                var course_advisor = $("select[name=course_advisor]").select2('data');
                var markup = "<tr><td> <input type='hidden' name='course_advisor[]' value='" +
                    course_advisor[0]['id'] + "' /> " + course_advisor[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_course_advisor'>{{ trans('global.delete') }}</a></td></tr>";
                $(".Advisor-table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_course_advisor', function(e) {
                $(this).closest('tr').remove();
            })

            $('body').on('click', '.delete_budget', function(e) {
                $(this).closest('tr').remove();
                total = 0;
                totalTax = 0;
                totalBDT = 0;
                calculateSum();

            })

            $(".add-director").click(function() {
                var course_director = $("select[name=course_director]").select2('data');

                var markup = "<tr><td> <input type='hidden' name='course_director[]' value='" +
                    course_director[0]['id'] + "' /> " + course_director[0]['text'] +
                    "</td><td>5</td><td>তথ্য অনুপস্থিত</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_course_director'>{{ trans('global.delete') }}</a></td></tr>";
                $(".Director-table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });
            $('body').on('click', '.delete_course_director', function(e) {
                $(this).closest('tr').remove();
            })

            var j = 0;
            $(".add-associate-officials").click(function() {
                j++
                var associate_official = $("select[name=add_associate_official]").select2('data');
                let ass_off = []
                let ass_off_id = []
                $.each(associate_official, function(index, value) {
                    ass_off.push(value.text)
                    ass_off_id.push(value.id)
                })
                var responsibility = $(".responsibility").val();
                var markup = "<tr><td> <input type='hidden' name='associate_official[" + j +
                    "][responsibility]' value='" + responsibility + "' />" + responsibility +
                    "</td><td><input type='hidden' name='associate_official[" + j + "][id]' value='" +
                    ass_off_id.toString() + "' /> " + ass_off.toString(); +
                "</td><td>তথ্য অনুপস্থিত</td><td><a class='btn btn-xs btn-danger delete_associate_official'>{{ trans('global.delete') }}</a></td></tr>";
                $(".Asssociate-officials-table table tbody").append(markup);
                $('.ajaxSearch').val(null).trigger("change")
            });

            $('body').on('click', '.delete_associate_official', function(e) {
                $(this).closest('tr').remove();
            })

            $(".add-budget").click(function() {
                var time = Date.now();
                var markup = "<tr><td><input type='text' class='form-control' name='budget[" + time +
                    "][name]' value='' /></td><td><input type='number' class='form-control' name='budget[" +
                    time +
                    "][unit]' value='' /></td><td><input type='number' class='form-control qty' name='budget[" +
                    time +
                    "][qty]' value='' /></td><td><input type='number' class='form-control budget_rate' name='budget[" +
                    time +
                    "][rate]' value='' /></td><td><input type='number' class='item-total-cost form-control total_cost' name='budget[" +
                    time +
                    "][total_cost]' value='' /></td> <td><a class='btn btn-xs btn-danger delete_budget'><i class='fas fa-trash'></i></a></td></tr>";
                $(".budget-table table tbody").append(markup);
            })

        });
    </script>

@endsection
