@extends('layouts.admin')
@section('content')
    @can('lesson_create')
        <div style="margin-bottom: 10px;" class="row">
            <div class="col-lg-12">
                <a class="btn btn-success" href="{{ route('lessons.create') }}">
                    {{ trans('global.add') }} {{ trans('cruds.lesson.title_singular') }}
                </a>
            </div>
        </div>
    @endcan
    <div class="card">
        <div class="card-header">
            {{ trans('cruds.lesson.title_singular') }} {{ trans('global.list') }}
        </div>

        <div class="card-body">
            <div class="table-responsive">
                <table class=" table table-bordered table-striped table-hover datatable datatable-Lesson">
                    <thead>
                        <tr>
                            <th width="10">

                            </th>

                            <th>
                                {{ trans('cruds.lesson.fields.course') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.name') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.date') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.start_time') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.end_time') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.resource_person') }}
                            </th>
                            <th>
                                {{ trans('cruds.lesson.fields.trg_session') }}
                            </th>
                            <th>
                                &nbsp;
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($lessons as $key => $lesson)
                            <tr data-entry-id="{{ $lesson->id }}">
                                <td>

                                </td>

                                <td>
                                    {{ $lesson->course->course_code ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->name ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->date ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->start_time ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->end_time ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->resource_person->name ?? '' }}
                                </td>
                                <td>
                                    {{ $lesson->trg_session ?? '' }}
                                </td>
                                <td>
                                    @can('lesson_show')
                                        <a class="btn btn-xs btn-primary" href="{{ route('lessons.show', $lesson->id) }}">
                                            {{ trans('global.view') }}
                                        </a>
                                    @endcan

                                    @can('lesson_edit')
                                        <a class="btn btn-xs btn-info" href="{{ route('lessons.edit', $lesson->id) }}">
                                            {{ trans('global.edit') }}
                                        </a>
                                    @endcan

                                    @can('lesson_delete')
                                        <form action="{{ route('lessons.destroy', $lesson->id) }}" method="POST"
                                            onsubmit="return confirm('{{ trans('global.areYouSure') }}');"
                                            style="display: inline-block;">
                                            <input type="hidden" name="_method" value="DELETE">
                                            <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                            <input type="submit" class="btn btn-xs btn-danger"
                                                value="{{ trans('global.delete') }}">
                                        </form>
                                    @endcan

                                </td>

                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection
@section('scripts')
    @parent
    <script>
        $(function() {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('lesson_delete')
                let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
                let deleteButton = {
                    text: deleteButtonTrans,
                    url: "{{ route('lessons.massDestroy') }}",
                    className: 'btn-danger',
                    action: function(e, dt, node, config) {
                        var ids = $.map(dt.rows({
                            selected: true
                        }).nodes(), function(entry) {
                            return $(entry).data('entry-id')
                        });

                        if (ids.length === 0) {
                            alert('{{ trans('global.datatables.zero_selected') }}')

                            return
                        }

                        if (confirm('{{ trans('global.areYouSure') }}')) {
                            $.ajax({
                                    headers: {
                                        'x-csrf-token': _token
                                    },
                                    method: 'POST',
                                    url: config.url,
                                    data: {
                                        ids: ids,
                                        _method: 'DELETE'
                                    }
                                })
                                .done(function() {
                                    location.reload()
                                })
                        }
                    }
                }
                dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                orderCellsTop: true,
                order: [
                    [1, 'desc']
                ],
                pageLength: 100,
            });
            let table = $('.datatable-Lesson:not(.ajaxTable)').DataTable({
                buttons: dtButtons
            })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e) {
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });

        })
    </script>
@endsection
