@extends('layouts.admin')
@section('styles')
    <style>
        h3 {
            font-size: 22px;
        }

        .details p {
            font-weight: 500;
        }

        p {
            margin-bottom: 5px;
        }
    </style>
@endsection
@section('content')
    <div class="card">
        <div class="card-header text-center">
            <div class="details">
                <h3>Lesson: {{ $data[0]->lesson_name }}</h3>
                <p>{!! $data[0]->lesson_topic !!}</p>
                <p>Date: {{ Carbon\Carbon::parse($data[0]->lesson_date)->format('jS F Y') }}</p>
                <p>Start: {{ $data[0]->lesson_start_time }} | End: {{ $data[0]->lesson_end_time }}</p>
            </div>
        </div>


        <div class="card-body">
            <form action="">
                <div class="table-responsive">
                    <table class="table table-bordered table-striped table-hover">
                        <thead>
                            <tr>
                                <th>
                                    Date & Time
                                </th>
                                <th>
                                    Trainee
                                </th>
                                <th>
                                    Learning Points
                                </th>
                                <th>
                                    Marks
                                </th>
                                <th>
                                    Action
                                </th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($data as $key => $data)
                                <tr>

                                    <td width="200px">
                                        {{ Carbon\Carbon::parse($data->created_at)->format('jS F Y g:i A') }}
                                    </td>
                                    <td width="200px">
                                        {{ $data->name }}
                                    </td>
                                    <td width="400px">
                                        {!! $data->learning_point !!}
                                    </td>

                                    <td width="300px">
                                        @php
                                            $mark = $data->mark ? $data->mark : null;
                                        @endphp
                                        @if ($mark)
                                            <b>{{ $mark }}</b>
                                        @else
                                            <div style="display: flex;gap:15px;" id="marking">
                                                <div>
                                                    <input type="number" class="form-control" id="mark"
                                                        name="mark">

                                                    <input type="hidden" name="lp_id" id="lp_id"
                                                        value="{{ $data->learning_point_id }}">
                                                    <input type="hidden" name="trainee_id" id="trainee_id"
                                                        value="{{ $data->user_id }}">
                                                </div>
                                                <div>
                                                    <button class="btn btn-success submit_mark">Submit</button>
                                                </div>
                                            </div>
                                        @endif

                                    </td>
                                    <td>
                                        @php
                                            $attendence = $data->is_present;
                                        @endphp
                                        <div class="form-check-inline">
                                            <label class="form-check-label" for="radio1">
                                                <input type="radio" class="form-check-input"
                                                    data-lesson-id={{ $data->lesson_id }}
                                                    data-trainee-id={{ $data->user_id }} id="radio1" name="present"
                                                    {{ $attendence ? ($attendence == '1' ? 'checked' : '') : '' }}
                                                    value="1">Present
                                            </label>
                                        </div>
                                        <div class="form-check-inline">
                                            <label class="form-check-label" for="radio2">
                                                <input type="radio" class="form-check-input"
                                                    data-lesson-id={{ $data->lesson_id }}
                                                    data-trainee-id={{ $data->user_id }} id="radio2" name="present"
                                                    {{ $attendence ? ($attendence == '0' ? 'checked' : '') : '' }}
                                                    value="0">Absent
                                            </label>
                                        </div>
                                    </td>

                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </form>
        </div>
    </div>
@endsection

@section('scripts')
    @parent
    <script>
        $("input[name=present]").change(function(e) {
            e.preventDefault();
            let val = $(this).val()
            let lesson_id = $(this).data('lesson-id')
            let trainee_id = $(this).data('trainee-id')
            $.ajax({
                url: '{{ route('trainee-attendance') }}',
                type: 'POST',
                data: {
                    "_token": "{{ csrf_token() }}",
                    present: val,
                    lesson_id: lesson_id,
                    trainee_id: trainee_id,
                },
                success: function(response) {
                    if (response == 'success') {
                        toastr.success('Operation Successful');
                    }
                },
                error: function(response) {

                },
            });
        });

        $(".submit_mark").click(function(e) {
            e.preventDefault();
            var $markedit = $(this);
            let val = $(this).val()
            let mark = $('#mark').val();
            let lp_id = $('#lp_id').val();
            let trainee_id = $('#trainee_id').val();
            $.ajax({
                url: '{{ route('learning-point-mark') }}',
                type: 'POST',
                data: {
                    "_token": "{{ csrf_token() }}",
                    mark: mark,
                    lp_id: lp_id,
                    trainee_id: trainee_id,
                },
                success: function(response) {
                    if (response == 'success') {
                        toastr.success('Operation Successful');
                        $markedit.parents('div').find("#marking").html('<b>' + mark + '</b>');
                    }

                },
                error: function(response) {

                },
            });
        });
    </script>
@endsection
