@extends('layouts.admin')
@section('content')
    @can('nomination_create', $courseRole)
        <div style="margin-bottom: 10px;" class="row">
            <div class="col-lg-12">
                <a class="btn btn-success" href="{{ route('nominations.create') }}">
                    {{ trans('global.add') }} {{ trans('cruds.nomination.title_singular') }}
                </a>
            </div>
        </div>
    @endcan
    <div class="card">
        <div class="card-header">
            {{ trans('cruds.nomination.title_singular') }} {{ trans('global.list') }}
        </div>

        <div class="card-body">
            <div class="table-responsive">
                <table class=" table table-bordered table-striped table-hover datatable datatable-Nomination">
                    <thead>
                        <tr>
                            <th width="10">
                                No
                            </th>

                            <th>
                                Course Title
                            </th>
                            <th>
                                Course Fee
                            </th>
                            <th>
                                Number of Trainee
                            </th>

                            <th>
                                &nbsp;
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($nominatedOrganisations as $key => $nomination)
                            <tr data-entry-id="{{ $nomination->id }}">
                                <td>
                                    {{ $key + 1 }}
                                </td>

                                <td>
                                    {{ $nomination->nomination->course->title }}
                                </td>

                                <td>
                                    {{ $nomination->nomination->course_fee ?? '' }}
                                </td>

                                <td>
                                    {{ $nomination->number_of_trainee ?? '' }}
                                </td>

                                <td>
                                    @can('nomination_list', $courseRole)
                                        @php
                                            $sentcount = $nomination->organization->organizationNominatedTrainees
                                                ->where('nomination_id', $nomination->nomination_id)
                                                ->where('replace', '=', 0)
                                                ->count();
                                        @endphp
                                        @if ($sentcount == $nomination->number_of_trainee)
                                            <a class="btn btn-xs btn-success disabled" data-toggle="modal"
                                                data-target="#exampleModal" disabled>
                                                Add Trainee
                                            </a>
                                            <span
                                                class="badge badge-pill badge-success">{{ $sentcount }}/{{ $nomination->number_of_trainee }}</span>
                                        @else
                                            <a class="btn btn-xs btn-success add_trainee"
                                                data-course_title="{{ $nomination->nomination->course->title }}"
                                                data-nomination-id={{ $nomination->nomination_id }}
                                                data-org-id={{ $nomination->organization_id }} data-toggle="modal"
                                                data-target="#exampleModal" style="color: white;">
                                                Add Trainee
                                            </a>
                                            <span
                                                class="badge badge-pill badge-success">{{ $sentcount }}/{{ $nomination->number_of_trainee }}</span>
                                        @endif
                                        <!-- Modal -->
                                        <div class="modal fade" id="exampleModal" tabindex="-1" role="dialog"
                                            aria-labelledby="exampleModalLabel" aria-hidden="true">
                                            <div class="modal-dialog" role="document">
                                                <div class="modal-content">
                                                    <div class="modal-header">
                                                        <h4 class="modal_title"></h4>
                                                        <button type="button" class="close" data-dismiss="modal"
                                                            aria-label="Close">
                                                            <span aria-hidden="true">&times;</span>
                                                        </button>
                                                    </div>
                                                    <div class="modal-body">
                                                        <form action="{{ route('organisation.trainee.store') }}"
                                                            method="POST">
                                                            @csrf
                                                            <input type="hidden" id="nomination_id" name="nomination_id"
                                                                value="">
                                                            <input type="hidden" id="organization_id" name="organization_id"
                                                                value="">
                                                            <div class="form-group">
                                                                <label for="exampleInputEmail1">Name</label>
                                                                <input type="text" name="name" class="form-control"
                                                                    id="exampleInputEmail1" aria-describedby="emailHelp"
                                                                    placeholder="name" data-validation="required">
                                                            </div>
                                                            <div class="form-group">
                                                                <label for="exampleInputEmail1">Email</label>
                                                                <input type="text" name="email" class="form-control"
                                                                    id="exampleInputEmail1" aria-describedby="emailHelp"
                                                                    placeholder="email" data-validation="required">
                                                            </div>
                                                            <div class="form-group">
                                                                <label for="exampleInputEmail1">Mobile</label>
                                                                <input type="text" name="mobile" class="form-control"
                                                                    id="exampleInputEmail1" aria-describedby="emailHelp"
                                                                    placeholder="017xxxxxxxx" data-validation="required">
                                                            </div>
                                                            <div class="form-group">
                                                                <label for="designation">Designation</label>
                                                                <select class="form-control" name="designation" id="designation"
                                                                    data-validation="required">
                                                                    <option value="">Please select</option>
                                                                    @foreach ($designations as $item)
                                                                        <option value="{{ $item->id }}">
                                                                            {{ $item->name }}</option>
                                                                    @endforeach
                                                                </select>

                                                            </div>

                                                            <input type="hidden" name="organization_id"
                                                                value="{{ auth()->user()->organization_id }}">
                                                            {{-- <div class="form-group">
                                                    <label for="exampleInputEmail1">Department</label>
                                                    <input type="text" name="department" class="form-control" id="exampleInputEmail1" aria-describedby="emailHelp" placeholder="Department" data-validation="required">
                                                </div> --}}
                                                            <button type="submit" class="btn btn-primary">Submit</button>
                                                        </form>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    @endcan

                                    @can('nomination_list', $courseRole)
                                        <a class="btn btn-xs btn-info"
                                            href="{{ route('organisation.trainee.view', $nomination->nomination_id) }}">
                                            View Trainee
                                        </a>
                                    @endcan

                                    @can('nomination_delete', $courseRole)
                                        <form action="{{ route('nominations.destroy', $nomination->id) }}" method="POST"
                                            onsubmit="return confirm('{{ trans('global.areYouSure') }}');"
                                            style="display: inline-block;">
                                            <input type="hidden" name="_method" value="DELETE">
                                            <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                            <input type="submit" class="btn btn-xs btn-danger"
                                                value="{{ trans('global.delete') }}">
                                        </form>
                                    @endcan

                                </td>

                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection
@section('scripts')
    @parent
    <script>
        $(document).on('click', '.add_trainee', function(e) {
            let nomination_id = $(this).data('nomination-id')
            let course_name = $(this).data('course_title')
            let org_id = $(this).data('org-id')
            $('#organization_id').val(org_id)
            $('#nomination_id').val(nomination_id)
            $('.modal_title').text('Add Trainee for ' + course_name)
        })
        $(function() {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('nomination_delete', $courseRole)
                let deleteButtonTrans =
                    '{{ trans('
                                                                                global.datatables.delete ') }}'
                let deleteButton = {
                    text: deleteButtonTrans,
                    url: "{{ route('nominations.massDestroy') }}",
                    className: 'btn-danger',
                    action: function(e, dt, node, config) {
                        var ids = $.map(dt.rows({
                            selected: true
                        }).nodes(), function(entry) {
                            return $(entry).data('entry-id')
                        });

                        if (ids.length === 0) {
                            alert(
                                '{{ trans('
                                                                                                                                                        global.datatables.zero_selected ') }}'
                            )

                            return
                        }

                        if (confirm(
                                '{{ trans('
                                                                                                                                                global.areYouSure ') }}'
                            )) {
                            $.ajax({
                                    headers: {
                                        'x-csrf-token': _token
                                    },
                                    method: 'POST',
                                    url: config.url,
                                    data: {
                                        ids: ids,
                                        _method: 'DELETE'
                                    }
                                })
                                .done(function() {
                                    location.reload()
                                })
                        }
                    }
                }
                dtButtons.push(deleteButton)
            @endcan

            let table = $('.datatable-Nomination:not(.ajaxTable)').DataTable({
                buttons: dtButtons
            })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e) {
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });

        })
    </script>
@endsection
