@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.edit') }} {{ trans('cruds.traineeInfo.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" action="{{ route("trainee-infos.update", [$traineeInfo->id]) }}" enctype="multipart/form-data">
            @method('PUT')
            @csrf
            <div class="form-group">
                <label class="required" for="email">{{ trans('cruds.traineeInfo.fields.email') }}</label>
                <input class="form-control {{ $errors->has('email') ? 'is-invalid' : '' }}" type="email" name="email" id="email" value="{{ old('email', $traineeInfo->email) }}" required>
                @if($errors->has('email'))
                    <div class="invalid-feedback">
                        {{ $errors->first('email') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.email_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="name_english">{{ trans('cruds.traineeInfo.fields.name_english') }}</label>
                <input class="form-control {{ $errors->has('name_english') ? 'is-invalid' : '' }}" type="text" name="name_english" id="name_english" value="{{ old('name_english', $traineeInfo->name_english) }}" required>
                @if($errors->has('name_english'))
                    <div class="invalid-feedback">
                        {{ $errors->first('name_english') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.name_english_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.traineeInfo.fields.designation') }}</label>
                <select class="form-control {{ $errors->has('designation') ? 'is-invalid' : '' }}" name="designation" id="designation" required>
                    <option value disabled {{ old('designation', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\TraineeInfo::DESIGNATION_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('designation', $traineeInfo->designation) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('designation'))
                    <div class="invalid-feedback">
                        {{ $errors->first('designation') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.designation_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="other_designation">{{ trans('cruds.traineeInfo.fields.other_designation') }}</label>
                <input class="form-control {{ $errors->has('other_designation') ? 'is-invalid' : '' }}" type="text" name="other_designation" id="other_designation" value="{{ old('other_designation', $traineeInfo->other_designation) }}">
                @if($errors->has('other_designation'))
                    <div class="invalid-feedback">
                        {{ $errors->first('other_designation') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.other_designation_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="organization_id">{{ trans('cruds.traineeInfo.fields.organization') }}</label>
                <select class="form-control select2 {{ $errors->has('organization') ? 'is-invalid' : '' }}" name="organization_id" id="organization_id" required>
                    @foreach($organizations as $id => $entry)
                        <option value="{{ $id }}" {{ (old('organization_id') ? old('organization_id') : $traineeInfo->organization->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('organization'))
                    <div class="invalid-feedback">
                        {{ $errors->first('organization') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.organization_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="mobile_no">{{ trans('cruds.traineeInfo.fields.mobile_no') }}</label>
                <input class="form-control {{ $errors->has('mobile_no') ? 'is-invalid' : '' }}" type="text" name="mobile_no" id="mobile_no" value="{{ old('mobile_no', $traineeInfo->mobile_no) }}" required>
                @if($errors->has('mobile_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mobile_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.mobile_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="gmail_address">{{ trans('cruds.traineeInfo.fields.gmail_address') }}</label>
                <input class="form-control {{ $errors->has('gmail_address') ? 'is-invalid' : '' }}" type="email" name="gmail_address" id="gmail_address" value="{{ old('gmail_address', $traineeInfo->gmail_address) }}" required>
                @if($errors->has('gmail_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('gmail_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.gmail_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="other_email_address">{{ trans('cruds.traineeInfo.fields.other_email_address') }}</label>
                <input class="form-control {{ $errors->has('other_email_address') ? 'is-invalid' : '' }}" type="email" name="other_email_address" id="other_email_address" value="{{ old('other_email_address', $traineeInfo->other_email_address) }}" required>
                @if($errors->has('other_email_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('other_email_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.other_email_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="work_division">{{ trans('cruds.traineeInfo.fields.work_division') }}</label>
                <input class="form-control {{ $errors->has('work_division') ? 'is-invalid' : '' }}" type="text" name="work_division" id="work_division" value="{{ old('work_division', $traineeInfo->work_division) }}" required>
                @if($errors->has('work_division'))
                    <div class="invalid-feedback">
                        {{ $errors->first('work_division') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.work_division_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="office_name">{{ trans('cruds.traineeInfo.fields.office_name') }}</label>
                <input class="form-control {{ $errors->has('office_name') ? 'is-invalid' : '' }}" type="text" name="office_name" id="office_name" value="{{ old('office_name', $traineeInfo->office_name) }}" required>
                @if($errors->has('office_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('office_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.office_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="office_address">{{ trans('cruds.traineeInfo.fields.office_address') }}</label>
                <input class="form-control {{ $errors->has('office_address') ? 'is-invalid' : '' }}" type="text" name="office_address" id="office_address" value="{{ old('office_address', $traineeInfo->office_address) }}" required>
                @if($errors->has('office_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('office_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.office_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="organization_id_no">{{ trans('cruds.traineeInfo.fields.organization_id_no') }}</label>
                <input class="form-control {{ $errors->has('organization_id_no') ? 'is-invalid' : '' }}" type="text" name="organization_id_no" id="organization_id_no" value="{{ old('organization_id_no', $traineeInfo->organization_id_no) }}" required>
                @if($errors->has('organization_id_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('organization_id_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.organization_id_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="entry_post">{{ trans('cruds.traineeInfo.fields.entry_post') }}</label>
                <input class="form-control {{ $errors->has('entry_post') ? 'is-invalid' : '' }}" type="text" name="entry_post" id="entry_post" value="{{ old('entry_post', $traineeInfo->entry_post) }}" required>
                @if($errors->has('entry_post'))
                    <div class="invalid-feedback">
                        {{ $errors->first('entry_post') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.entry_post_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="present_job_description">{{ trans('cruds.traineeInfo.fields.present_job_description') }}</label>
                <textarea class="form-control {{ $errors->has('present_job_description') ? 'is-invalid' : '' }}" name="present_job_description" id="present_job_description" required>{{ old('present_job_description', $traineeInfo->present_job_description) }}</textarea>
                @if($errors->has('present_job_description'))
                    <div class="invalid-feedback">
                        {{ $errors->first('present_job_description') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.present_job_description_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="service_history">{{ trans('cruds.traineeInfo.fields.service_history') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('service_history') ? 'is-invalid' : '' }}" name="service_history" id="service_history">{!! old('service_history', $traineeInfo->service_history) !!}</textarea>
                @if($errors->has('service_history'))
                    <div class="invalid-feedback">
                        {{ $errors->first('service_history') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.service_history_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="promotion_history">{{ trans('cruds.traineeInfo.fields.promotion_history') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('promotion_history') ? 'is-invalid' : '' }}" name="promotion_history" id="promotion_history">{!! old('promotion_history', $traineeInfo->promotion_history) !!}</textarea>
                @if($errors->has('promotion_history'))
                    <div class="invalid-feedback">
                        {{ $errors->first('promotion_history') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.promotion_history_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="major_professional_trainings">{{ trans('cruds.traineeInfo.fields.major_professional_trainings') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('major_professional_trainings') ? 'is-invalid' : '' }}" name="major_professional_trainings" id="major_professional_trainings">{!! old('major_professional_trainings', $traineeInfo->major_professional_trainings) !!}</textarea>
                @if($errors->has('major_professional_trainings'))
                    <div class="invalid-feedback">
                        {{ $errors->first('major_professional_trainings') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.major_professional_trainings_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="bank_account_name">{{ trans('cruds.traineeInfo.fields.bank_account_name') }}</label>
                <input class="form-control {{ $errors->has('bank_account_name') ? 'is-invalid' : '' }}" type="text" name="bank_account_name" id="bank_account_name" value="{{ old('bank_account_name', $traineeInfo->bank_account_name) }}" required>
                @if($errors->has('bank_account_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('bank_account_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.bank_account_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="bank_name">{{ trans('cruds.traineeInfo.fields.bank_name') }}</label>
                <input class="form-control {{ $errors->has('bank_name') ? 'is-invalid' : '' }}" type="text" name="bank_name" id="bank_name" value="{{ old('bank_name', $traineeInfo->bank_name) }}" required>
                @if($errors->has('bank_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('bank_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.bank_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="branch_name">{{ trans('cruds.traineeInfo.fields.branch_name') }}</label>
                <input class="form-control {{ $errors->has('branch_name') ? 'is-invalid' : '' }}" type="text" name="branch_name" id="branch_name" value="{{ old('branch_name', $traineeInfo->branch_name) }}" required>
                @if($errors->has('branch_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('branch_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.branch_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="bank_account_no">{{ trans('cruds.traineeInfo.fields.bank_account_no') }}</label>
                <input class="form-control {{ $errors->has('bank_account_no') ? 'is-invalid' : '' }}" type="text" name="bank_account_no" id="bank_account_no" value="{{ old('bank_account_no', $traineeInfo->bank_account_no) }}" required>
                @if($errors->has('bank_account_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('bank_account_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.bank_account_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.traineeInfo.fields.mobile_banking') }}</label>
                <select class="form-control {{ $errors->has('mobile_banking') ? 'is-invalid' : '' }}" name="mobile_banking" id="mobile_banking" required>
                    <option value disabled {{ old('mobile_banking', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\TraineeInfo::MOBILE_BANKING_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('mobile_banking', $traineeInfo->mobile_banking) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('mobile_banking'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mobile_banking') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.mobile_banking_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="mobile_banking_no">{{ trans('cruds.traineeInfo.fields.mobile_banking_no') }}</label>
                <input class="form-control {{ $errors->has('mobile_banking_no') ? 'is-invalid' : '' }}" type="text" name="mobile_banking_no" id="mobile_banking_no" value="{{ old('mobile_banking_no', $traineeInfo->mobile_banking_no) }}" required>
                @if($errors->has('mobile_banking_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mobile_banking_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.mobile_banking_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="name_bangla">{{ trans('cruds.traineeInfo.fields.name_bangla') }}</label>
                <input class="form-control {{ $errors->has('name_bangla') ? 'is-invalid' : '' }}" type="text" name="name_bangla" id="name_bangla" value="{{ old('name_bangla', $traineeInfo->name_bangla) }}">
                @if($errors->has('name_bangla'))
                    <div class="invalid-feedback">
                        {{ $errors->first('name_bangla') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.name_bangla_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="fathers_name">{{ trans('cruds.traineeInfo.fields.fathers_name') }}</label>
                <input class="form-control {{ $errors->has('fathers_name') ? 'is-invalid' : '' }}" type="text" name="fathers_name" id="fathers_name" value="{{ old('fathers_name', $traineeInfo->fathers_name) }}" required>
                @if($errors->has('fathers_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('fathers_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.fathers_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="mothers_name">{{ trans('cruds.traineeInfo.fields.mothers_name') }}</label>
                <input class="form-control {{ $errors->has('mothers_name') ? 'is-invalid' : '' }}" type="text" name="mothers_name" id="mothers_name" value="{{ old('mothers_name', $traineeInfo->mothers_name) }}" required>
                @if($errors->has('mothers_name'))
                    <div class="invalid-feedback">
                        {{ $errors->first('mothers_name') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.mothers_name_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="national_id_no">{{ trans('cruds.traineeInfo.fields.national_id_no') }}</label>
                <input class="form-control {{ $errors->has('national_id_no') ? 'is-invalid' : '' }}" type="text" name="national_id_no" id="national_id_no" value="{{ old('national_id_no', $traineeInfo->national_id_no) }}" required>
                @if($errors->has('national_id_no'))
                    <div class="invalid-feedback">
                        {{ $errors->first('national_id_no') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.national_id_no_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="present_address">{{ trans('cruds.traineeInfo.fields.present_address') }}</label>
                <input class="form-control {{ $errors->has('present_address') ? 'is-invalid' : '' }}" type="text" name="present_address" id="present_address" value="{{ old('present_address', $traineeInfo->present_address) }}" required>
                @if($errors->has('present_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('present_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.present_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="home_district">{{ trans('cruds.traineeInfo.fields.home_district') }}</label>
                <input class="form-control {{ $errors->has('home_district') ? 'is-invalid' : '' }}" type="text" name="home_district" id="home_district" value="{{ old('home_district', $traineeInfo->home_district) }}" required>
                @if($errors->has('home_district'))
                    <div class="invalid-feedback">
                        {{ $errors->first('home_district') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.home_district_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="permanent_address">{{ trans('cruds.traineeInfo.fields.permanent_address') }}</label>
                <input class="form-control {{ $errors->has('permanent_address') ? 'is-invalid' : '' }}" type="text" name="permanent_address" id="permanent_address" value="{{ old('permanent_address', $traineeInfo->permanent_address) }}" required>
                @if($errors->has('permanent_address'))
                    <div class="invalid-feedback">
                        {{ $errors->first('permanent_address') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.permanent_address_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.traineeInfo.fields.religion') }}</label>
                <select class="form-control {{ $errors->has('religion') ? 'is-invalid' : '' }}" name="religion" id="religion" required>
                    <option value disabled {{ old('religion', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\TraineeInfo::RELIGION_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('religion', $traineeInfo->religion) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('religion'))
                    <div class="invalid-feedback">
                        {{ $errors->first('religion') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.religion_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="educational_qualification">{{ trans('cruds.traineeInfo.fields.educational_qualification') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('educational_qualification') ? 'is-invalid' : '' }}" name="educational_qualification" id="educational_qualification">{!! old('educational_qualification', $traineeInfo->educational_qualification) !!}</textarea>
                @if($errors->has('educational_qualification'))
                    <div class="invalid-feedback">
                        {{ $errors->first('educational_qualification') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.educational_qualification_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="fields_of_interest">{{ trans('cruds.traineeInfo.fields.fields_of_interest') }}</label>
                <textarea class="form-control {{ $errors->has('fields_of_interest') ? 'is-invalid' : '' }}" name="fields_of_interest" id="fields_of_interest">{{ old('fields_of_interest', $traineeInfo->fields_of_interest) }}</textarea>
                @if($errors->has('fields_of_interest'))
                    <div class="invalid-feedback">
                        {{ $errors->first('fields_of_interest') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.fields_of_interest_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="innovative_idea">{{ trans('cruds.traineeInfo.fields.innovative_idea') }}</label>
                <textarea class="form-control {{ $errors->has('innovative_idea') ? 'is-invalid' : '' }}" name="innovative_idea" id="innovative_idea">{{ old('innovative_idea', $traineeInfo->innovative_idea) }}</textarea>
                @if($errors->has('innovative_idea'))
                    <div class="invalid-feedback">
                        {{ $errors->first('innovative_idea') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.innovative_idea_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="willing_to_work_as_a_trainer">{{ trans('cruds.traineeInfo.fields.willing_to_work_as_a_trainer') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('willing_to_work_as_a_trainer') ? 'is-invalid' : '' }}" name="willing_to_work_as_a_trainer" id="willing_to_work_as_a_trainer">{!! old('willing_to_work_as_a_trainer', $traineeInfo->willing_to_work_as_a_trainer) !!}</textarea>
                @if($errors->has('willing_to_work_as_a_trainer'))
                    <div class="invalid-feedback">
                        {{ $errors->first('willing_to_work_as_a_trainer') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.willing_to_work_as_a_trainer_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="willing_to_work_as_a_consultant">{{ trans('cruds.traineeInfo.fields.willing_to_work_as_a_consultant') }}</label>
                <textarea class="form-control ckeditor {{ $errors->has('willing_to_work_as_a_consultant') ? 'is-invalid' : '' }}" name="willing_to_work_as_a_consultant" id="willing_to_work_as_a_consultant">{!! old('willing_to_work_as_a_consultant', $traineeInfo->willing_to_work_as_a_consultant) !!}</textarea>
                @if($errors->has('willing_to_work_as_a_consultant'))
                    <div class="invalid-feedback">
                        {{ $errors->first('willing_to_work_as_a_consultant') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.willing_to_work_as_a_consultant_helper') }}</span>
            </div>
            <div class="form-group">
                <label for="additional_comment">{{ trans('cruds.traineeInfo.fields.additional_comment') }}</label>
                <textarea class="form-control {{ $errors->has('additional_comment') ? 'is-invalid' : '' }}" name="additional_comment" id="additional_comment">{{ old('additional_comment', $traineeInfo->additional_comment) }}</textarea>
                @if($errors->has('additional_comment'))
                    <div class="invalid-feedback">
                        {{ $errors->first('additional_comment') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.additional_comment_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required">{{ trans('cruds.traineeInfo.fields.bpmi_bus_arrangements') }}</label>
                <select class="form-control {{ $errors->has('bpmi_bus_arrangements') ? 'is-invalid' : '' }}" name="bpmi_bus_arrangements" id="bpmi_bus_arrangements" required>
                    <option value disabled {{ old('bpmi_bus_arrangements', null) === null ? 'selected' : '' }}>{{ trans('global.pleaseSelect') }}</option>
                    @foreach(App\Models\TraineeInfo::BPMI_BUS_ARRANGEMENTS_SELECT as $key => $label)
                        <option value="{{ $key }}" {{ old('bpmi_bus_arrangements', $traineeInfo->bpmi_bus_arrangements) === (string) $key ? 'selected' : '' }}>{{ $label }}</option>
                    @endforeach
                </select>
                @if($errors->has('bpmi_bus_arrangements'))
                    <div class="invalid-feedback">
                        {{ $errors->first('bpmi_bus_arrangements') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.bpmi_bus_arrangements_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="other_method_to_go_to_payra">{{ trans('cruds.traineeInfo.fields.other_method_to_go_to_payra') }}</label>
                <textarea class="form-control {{ $errors->has('other_method_to_go_to_payra') ? 'is-invalid' : '' }}" name="other_method_to_go_to_payra" id="other_method_to_go_to_payra" required>{{ old('other_method_to_go_to_payra', $traineeInfo->other_method_to_go_to_payra) }}</textarea>
                @if($errors->has('other_method_to_go_to_payra'))
                    <div class="invalid-feedback">
                        {{ $errors->first('other_method_to_go_to_payra') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.other_method_to_go_to_payra_helper') }}</span>
            </div>
            <div class="form-group">
                <label class="required" for="user_id">{{ trans('cruds.traineeInfo.fields.user') }}</label>
                <select class="form-control select2 {{ $errors->has('user') ? 'is-invalid' : '' }}" name="user_id" id="user_id" required>
                    @foreach($users as $id => $entry)
                        <option value="{{ $id }}" {{ (old('user_id') ? old('user_id') : $traineeInfo->user->id ?? '') == $id ? 'selected' : '' }}>{{ $entry }}</option>
                    @endforeach
                </select>
                @if($errors->has('user'))
                    <div class="invalid-feedback">
                        {{ $errors->first('user') }}
                    </div>
                @endif
                <span class="help-block">{{ trans('cruds.traineeInfo.fields.user_helper') }}</span>
            </div>
            <div class="form-group">
                <button class="btn btn-danger" type="submit">
                    {{ trans('global.save') }}
                </button>
            </div>
        </form>
    </div>
</div>



@endsection

@section('scripts')
<script>
    $(document).ready(function () {
  function SimpleUploadAdapter(editor) {
    editor.plugins.get('FileRepository').createUploadAdapter = function(loader) {
      return {
        upload: function() {
          return loader.file
            .then(function (file) {
              return new Promise(function(resolve, reject) {
                // Init request
                var xhr = new XMLHttpRequest();
                xhr.open('POST', '{{ route('trainee-infos.storeCKEditorImages') }}', true);
                xhr.setRequestHeader('x-csrf-token', window._token);
                xhr.setRequestHeader('Accept', 'application/json');
                xhr.responseType = 'json';

                // Init listeners
                var genericErrorText = `Couldn't upload file: ${ file.name }.`;
                xhr.addEventListener('error', function() { reject(genericErrorText) });
                xhr.addEventListener('abort', function() { reject() });
                xhr.addEventListener('load', function() {
                  var response = xhr.response;

                  if (!response || xhr.status !== 201) {
                    return reject(response && response.message ? `${genericErrorText}\n${xhr.status} ${response.message}` : `${genericErrorText}\n ${xhr.status} ${xhr.statusText}`);
                  }

                  $('form').append('<input type="hidden" name="ck-media[]" value="' + response.id + '">');

                  resolve({ default: response.url });
                });

                if (xhr.upload) {
                  xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                      loader.uploadTotal = e.total;
                      loader.uploaded = e.loaded;
                    }
                  });
                }

                // Send request
                var data = new FormData();
                data.append('upload', file);
                data.append('crud_id', '{{ $traineeInfo->id ?? 0 }}');
                xhr.send(data);
              });
            })
        }
      };
    }
  }

  var allEditors = document.querySelectorAll('.ckeditor');
  for (var i = 0; i < allEditors.length; ++i) {
    ClassicEditor.create(
      allEditors[i], {
        extraPlugins: [SimpleUploadAdapter]
      }
    );
  }
});
</script>

@endsection