@extends('layouts.admin')
@section('content')
    @can('batch_create', $courseRole)
        <div style="margin-bottom: 10px;" class="row">
            <div class="col-lg-12">
                <a class="btn btn-success" href="{{ route('quiz.question.create') }}">
                    {{ trans('global.add') }} Quiz
                </a>
            </div>
        </div>
    @endcan
    <div class="card">
        <div class="card-header">
            Quiz List
        </div>

        <div class="card-body">
            <div class="table-responsive">
                <table class=" table table-bordered table-striped table-hover datatable datatable-Batch">
                    <thead>
                        <tr>
                            <th width="10">
                                No
                            </th>

                            <th>
                                Quiz
                            </th>
                            <th>
                                Course
                            </th>
                            <th>
                                Module
                            </th>
                            <th>
                                Topic
                            </th>
                            <th>
                                Mark
                            </th>
                            <th>
                                Date & Time
                            </th>
                            <th>
                                Action
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        {{-- @dd($quizes) --}}
                        @foreach ($quizes as $key => $quiz)
                            <tr data-entry-id="{{ $quiz->id }}">
                                <td>
                                    {{ $key + 1 }}
                                </td>

                                <td>
                                    {{ $quiz->title }}
                                </td>
                                <td>
                                    {{ $quiz->course ? $quiz->course->title : 'No course available' }}
                                </td>
                                <td>
                                    {{ $quiz->module->name }}
                                </td>
                                <td>
                                    {{ $quiz->topic }}
                                </td>
                                <td>
                                    {{ $quiz->quiz_mark }}
                                </td>
                                <td>
                                    {{ Carbon\Carbon::parse($quiz->date_time)->format('jS F Y g:i A') }}
                                </td>
                                <td>

                                    <a class="btn btn-xs btn-info" href="{{ route('quiz.index.edit', $quiz->id) }}">
                                        {{ trans('global.edit') }}
                                    </a>
                                    <form action="{{ route('quiz.index.destroy', $quiz->id) }}" method="POST"
                                        onsubmit="return confirm('{{ trans('global.areYouSure') }}');"
                                        style="display: inline-block;">
                                        <input type="hidden" name="_method" value="DELETE">
                                        <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                        <input type="submit" class="btn btn-xs btn-danger"
                                            value="{{ trans('global.delete') }}">
                                    </form>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection
@section('scripts')
    @parent
    <script>
        $(function() {
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('batch_delete', $courseRole)
                let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
                let deleteButton = {
                    text: deleteButtonTrans,
                    url: "{{ route('batches.massDestroy') }}",
                    className: 'btn-danger',
                    action: function(e, dt, node, config) {
                        var ids = $.map(dt.rows({
                            selected: true
                        }).nodes(), function(entry) {
                            return $(entry).data('entry-id')
                        });

                        if (ids.length === 0) {
                            alert('{{ trans('global.datatables.zero_selected') }}')

                            return
                        }

                        if (confirm('{{ trans('global.areYouSure') }}')) {
                            $.ajax({
                                    headers: {
                                        'x-csrf-token': _token
                                    },
                                    method: 'POST',
                                    url: config.url,
                                    data: {
                                        ids: ids,
                                        _method: 'DELETE'
                                    }
                                })
                                .done(function() {
                                    location.reload()
                                })
                        }
                    }
                }
                dtButtons.push(deleteButton)
            @endcan

            $.extend(true, $.fn.dataTable.defaults, {
                "ordering": false,
                pageLength: 100,
            });
            let table = $('.datatable-Batch:not(.ajaxTable)').DataTable({
                buttons: dtButtons
            })
            $('a[data-toggle="tab"]').on('shown.bs.tab click', function(e) {
                $($.fn.dataTable.tables(true)).DataTable()
                    .columns.adjust();
            });

        })
    </script>
@endsection
