<?php

use App\Http\Controllers\CalenderController;

Route::get('/clear-cache', function () {
    $exitCode = Artisan::call('config:clear');
    $exitCode = Artisan::call('cache:clear');
    $exitCode = Artisan::call('config:cache');

    return 'DONE'; //Return anything
});

Route::get('/migrate', function () {

    ini_set('memory_limit', '64M');

    Artisan::call('migrate', [
        '--force' => true
    ]);

    return 'DONE'; //Return anything
});
Route::view('/', 'welcome');
Route::get('/trainee-signup', 'Auth\RegisterController@traineSignupPage');
Route::post('/trainee-signup', 'Auth\RegisterController@traineSignup');
Route::post('/join-course', 'Admin\CourseController@joinCourse')->name('joinCourse');
Route::view('/join-a-course', 'coursejoin');
Route::get('/home', function () {
    if (session('status')) {
        return redirect()->route('home')->with('status', session('status'));
    }

    return redirect()->route('home');
});


Auth::routes(['register' => false]);

Route::group(['namespace' => 'Admin', 'middleware' => ['auth']], function () {
    Route::get('/dashboard', 'HomeController@index')->name('home');
    // Permissions
    Route::delete('permissions/destroy', 'PermissionsController@massDestroy')->name('permissions.massDestroy');
    Route::resource('permissions', 'PermissionsController');

    // Roles
    Route::delete('roles/destroy', 'RolesController@massDestroy')->name('roles.massDestroy');
    Route::resource('roles', 'RolesController');

    // Users
    //Route::delete('users/destroy', 'UsersController@massDestroy')->name('users.massDestroy');
    Route::resource('users', 'UsersController');
    Route::get('allusers', 'UsersController@allUsers')->name('allusers.list');
    Route::get('users/list/{id}', 'UsersController@traineeList')->name('users.list');
    Route::get('organization/list', 'UsersController@orgList')->name('org.list');

    // Organization
    Route::delete('organizations/destroy', 'OrganizationController@massDestroy')->name('organizations.massDestroy');
    Route::post('organizations/media', 'OrganizationController@storeMedia')->name('organizations.storeMedia');
    Route::post('organizations/ckmedia', 'OrganizationController@storeCKEditorImages')->name('organizations.storeCKEditorImages');
    Route::resource('organizations', 'OrganizationController');
    Route::get('approve-list', 'OrganizationController@traineeList')->name('trainee_approve');
    Route::get('organization-trainee/{courseid}', 'OrganizationController@courseWiseTrainee')->name('organization.trainee');
    Route::post('organization-trainee-approve', 'OrganizationController@approveTrainee')->name('trainee.approve');
    Route::post('organization-trainee-deny', 'OrganizationController@denyTrainee')->name('trainee.deny');


    // Nomination
    Route::delete('nominations/destroy', 'NominationController@massDestroy')->name('nominations.massDestroy');
    Route::resource('nominations', 'NominationController');
    Route::patch('update-number-of-trainee/{traineeId}', 'NominationController@updateNumberTrainee')->name('number-of-nomination');

    // Nominated Organisation
    Route::delete('nominated-organisations/destroy', 'NominatedOrganisationController@massDestroy')->name('nominated-organisations.massDestroy');
    Route::resource('nominated-organisations', 'NominatedOrganisationController');
    Route::get('nominated-organisations-create/{nomination_id}', 'NominatedOrganisationController@create');
    Route::get('get-nomination/{nomination_id}', 'NominatedOrganisationController@getNomination');
    Route::get('nominated-org-remove/{id}', 'NominatedOrganisationController@nominatedOrgRemove');
    // Nomination Wise Organisation
    Route::get('nomination/organization/ajax/{nomination_id}', 'NominatedOrganisationController@nominationWiseOrganization');


    // Nominated Trainee
    Route::delete('nominated-trainees/destroy', 'NominatedTraineeController@massDestroy')->name('nominated-trainees.massDestroy');
    Route::resource('nominated-trainees', 'NominatedTraineeController');

    // Batch
    Route::delete('batches/destroy', 'BatchController@massDestroy')->name('batches.massDestroy');
    Route::resource('batches', 'BatchController');

    // Course
    Route::delete('courses/destroy', 'CourseController@massDestroy')->name('courses.massDestroy');
    Route::post('courses/media', 'CourseController@storeMedia')->name('courses.storeMedia');
    Route::post('courses/ckmedia', 'CourseController@storeCKEditorImages')->name('courses.storeCKEditorImages');
    Route::resource('courses', 'CourseController')->except(['index']);
    Route::get('previous-courses', 'CourseController@previousCourses')->name('courses.previous');
    Route::get('ongoing-courses', 'CourseController@ongoingCourses')->name('courses.ongoing');
    Route::get('all-courses', 'CourseController@index')->name('courses.all');
    Route::get('adjustment-sheet/course/{courseId}', 'CourseController@adjustmentSheet')->name('courseadjustmentsheet.index');;
    Route::post('adjustment-sheet', 'CourseController@adjustmentSheetUpload')->name('courseadjustmentsheet.store');
    Route::get('course-approval', 'CourseController@approval')->name('courses.approval');
    Route::get('course-settings/{course}', 'CourseController@courseSettingsEdit')->name('courses.settings');
    Route::PUT('course-settings/{course}', 'CourseController@updateCourseSettings')->name('courses.settings.update');
    Route::resource('course-initiation', 'CourseInitiationController');
    Route::delete('course-initiation/destroy', 'CourseInitiationController@massDestroy')->name('course-initiation.massDestroy');
    // COURSE DIRECTOR COURSE CREATE
    Route::get('courses-create/{courseIntiation}', 'CourseController@courseCreateWithIntiation')->name('course-create');
    Route::get('courses/{courseId}/trainerlist', 'CourseController@courseTrainerList')->name('courses.trainer.list');

    Route::resource('module', 'ModuleController');
    Route::delete('moduletopics/{topic}', 'ModuleController@deleteTopic')->name('moduletopics.delete');
    Route::get('courses/{course}/add-lesson', 'CourseController@addLesson')->name('courses.addlesson');
    Route::get('courses/{course}/view-lesson', 'CourseController@viewLesson')->name('courses.viewlesson');
    Route::get('courses/{course}/evaluation-form', 'CourseController@viewEvaluationForm')->name('courses.evaluationform');
    Route::post('courses/{course}/evaluation-form', 'CourseController@saveEvaluationForm')->name('courses.saveevaluationform');
    Route::get('courses/lessons/{lessonid}/view-learning-points', 'CourseController@viewLessonLearningPoint')->name('courses.viewLessonLearningPoint');
    Route::get('courses/lessons/{lessonid}/view-evaluation', 'CourseController@viewLessonEvaluation')->name('courses.viewLessonEvaluation');
    Route::get('courses/{course}/lessons', 'CourseController@getLesson')->name('courses.getlesson');
    Route::put('course/{course}/approval', 'CourseController@approveCourse')->name('course.approve');
    Route::put('/courses/{course}/approve-deny-course', 'CourseController@approveOrDenyCourseByTrainer')->name('courses.approveOrDenyCourseByTrainer');

    // Lesson
    Route::delete('lessons/destroy', 'LessonController@massDestroy')->name('lessons.massDestroy');
    Route::post('lessons/media', 'LessonController@storeMedia')->name('lessons.storeMedia');
    Route::post('lessons/ckmedia', 'LessonController@storeCKEditorImages')->name('lessons.storeCKEditorImages');
    Route::resource('lessons', 'LessonController');
    Route::post('lessons/file', 'LessonController@lessonFileStore')->name('lessons.file.store');

    // Trainer
    Route::delete('trainers/destroy', 'TrainerController@massDestroy')->name('trainers.massDestroy');
    Route::resource('trainers', 'TrainerController');

    // Course Content
    Route::delete('course-contents/destroy', 'CourseContentController@massDestroy')->name('course-contents.massDestroy');
    Route::resource('course-contents', 'CourseContentController');

    // Exam module
    Route::get('courses/{course}/exam-module', 'CourseController@examModule')->name('courses.examModule');

    // Budget
    Route::delete('budgets/destroy', 'BudgetController@massDestroy')->name('budgets.massDestroy');
    Route::resource('budgets', 'BudgetController');

    // Course Budget
    Route::delete('course-budgets/destroy', 'CourseBudgetController@massDestroy')->name('course-budgets.massDestroy');
    Route::resource('course-budgets', 'CourseBudgetController');

    // Course Associate Officer
    Route::delete('course-associate-officers/destroy', 'CourseAssociateOfficerController@massDestroy')->name('course-associate-officers.massDestroy');
    Route::resource('course-associate-officers', 'CourseAssociateOfficerController');
    // Trainee Info
    Route::delete('trainee-infos/destroy', 'TraineeInfoController@massDestroy')->name('trainee-infos.massDestroy');
    Route::post('trainee-infos/media', 'TraineeInfoController@storeMedia')->name('trainee-infos.storeMedia');
    Route::post('trainee-infos/ckmedia', 'TraineeInfoController@storeCKEditorImages')->name('trainee-infos.storeCKEditorImages');
    Route::resource('trainee-infos', 'TraineeInfoController');
    Route::get('trainee-infos/get-branch-by-organization/{id}', 'TraineeInfoController@getBranchByOrganization');

    // Designation
    Route::delete('designations/destroy', 'DesignationController@massDestroy')->name('designations.massDestroy');
    Route::resource('designations', 'DesignationController');

    // Trainee Organization
    Route::delete('trainee-organizations/destroy', 'TraineeOrganizationController@massDestroy')->name('trainee-organizations.massDestroy');
    Route::resource('trainee-organizations', 'TraineeOrganizationController');

    // Coursefeepayment
    Route::delete('coursefeepayments/destroy', 'CoursefeepaymentController@massDestroy')->name('coursefeepayments.massDestroy');
    Route::post('coursefeepayments/media', 'CoursefeepaymentController@storeMedia')->name('coursefeepayments.storeMedia');
    Route::post('coursefeepayments/ckmedia', 'CoursefeepaymentController@storeCKEditorImages')->name('coursefeepayments.storeCKEditorImages');
    Route::resource('coursefeepayments', 'CoursefeepaymentController');
    //  COURSE PAYMENT
    Route::get('coursepayment', 'CoursefeepaymentController@list')->name('coursepayment');
    Route::get('coursepayment/{id}', 'CoursefeepaymentController@showCoursePayment')->name('coursepayment.show');
    Route::get('coursepayment/approve/{id}', 'CoursefeepaymentController@approveCoursePayment')->name('coursepayment.approve');
    Route::post('coursepayment/approve/org', 'CoursefeepaymentController@approveCoursePaymentOrg')->name('coursepayment.approve.org');
    Route::get('get-moneyReceiptData/{id}', 'CoursefeepaymentController@getMoneyReceiptData');
    Route::get('money-receipt/{id}', 'CoursefeepaymentController@moneyReceipt')->name('coursepayment.money-receipt');
    Route::post('money-receipt/mail', 'CoursefeepaymentController@moneyReceiptMail')->name('money-receipt.mail');
    Route::resource('generate-certificate', 'CertificateController');
    Route::get('certificate/{course}', 'CertificateController@certificatePDF')->name('certificate.pdf');
});
// quiz routes
Route::group(['prefix' => 'quiz', 'as' => 'quiz.', 'middleware' => ['auth']], function () {
    Route::resource('category', 'QuizCategoryController');
    Route::resource('/index', 'QuizController');
    Route::get('/list/{course}', 'QuizController@viewCourseQuiz')->name('course.view');
    Route::get('/{quizid}/exam', 'QuizController@viewQuizExam')->name('quizExam.view');
    Route::resource('question', 'QuestionBankController');
    Route::resource('exam', 'ExamController');
    Route::get('exam-result/{quizId}', 'ExamController@exemResult')->name('result');
    Route::get('trainee-result/{quizId}', 'ExamController@traineeResult')->name('allresult');
});

// Organization list
Route::group(['prefix' => 'organisation', 'namespace' => 'Organization', 'middleware' => ['auth']], function () {
    Route::get('nomination/list', 'NominatedController@index')->name('organisation.nomination.index');
    Route::post('trainee/store', 'NominatedController@traineeStore')->name('organisation.trainee.store');
    Route::get('trainee/view/{nomination_id}', 'NominatedController@traineeView')->name('organisation.trainee.view');
    Route::post('trainee/replace', 'NominatedController@traineeReplace')->name('approved_trainee_replace');
    Route::post('trainee/destroy/', 'NominatedController@destroy')->name('nominationtrainee.destroy');
});
Route::group(['prefix' => 'profile', 'as' => 'profile.', 'namespace' => 'Auth', 'middleware' => ['auth']], function () {
    // Change password
    if (file_exists(app_path('Http/Controllers/Auth/ChangePasswordController.php'))) {
        Route::get('password', 'ChangePasswordController@edit')->name('password.edit');
        Route::post('password', 'ChangePasswordController@update')->name('password.update');
        Route::post('profile', 'ChangePasswordController@updateProfile')->name('password.updateProfile');
        Route::post('profile/destroy', 'ChangePasswordController@destroy')->name('password.destroyProfile');
        Route::post('profile/sign', 'ChangePasswordController@signUpload')->name('sign.update');
    }
});
Route::group(['middleware' => ['auth']], function () {
    //learning-points
    Route::resource('learning-points', 'LearningPointController');
    Route::resource('trainer-evaluation', 'TrainerEvaluationController');
    Route::resource('trainer-evaluation', 'TrainerEvaluationController');
    Route::resource('training-resource', 'TrainingResourceController');
    //Route::resource('training_allownce_acknowledgement', 'TrainingResourceController');
    Route::resource('exam-module', 'ExamModuleController');
    Route::resource('exam-marks', 'ExamMarkController');
    Route::get('release-order/{course}', 'ReleaseOrderController@create')->name('release-order.create');
    Route::post('release-order', 'ReleaseOrderController@store')->name('release-order.store');
    Route::get('view-release-order/{course}', 'ReleaseOrderController@show')->name('release-order.show');
});
//assignments
Route::group(['namespace' => 'Admin', 'middleware' => ['auth']], function () {
    Route::get('create-assignment-group/{course}', 'CourseController@createAssignmentGroup')->name('assignment-group.create');
    Route::get('view-assignment-group/{course}', 'CourseController@viewAssignmentGroup')->name('assignment-group.view');
    Route::post('store-assignment-group', 'CourseController@storeAssignmentGroup')->name('assignment-group.store');
    Route::post('delete-assignment-group', 'CourseController@deleteAssignmentGroup')->name('assignment-group.delete');
    Route::post('saveAssignmentFileForGroup', 'CourseController@saveAssignmentFileForGroup')->name('assignment-group-file.store');
    Route::post('saveAssignmentFileForSingle', 'CourseController@saveAssignmentFileForSingle')->name('assignment-single-file.store');
    // SINGLE ASSIGNMET
    Route::get('view-assignment/{course}', 'CourseController@viewAssignments')->name('assignments.view');
    Route::get('view-myAssignment/{id}', 'CourseController@getMyAssignment');
    Route::post('store-assignment-submission', 'CourseController@storeAssignmentSubmission')->name('assignment-submission');
    // GROUP ASSIGNMENT
    Route::get('get-groupAssignment/{id}', 'CourseController@getGroupAssignment');
    // GROUP Presentation
    Route::get('get-groupPresentation/{id}', 'CourseController@getGroupPresentation');
    Route::post('store-presentation-submission', 'CourseController@storePresentationSubmission')->name('presentation-submission');

    // TRAINEE REMOVE FORM ASSIGNMENT GROUP
    Route::post('trainee-remove', 'CourseController@traineeRemove')->name('trainee-remove.assignment');

    Route::get('get-myAssignment/{id}', 'CourseController@getMyAssignment');
    // COURSE WISE TRAINEE VIEW

    Route::get('view-course-trainee/{courseId}', 'CourseController@viewCourseTrainee')->name('course-trainee.view');
    // CREATE PRESENTATION 
    Route::get('create-presentation-group/{course}', 'CourseController@createPresentationGroup')->name('presentation-group.create');
    Route::get('view-presentation-group/{course}', 'CourseController@viewPresentationGroup')->name('presentation-group.view');
    Route::post('delete-presentation-group', 'CourseController@deletePresentationGroup')->name('presentation-group.delete');
    Route::post('store-presentation-group', 'CourseController@storePresentationGroup')->name('presentation-group.store');
    Route::post('savePresentationForSingle', 'CourseController@savePresentationForSingle')->name('presentation-single.store');
    Route::post('savePresentationForGroup', 'CourseController@savePresentationForGroup')->name('presentation-group-file.store');
    Route::get('view-presentation/{course}', 'CourseController@viewPresentations')->name('presentation.view');
    Route::get('add-marks/{course}', 'CourseController@addMarks')->name('marks.add');
    // TRAINEE REMOVE FORM PRESENTATION GROUP
    Route::post('trainee-remove/presentation', 'CourseController@traineeRemovePresentation')->name('trainee-remove.presentation');
});

// report  routes

Route::group(['prefix' => 'report', 'as' => 'report.', 'middleware' => ['auth']], function () {

    Route::get('/trainee', 'ReportController@courseTraineeReport')->name('trainee');
});



Route::group(['prefix' => 'export', 'as' => 'export.', 'middleware' => ['auth']], function () {

    Route::get('/trainee/{courseid}', 'ReportController@exportTraineeList')->name('trainee');
});


// Route::group(['namespace' => 'Admin', 'prefix' => 'trainer', 'as' => 'trainer.', 'middleware' => ['auth']], function () {
//     Route::get('approve-lessons/{course}', 'LessonController@viewAndApproveLesson')->name('course.approvelesson');
// });

//ajax routes
Route::get('user-search', 'AjaxController@userSearch')->name('user.search');
Route::post('exam-module-form', 'AjaxController@examModuleForm')->name('courses.examModuleForm');
Route::get('staff-search', 'AjaxController@staffSearch')->name('staff.search');
Route::get('get-quiz-subcategories/{catId}', 'AjaxController@getQuizSubcategories')->name('quizsubcategory.list');
Route::get('get-questions', 'AjaxController@getQuizQuestions');
Route::get('get-students/{courseId}', 'AjaxController@getCourseStudents');
Route::post('trainee-attendance', 'AjaxController@traineeAttendance')->name('trainee-attendance');
Route::post('learning-point-mark', 'AjaxController@saveLearningPointMark')->name('learning-point-mark');
Route::get('get-modules-by-course/{courseId}', 'AjaxController@getModulesFromCourse');
Route::get('get-lessons/{courseId}', 'AjaxController@getLessons');
Route::get('allowance-create/{courseId}', 'AllowanceAcknowledgementController@allowanceForm')->name('allowance-create');
Route::get('allowance-list/{courseId}', 'AllowanceAcknowledgementController@allowanceList')->name('allowance-list');
Route::post('allowance-save', 'AllowanceAcknowledgementController@allowanceStore')->name('allowance-store');
Route::get('book-review/{courseId}', 'BookReviewController@createCourseBookReview')->name('book-review.create');
Route::get('book-review/{courseId}/list', 'BookReviewController@index')->name('book-review.index');
Route::get('book-review-submit/{id}', 'BookReviewController@submitCourseBookReview')->name('book-review.submit');
Route::post('book-review}', 'BookReviewController@store')->name('book-review.store');
Route::PUT('book-review/{bookReview}', 'BookReviewController@update')->name('book-review.update');
// TRAINING MANAGEMENT FOR POWERDIVISION

Route::get('training-management', 'TMController@index')->name('training.management');


Route::get('calender', [CalenderController::class, 'index'])->name('calender');
Route::post('calenderAjax', [CalenderController::class, 'ajax']);
